<?php

namespace Teknisa\SM\Factory;

class ApiPropostaFactory {
    
    protected $connection;
    
    public function __construct($connection) {
        $this->connection = $connection;
    }
    
    public function getDadosLayoutGeracaoProposta(array $params) {
        $sql = "SELECT GP.NRORCAMENTOMODELO,
                       GP.DSGERACAOPROPOSTA,
                       GP.NRORG,
                       LISTAGG(ESCGP.NRTIPOORCAMENTO, ',') WITHIN GROUP (ORDER BY ESCGP.NRTIPOORCAMENTO) AS NRTIPOORCAMENTO,
                       LISTAGG(PARAMESC.CDFILIALFATURA, ',') WITHIN GROUP (ORDER BY ESCGP.NRTIPOORCAMENTO) AS CDFILIALESCOPO
                  FROM FCT_GERACAOPROPOSTA GP
                  LEFT JOIN FCT_ESCOPOGERACAOPROP ESCGP
                    ON ESCGP.NRGERACAOPROPOSTA = GP.NRGERACAOPROPOSTA
                   AND ESCGP.NRORG             = GP.NRORG
                  LEFT JOIN FCT_CAPAPARAMFATESC PARAMESC
                    ON ESCGP.NRTIPOORCAMENTO = PARAMESC.NRTIPOORCAMENTO
                   AND ESCGP.NRORG           = PARAMESC.NRORG
                 WHERE GP.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND GP.NRORG             = :NRORG
                   AND GP.IDATIVO           = 'S'
                 GROUP BY GP.NRORCAMENTOMODELO,
                       GP.DSGERACAOPROPOSTA,
                       GP.NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDadosModeloProposta(array $params) {
        $sql = "SELECT NRORCAMENTOMODELO,
                       NRARVOREPAI,
                       NRTIPOORCAMENTO,
                       NRPARCTRANSPORTADORA,
                       CDREDUCONT,
                       NMORCAMENTOMODELO,
                       DSREFERENCIAORCA,
                       IDTRANSPORTADORA,
                       QTDIASVALIDADE,
                       QTDIASCONTRATO,
                       DSOBSERVACAOORCA,
                       CDMINEMORCA,
                       NRORG,
                       IDATIVO,
                       DTINCLUSAO,
                       DTULTATU,
                       NRORGINCLUSAO,
                       CDOPERINCLUSAO,
                       NRORGULTATU,
                       CDOPERULTATU,
                       IDFATURACONTR,
                       CDMODPGTO,
                       NRGRUPOFATURA,
                       IDUTILIZAHIERSERV,
                       IDBLOQALTERADADOS,
                       IDOBRIGAOPORTUNIDADE,
                       IDUTILIZACOMP,
                       NRDIASCARENCIA,
                       QTPARCELASFATU,
                       NRDIAVENCPARCELASFATU,
                       NRSEQMODCONTRA,
                       IDASSELETRDIGITAL,
                       IDENVIADOCCONCLUSAO
                  FROM FCT_ORCAMENTOMODELO
                 WHERE NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND NRORG             = :NRORG
                   AND IDATIVO           = 'S'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getParceiroNegocioPorInscricao(array $params) {
        $sql = "SELECT NRPARCNEGOCIO
                  FROM PARCNEGOCIO
                 WHERE NRINSCRICAOPARC = :NRINSCRICAOPARC
                   AND NRORG           = :NRORG
                   AND IDATIVO         = 'S'";
                   
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getComposicoesEscolhidasLayoutGP(array $params) {
        $sql = "SELECT CGP.NRCOMPSERVICO,
                       COMP.NMCOMPSERVICO,
                       CGP.NRCOMPSERVICOPAI,
                       CGP.IDCOMPOBRIGATORIA,
                       CGP.IDESCOLHIDO
                  FROM FCT_COMPSERVGERACAOPROP CGP
                  LEFT JOIN FCT_COMPSERVICO COMP
                    ON CGP.NRCOMPSERVICO = COMP.NRCOMPSERVICO
                   AND CGP.NRORG         = COMP.NRORG
                 WHERE CGP.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND CGP.NRORG             = :NRORG
                   AND CGP.IDESCOLHIDO       = 'S'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getElementosEscolhidosLayoutGP(array $params) {
        $sql = "SELECT IDELEMENTO,
                       IDESCOLHIDO
                  FROM FCT_ELEMENTOGERACAOPROP
                 WHERE NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND NRORG             = :NRORG
                   AND IDESCOLHIDO       = 'S'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getTiposMedidaVariavelLayoutGP(array $params) {
        $sql = "SELECT MEDVAR.IDELEMENTORAIZ,
                       ELE.NMSERVORCA AS NMELEMENTORAIZ,
                       MEDVAR.CDTPMEDIDAVARIAVEL AS CDTPMEDIDASERV,
                       MEDVAR.QTMINIMA,
                       MEDVAR.QTMAXIMA,
                       MEDVAR.QTMINIMA AS QUANTIDADE,
                       MEDVAR.QTFRANQUIA
                  FROM FCT_MEDVARGERACAOPROP MEDVAR
                  LEFT JOIN FCT_SERVICOORCA ELE
                    ON MEDVAR.IDELEMENTORAIZ = ELE.IDELEMENTO
                   AND MEDVAR.NRORG          = ELE.NRORG
                 WHERE MEDVAR.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND MEDVAR.NRORG             = :NRORG
                   AND MEDVAR.IDATIVO           = 'S'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDocumentosEscoposModeloProposta(array $params, $strNrtipoorcamento) {
        $sql = "SELECT REL.NRTIPOORCAMENTO,
                       DOC.NRSEQMODDOCFCT,
                       DOC.IDSITUACAOORCAMENTO,
                       MODELO.DSMODELODOCORCA,
                       MODELO.NRORDENACAO,
                       MODELO.IDIDIOMA,
                       MODELO.IDTIPOMODELODOC,
                       MODELO.TXMODELODOCORCA,
                       MODELO.NMARQUIVO,
                       MODELO.DSCAMINHOARQ,
                       MODELO.DSTIPO,
                       MODELO.VRTAMANHO
                  FROM FCT_RELACESCOPOMODELO REL
                 INNER JOIN FCT_ORCAESCOPODOC DOC
                    ON REL.NRRELACESCOPOMODELO = DOC.NRRELACESCOPOMODELO
                   AND REL.NRORG               = DOC.NRORG
                 INNER JOIN FCT_MODELODOC MODELO
                    ON DOC.NRSEQMODDOCFCT = MODELO.NRSEQMODDOCFCT
                   AND DOC.NRORG          = MODELO.NRORG
                 WHERE REL.NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND REL.NRORG             = :NRORG
                   AND REL.NRTIPOORCAMENTO   IN ($strNrtipoorcamento)";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirParceiroNegocio(array $params) {
        $sql = "INSERT INTO PARCNEGOCIO (
                    NRPARCNEGOCIO,      NMPRINCIPALPARC,        NMSECUNDARIPARC,
                    NRINSCRICAOPARC,    CDTIPOPARCPRINCIPAL,    CDTIPOINSCRICAO,
                    IDPESSOAFISICA,     NRORG,                  IDATIVO,
                    DTINCLUSAO,         NRORGINCLUSAO,          CDOPERINCLUSAO
                )
                VALUES (
                    :NRPARCNEGOCIO,      :NMPRINCIPALPARC,        :NMSECUNDARIPARC,
                    :NRINSCRICAOPARC,    :CDTIPOPARCPRINCIPAL,    :CDTIPOINSCRICAO,
                    :IDPESSOAFISICA,     :NRORG,                  :IDATIVO,
                    SYSDATE,             :NRORGINCLUSAO,          :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirParceria(array $params) {
        $sql = "INSERT INTO PARCERIA (
                    NRPARCERIA,         NRPARCNEGOCIO,      CDTIPOPARCEIRO,
                    NRORG,              IDATIVO,            DTINCLUSAO,
                    NRORGINCLUSAO,      CDOPERINCLUSAO
                )
                VALUES (
                    :NRPARCERIA,        :NRPARCNEGOCIO,     :CDTIPOPARCEIRO,
                    :NRORG,             :IDATIVO,           SYSDATE,
                    :NRORGINCLUSAO,     :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirEnderecoParceiroNegocio(array $params) {
        $sql = "INSERT INTO ENDERECOPARC (
                    NRENDERECOPARC,     NRPARCNEGOCIO,      CDTIPOENDERECO,
                    CDPAIS,             SGESTADO,           CDMUNICIPIO,
                    CDBAIRRO,           NMBAIRROENDERECO,   DSENDERECO,
                    NRORG,              IDATIVO,            DTINCLUSAO,
                    NRORGINCLUSAO,      CDOPERINCLUSAO
                )
                VALUES (
                    :NRENDERECOPARC,     :NRPARCNEGOCIO,      :CDTIPOENDERECO,
                    :CDPAIS,             :SGESTADO,           :CDMUNICIPIO,
                    :CDBAIRRO,           :NMBAIRROENDERECO,   :DSENDERECO,
                    :NRORG,              :IDATIVO,            SYSDATE,
                    :NRORGINCLUSAO,      :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirProspect(array $params) {
        $sql = "INSERT INTO PROSPECT (
                    CDPROSPECT,     IDTPIJURPROS,   NRINSJURPROS,
                    NMRAZSOCPROS,   NMFANTPROS,     NRINSESTPROS,
                    NRPARCNEGOCIO,  NRORG,          IDATIVO,
                    DTINCLUSAO,     NRORGINCLUSAO,  CDOPERINCLUSAO
                )
                VALUES (
                    :CDPROSPECT,     :IDTPIJURPROS,   :NRINSJURPROS,
                    :NMRAZSOCPROS,   :NMFANTPROS,     :NRINSESTPROS,
                    :NRPARCNEGOCIO,  :NRORG,          :IDATIVO,
                    SYSDATE,         :NRORGINCLUSAO,  :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirEnderecoProspect(array $params) {
        $sql = "INSERT INTO ENDEPROSPECT (
                    CDPROSPECT,      IDTPENDEPROS,   CDPAIS,
                    SGESTADO,        CDMUNICIPIO,    CDBAIRRO,
                    NMBAIRPROS,      DSENDEPROS,     NRTELEPROS1,
                    NRENDERECOPARC,  NRORG,          IDATIVO,
                    DTINCLUSAO,      NRORGINCLUSAO,  CDOPERINCLUSAO
                )
                VALUES (
                    :CDPROSPECT,      :IDTPENDEPROS,   :CDPAIS,
                    :SGESTADO,        :CDMUNICIPIO,    :CDBAIRRO,
                    :NMBAIRPROS,      :DSENDEPROS,     :NRTELEPROS1,
                    :NRENDERECOPARC,  :NRORG,          :IDATIVO,
                    SYSDATE,          :NRORGINCLUSAO,  :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirComunicacaoParceiro(array $params) {
        $sql = "INSERT INTO COMUNICAPARC (
                    NRCOMUNICAPARC,     NRORG,          CDCOMUNICAPARC,
                    NRORGINCLUSAO,      CDOPERINCLUSAO, IDATIVO,
                    NRPARCNEGOCIO,      NRENDERECOPARC, DTINCLUSAO,
                    CDFORMACOMU
                )
                VALUES (
                    :NRCOMUNICAPARC,     :NRORG,          :CDCOMUNICAPARC,
                    :NRORGINCLUSAO,      :CDOPERINCLUSAO, :IDATIVO,
                    :NRPARCNEGOCIO,      :NRENDERECOPARC, SYSDATE,
                    :CDFORMACOMU
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getCodigoInterlocutorComParc(array $params){
        $sql ="SELECT NRSEQINTERLOCUTOR
            FROM CRM_INTERLOCUTOR
            WHERE EMAILINTERLOC = :EMAILINTERLOC
            AND NRCPFINTERLOC = :NRCPFINTERLOC
            AND NRPARCNEGOCIO = :NRPARCNEGOCIO
            AND NRORG         = :NRORG";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirInterlocutorAssinaturaComDados(array $params){
        $sql = "INSERT INTO FCT_ASSINATDIGITALPROP( 
                    NRASSDIGITALORCA , NRSEQORCAMENTO , NRPARCNEGOCIO ,
                    NRSEQINTERLOCUTOR, NRCPFSIGNATARIO , IDTIPOASSINATURA ,
                    IDTESTEMUNHA , NRORDENACAO , IDSITUACAO ,
                    NRORG , NRORGINCLUSAO , CDOPERINCLUSAO ,
                    DSEMAILNOTIFOUTROS, DSEMAILNOTSIGNENV, DTINCLUSAO
                ) 
                VALUES (
                    :NRASSDIGITALORCA , :NRSEQORCAMENTO, :NRPARCNEGOCIO,
                    :NRSEQINTERLOCUTOR, :NRCPFSIGNATARIO, :IDTIPOASSINATURA,
                    :IDTESTEMUNHA, :NRORDENACAO, :IDSITUACAO,
                    :NRORG,:NRORGINCLUSAO, :CDOPERINCLUSAO,
                    :DSEMAILNOTIFOUTROS, :DSEMAILNOTSIGNENV, SYSDATE 
                )";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirInterlocutorAssinaturaSemDados(array $params){
        $sql = "INSERT INTO FCT_ASSINATDIGITALPROP( 
                    NRASSDIGITALORCA , NRSEQORCAMENTO , NRPARCNEGOCIO ,
                    NRSEQINTERLOCUTOR, NRCPFSIGNATARIO , IDTIPOASSINATURA ,
                    IDTESTEMUNHA , NRORDENACAO , IDSITUACAO ,
                    NRORG , NRORGINCLUSAO , CDOPERINCLUSAO ,
                    DTINCLUSAO
                ) 
                VALUES (
                    :NRASSDIGITALORCA , :NRSEQORCAMENTO, :NRPARCNEGOCIO,
                    :NRSEQINTERLOCUTOR, :NRCPFSIGNATARIO, :IDTIPOASSINATURA,
                    :IDTESTEMUNHA, :NRORDENACAO, :IDSITUACAO,
                    :NRORG,:NRORGINCLUSAO, :CDOPERINCLUSAO,
                    SYSDATE 
                )";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getOperadoresASerNotificado(array $params) {
        $sql = "SELECT *
                  FROM FCT_ASSINATDIGITALPROP
                 WHERE NRASSDIGITALORCA = :NRASSDIGITALORCA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getNotifOutros(array $params) {
        $sql = "SELECT DSEMAILNOTIFOUTROS
                  FROM FCT_ASSINATDIGITALPROP
                 WHERE NRASSDIGITALORCA = :NRASSDIGITALORCA
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirInterlocutor(array $params) {
        $sql = "INSERT INTO CRM_INTERLOCUTOR (
                    NRSEQINTERLOCUTOR,   NRPARCNEGOCIO,    NMINTERLOCUTOR,
                    EMAILINTERLOC,       NRCPFINTERLOC,    NRTELEFONE1,
                    NRORG,               IDATIVO,          DTINCLUSAO,
                    NRORGINCLUSAO,       CDOPERINCLUSAO,   IDTPSIGNATARIO
                )
                VALUES (
                    :NRSEQINTERLOCUTOR,   :NRPARCNEGOCIO,    :NMINTERLOCUTOR,
                    :EMAILINTERLOC,       :NRCPFINTERLOC,    :NRTELEFONE1,
                    :NRORG,               :IDATIVO,          SYSDATE,
                    :NRORGINCLUSAO,       :CDOPERINCLUSAO,   :IDTPSIGNATARIO
                )";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getMunicipio(array $params) {
        $sql = "SELECT CDMUNICIPIO, NMMUNICIPIO
                  FROM MUNICIPIO
                 WHERE UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO)
                   AND SGESTADO           = :SGESTADO
                   AND CDPAIS             = :CDPAIS
                   AND NRORG              = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getBairro(array $params) {
        $sql = "SELECT CDBAIRRO, NMBAIRRO
                  FROM BAIRRO
                 WHERE UPPER(NMBAIRRO) = UPPER(:NMBAIRRO)
                   AND CDMUNICIPIO     = :CDMUNICIPIO
                   AND SGESTADO        = :SGESTADO
                   AND CDPAIS          = :CDPAIS
                   AND NRORG           = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getNrOrcamento(array $params) {
        $sql = "SELECT NRORCAMENTO 
                FROM FCT_ORCAMENTO
                WHERE NRSEQORCAMENTO =:NRSEQORCAMENTO";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    public function getSignatariosCadastradosNoModelo(array $params) {
        $sql = "SELECT * FROM FCT_SIGNATPADRMODORCA WHERE NRORCAMENTOMODELO = :NRORCAMENTOMODELO AND IDTPSIGNATARIO = 'SC'";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getItensNaoConsideradosLayoutGP(array $params) {
        $sql = "SELECT ITGP.NRTIPOORCAMENTO,
                       ITGP.NRITESCOPOPROPOSTA,
                       ITESC.CDSERVORCA
                  FROM FCT_ITESCOPOGERACAOPROP ITGP
                 INNER JOIN FCT_ITESCOPOPROPOSTA ITESC
                    ON ITGP.NRITESCOPOPROPOSTA = ITESC.NRITESCOPOPROPOSTA
                   AND ITGP.NRORG              = ITESC.NRORG
                 WHERE ITGP.NRGERACAOPROPOSTA = :NRGERACAOPROPOSTA
                   AND ITGP.NRORG             = :NRORG
                   AND ITGP.IDCONSIDERADO     = 'N'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
}

?>
