<?php

namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Util\Procedure\CriaMnemonico;
use Teknisa\SM\Util\Procedure\FctGeraDadosProposta;
use Teknisa\SM\Util\Procedure\FctCopiaVersionaProposta;
use Teknisa\SM\Util\Procedure\FctGeraContrato;
use Teknisa\SM\Util\Procedure\FctGeraPropostasFilhas;
use Teknisa\SM\Util\Procedure\FctSubMneDoc;
use Teknisa\SM\Util\Procedure\FctConversaoCliente;
use Teknisa\SM\Util\Procedure\FctSubMneDocProv;
use Teknisa\SM\Factory\Sm00001000LancamentoPropostaFactory as PropostaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\Session\Session;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Zeedhi\Framework\DTO\Row;
use Teknisa\SM\Service\Sm00003000ParamFatEscopoService;
use Teknisa\SM\Service\Sm00015004AgendamentoDeRecursoService;
use Teknisa\SM\Util\Utilities;
use Teknisa\SM\Service\IntegracaoOmService;
use Teknisa\SM\Service\IntegracoesTeknisaService;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\SM\Service\SmDocumentosService;
use Teknisa\SM\Service\SmAssinaturaDigitalService;

class Sm00001000LancamentoPropostaService {
    
    protected $connection;
    protected $propostaFactory;
    protected $environment;
    protected $newCode;
    protected $session;
    protected $paramFatEscopoFactory;
    protected $fileServerBaseUrl;
    protected $zhFileUploader;
    protected $integracaoOmService;
    protected $integracoesTeknisaService;
    protected $agedRecPendente;
    protected $smdocumentos;
    protected $assinaturaDigital;
    
    private $tempDir;
    
    
    public function __construct(EntityManager $entityManager, PropostaFactory $propostaFactory, Environment $environment, NewCode $newCode,  Session $session, Sm00003000ParamFatEscopoService $paramFatEscopoFactory,  $fileServerBaseUrl, Server $zhFileUploader, IntegracaoOmService $integracaoOmService, IntegracoesTeknisaService $integracoesTeknisaService, Sm00015004AgendamentoDeRecursoService $agedRecPendente, SmDocumentosService $smdocumentos, SmAssinaturaDigitalService $assinaturaDigital) {
        $this->connection                = $entityManager->getConnection();
        $this->propostaFactory           = $propostaFactory;
        $this->environment               = $environment;
        $this->newCode                   = $newCode;
        $this->session                   = $session;
        $this->paramFatEscopoFactory     = $paramFatEscopoFactory;
        $this->fileServerBaseUrl         = $fileServerBaseUrl;
        $this->zhFileUploader            = $zhFileUploader;
        $this->integracaoOmService       = $integracaoOmService;
        $this->integracoesTeknisaService = $integracoesTeknisaService;
        $this->agedRecPendente           = $agedRecPendente;
        $this->smdocumentos              = $smdocumentos;
        $this->assinaturaDigital         = $assinaturaDigital;
        
        $this->tempDir = sys_get_temp_dir();
    }
    
    /**
     * Executa a procedure CRIA_MNEMONICO.
     * 
     * @param integer $nrorg
     * @param string  $tipo
     * @param integer $nrseq
     * 
     * @return string
     */
    public function executarProcedureCriaMnemonico($nrorg, $tipo, $nrseq) {
        $procedure = new CriaMnemonico($this->connection);
        $mnemonico = $procedure->executar($nrorg, $tipo, $nrseq);
        return $mnemonico;
    }
    
    /**
     * Executa a procedure FCT_GERA_DADOS_PROPOSTA.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function executarProcedureFctGeraDadosProposta($nrseqorcamento, $nrorg) {
        $procedure = new FctGeraDadosProposta($this->connection);
        $procedure->executar($nrseqorcamento, $nrorg);
    }
    
    /**
     * Executa a procedure FCT_COPIA_VERSIONA_PROPOSTA.
     * 
     * @param integer $nrseqorcamento
     * @param string  $tipo
     * @param string  $cdoperador
     * @param integer $nrorg
     */
    public function executarProcedureFctCopiaVersionaProposta($nrseqorcamento, $tipo, $cdoperador, $nrorg) {
        $procedure = new FctCopiaVersionaProposta($this->connection);
        return $procedure->executar($nrseqorcamento, $tipo, $cdoperador, $nrorg);
    }
    
    /**
     * Retorna os elementos que formam a composição da proposta (o que será inserido na FCT_TRABSERVORCAMENTO).
     * 
     * @param integer[] $escopos
     * $param mixed[]   $composicoes
     * 
     * @return mixed[]
     */
    public function getElementosComposicao(array $escopos, $composicoes, $idApareceProposta = "S", $nrmoeda = null) {
        $escopos = implode(",", $escopos);
        $nrorg = $this->environment->getNrOrg();
        
        $composicoesAux = $this->getCodigoComposicaoArray($composicoes);
        $composicoesAux = implode(",", $composicoesAux);
        
        return $this->propostaFactory->getElementosComposicao($escopos, $composicoesAux, $nrorg, $idApareceProposta, $nrmoeda);
    }
    /**
     * Pega o array de dados da composição e cria outro apenas com os códigos
    **/
    public function getCodigoComposicaoArray($composicoes){
        $composicoesAux = array();
        foreach ($composicoes as $comp) {
            if ($comp["IDESCOLHIDO"] == "S") {
                $composicoesAux[] = $comp["NRCOMPSERVICO"];
            }
        }
        return $composicoesAux;
    }
    
    public function getElementosComposicaoSemCodigoComposicao(array $escopos, $composicoes, $nrorg = null, $idApareceProposta = "S", $nrmoeda = null) {
        $escopos = implode(",", $escopos);
        $nrorg = $nrorg ? $nrorg : $this->environment->getNrorg();
        $composicoesAux = $this->getCodigoComposicaoArray($composicoes);
        $composicoesAux = implode(",", $composicoesAux);
        return $this->propostaFactory->getElementosComposicaoSemCodigoComposicao($escopos, $composicoesAux, $nrorg, $idApareceProposta, $nrmoeda);
    }
    
    public function getElementosComposicaoSemCodigoComposicaoContrRenegociado(array $escopos, $composicoes, $nrorg = null, $idApareceProposta = null, $nrmoeda = null, $nrseqcontrato) {
        $escopos = implode(",", $escopos);
        $nrorg = $nrorg ? $nrorg : $this->environment->getNrorg();
        $composicoesAux = $this->getCodigoComposicaoArray($composicoes);
        $composicoesAux = implode(",", $composicoesAux);
        return $this->propostaFactory->getElementosComposicaoSemCodigoComposicaoContrRenegociado($escopos, $composicoesAux, $nrorg, $idApareceProposta, $nrmoeda, $nrseqcontrato);
    }

    /**
     * Preenche a coluna IDESCOLHIDO como "S" para os elementos da composição escolhidos.
     * 
     * @param mixed[] $dataset
     * @param integer[] $escolhidos
     * 
     * @return mixed[]
     */
    public function preencherIdEscolhido(array $dataset, array $escolhidos) {
        $codEscolhidos = array();
        foreach ($escolhidos as $esc) {
            if (!in_array($esc["IDELEMENTO"], $codEscolhidos))
                $codEscolhidos[] = $esc["IDELEMENTO"];
        }
        
        foreach ($dataset as &$linha) {
            $linha["IDESCOLHIDO"] = (in_array($linha["IDELEMENTO"], $codEscolhidos)) ? "S": "N";
        }
        unset($linha);
        
        return $dataset;
    }
    
    /**
     * Preenche a coluna IDESCOLHIDO como "S" para os elementos da composição escolhidos.
     * 
     * @param mixed[] $dataset
     * @param integer[] $escolhidos
     * 
     * @return mixed[]
     */
    public function preencherIdEscolhidoComComposicao(array $dataset, array $escolhidos) {
        foreach ($dataset as &$linha) {
            foreach ($escolhidos as $esc) {
                if ($linha["IDELEMENTO"] == $esc["IDELEMENTO"] && $linha["NRCOMPSERVICO"] == $esc["NRCOMPSERVICO"]) {
                    $linha["IDESCOLHIDO"] = "S";
                    break;
                } else {
                    $linha["IDESCOLHIDO"] = "N";
                }
            }
        }
        unset($linha);
        return $dataset;
    }
    
    /**
     * Insere a Composição da Proposta.
     * 
     * @param integer[] $dataset
     * @param integer   $nrseqorcamento
     */
    public function inserirElementosProposta(array $dataset, $nrseqorcamento) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        foreach ($dataset as $row) {
            $nrtrabservorca = $this->newCode->getCodeByTableName("FCT_TRABSERVORCAMENTO", $nrorg, 1, 10, true);
            $valorTotal = $row["VRPRECO"];
            $params = array(
                "NRTRABSERVORCA"    => $nrtrabservorca,
                "NRSEQORCAMENTO"    => $nrseqorcamento,
                "NRTIPOORCAMENTO"   => $row["NRTIPOORCAMENTO"],
                "NRCOMPSERVICO"     => isset($row["NRCOMPSERVICO"]) ? $row["NRCOMPSERVICO"] : null,
                "NRITCOMPSERVICO"   => isset($row["NRCOMPSERVICO"]) ? $row["NRCOMPSERVICO"] : null,
                "IDELEMENTO"        => $row["IDELEMENTO"],
                "IDELEMENTOPAI"     => $row["IDELEMENTOPAI"],
                "IDTIPOELEMENTO"    => $row["IDTIPOELEMENTO"],
                "IDESCOLHIDO"       => $row["IDESCOLHIDO"],
                "CDSERVORCA"        => $row["CDSERVORCARELAC"],
                "QTSERVORCA"        => 1,
                "CDTPMEDIDASERV"    => $row["CDTPMEDIDAVARIAVEL"],
                "QTMEDSERVORCA"     => $row["QTMEDIDASERV"],
                "VRUNITSERVORCA"    => (float)$row["VRPRECO"],
                "VRTOTSERVORCA"     => (float)$row["VRPRECO"] * $row["QTMEDIDASERV"],//$valorTotal,
                "IDATIVO"           => "S",
                "NRORG"             => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "NRORGINCLUSAO"     => $nrorg,
                "IDSERVOBRIGCOMP"   => $row["IDSERVOBRIGCOMP"],
                "QTMEDIDAVARIAVEL"  => $row["QTMEDIDAVARIAVEL"],
                "QTMEDIDACALC"      => $row["QTMEDIDASERV"],
                "VRTOTSAJUSTE"      => (float)$row["VRPRECO"] * $row["QTMEDIDASERV"],
                "IDAPARECEPROPOSTA" => isset($row["IDAPARECEPROPOSTA"]) ? $row["IDAPARECEPROPOSTA"] : "S",
                "CDCENTCUST"        => isset($row["CDCENTCUST"]) ? $row["CDCENTCUST"] : null 
            );
            $this->propostaFactory->inserirElementosProposta($params);
        }
    
        
    }
    
    /**
     * Insere os Itens da Proposta.
     * 
     * @param integer[] $dataset
     */
    public function inserirItensProposta(array $dataset, $nrseqorcamento, $itensServOrca) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $arrayItensPai = array();
        
        $proposta = $this->getDadosPropostaParaItens($nrseqorcamento, $nrorg);
        foreach ($dataset as &$row) {
            if(count($itensServOrca) == 0 || array_key_exists((string)$row["CDSERVORCA"], $itensServOrca)){
                $nritemorcamento = $this->newCode->getCodeByTableName("NRITEMORCAMENTO", $nrorg, 1, 10, true);
                $arrayItensPai[(string)$row["CDSERVORCA"]] = $nritemorcamento;
    
                $idfaturaorca          = (!isset($row["IDELEMENTO"]))? $row["IDFATURACONTR"] : null;
                $cdmodpgto             = (!isset($row["IDELEMENTO"]))? $row["CDMODPGTO"] : null;
                $nrgrupofatura         = (!isset($row["IDELEMENTO"]))? $row["NRGRUPOFATURA"] : null;
                $qtParcelasFatu        = (!isset($row["IDELEMENTO"]))? $row["QTPARCELASFATU"] : null;
                $nrdiavencparcelasfatu = (!isset($row["IDELEMENTO"]))? $row["NRDIAVENCPARCELASFATU"] : null;
                
                $vrpercdescorca = isset($row["VRPERCDESCORCA"]) ? $row["VRPERCDESCORCA"] : 0;
                $idtpdescorca   = isset($row["IDTPDESCORCA"]) ? $row["IDTPDESCORCA"] : "N";
                if($row["IDTIPO"] == "I") {
                    $row["VRUNITITEMORCA"] = $row["VRTOTALITEMORCA"];
                } else {
                    if (is_string($row["VRUNITITEMORCA"])) {
                        if (strpos($row["VRUNITITEMORCA"], ',') !== false) {
                            $row["VRUNITITEMORCA"] = (float)str_replace(",", ".", str_replace(".", "", $row["VRUNITITEMORCA"]));
                        }
                        else {
                            $row["VRUNITITEMORCA"] = (float)$row["VRUNITITEMORCA"];
                        }
                    }
                    if (is_string($row["QTMEDIDASERV"])) {
                        if (strpos($row["QTMEDIDASERV"], ',') !== false) {
                            $row["QTMEDIDASERV"] = (float)str_replace(",", ".", str_replace(".", "", $row["QTMEDIDASERV"]));
                        }
                        else {
                            $row["QTMEDIDASERV"] = (float)$row["QTMEDIDASERV"];
                        }
                    }
                }
                
                $vritemsemdesc = $row["QTITEMORCAMENTO"] * $row["VRUNITITEMORCA"];
                if ($row["QTMEDIDASERV"] != null && $row["QTMEDIDASERV"] != 0) {
                    $vritemsemdesc = $vritemsemdesc * (float)$row["QTMEDIDASERV"];
                }
                
                if ($idfaturaorca == null && !isset($row["IDELEMENTO"])) {
                    $idfaturaorca          = $proposta["IDFATURAORCA"];
                    $cdmodpgto             = $proposta["CDMODPGTO"];
                    $nrgrupofatura         = $proposta["NRGRUPOFATURA"];
                    $qtParcelasFatu        = $proposta["QTPARCELASFATU"];
                    $nrdiavencparcelasfatu = $proposta["NRDIAVENCPARCELASFATU"];
                }

                $params = array(
                    "NRITEMORCAMENTO"       => $nritemorcamento,
                    "NRSEQORCAMENTO"        => $nrseqorcamento,
                    "CDSERVORCA"            => $row["CDSERVORCA"],
                    "NMITEMORCAMENTO"       => !empty($row["NMDOCITEMORCAMENTO"]) ? $row["NMDOCITEMORCAMENTO"] : $row["NMSERVORCA"],
                    "DSQTITEMORCA"          => "Referente ao Produto",
                    "QTITEMORCAMENTO"       => $row["QTITEMORCAMENTO"],
                    "CDTPMEDIDASERV"        => $row["CDTPMEDIDASERV"],
                    "QTMEDIDAORCA"          => $row["QTMEDIDASERV"],
                    "QTMEDIDACALCULADA"     => !empty($row["QTMEDIDACALCULADA"]) ? $row["QTMEDIDACALCULADA"] : $row["QTMEDIDASERV"],
                    "VRUNITITEMORCA"        => (float)$row["VRUNITITEMORCA"],
                    "VRUNITITEMORCATBLPRECO"=> isset($row["VRUNITITEMORCATBLPRECO"]) ? $row["VRUNITITEMORCATBLPRECO"] : (float)$row["VRUNITITEMORCA"],
                    "VRTOTALITEMORCA"       => $row["VRTOTALITEMORCA"],
                    "IDITEMOBRIGORCA"       => "N",
                    "IDSOMASUBITENS"        => "N",
                    "IDSOMANOITEMPAI"       => "S",
                    "IDSOMANOTOTALORCA"     => "S",
                    "IDIMPRESSAOORCA"       => isset($row["IDIMPRESSAOORCA"]) ? $row["IDIMPRESSAOORCA"] : "S",
                    "IDPRECOLOCACAO"        => "PROPORCIONAL_TEMPO",
                    "IDMULTMEDVRTOT"        => "S",
                    "IDBLOQALTORC"          => "N",
                    "IDADICITEMORC"         => "N",
                    "IDADICCOBRITEMORC"     => "N",
                    "IDTPDESCORCA"          => $idtpdescorca,
                    "IDTRANSPORTADORA"      => "PROPRIA",
                    "IDATIVO"               => "S",
                    "NRORG"                 => $nrorg,
                    "CDOPERINCLUSAO"        => $cdoperador,
                    "NRORGINCLUSAO"         => $nrorg,
                    "NRTIPOORCAMENTO"       => $row["NRTIPOORCAMENTO"],
                    "IDFATURAORCA"          => $idfaturaorca,
                    "CDMODPGTO"             => $cdmodpgto,
                    "NRGRUPOFATURA"         => $nrgrupofatura,
                    "QTPARCELASFATU"        => $qtParcelasFatu,
                    "NRDIAVENCPARCELASFATU" => $nrdiavencparcelasfatu,
                    "VRPERCDESCORCA"        => $vrpercdescorca,
                    "VRITEMSEMDESC"         => $vritemsemdesc,
                    "IDELEMENTO"            => $row["IDELEMENTO"],
                    "CDTPMEDIDAVARIAVEL"    => $row["CDTPMEDIDAVARIAVEL"],
                    "NRITEMORCAMENTOPAI"    => (array_key_exists((string)$row["CDSERVORCA"], $itensServOrca)) ? $itensServOrca[$row["CDSERVORCA"]] : null,
                    "IDMEDIDAFIXA"          => $row["IDMEDIDAFIXA"],
                    "NMCONTRATUALITEMORCA"  => isset($row["NMCONTRATUALITEMORCA"]) ? $row["NMCONTRATUALITEMORCA"] : $row["NMSERVORCA"],
                    "VRDESCORCA"            => isset($row["VRDESCORCA"]) ? $row["VRDESCORCA"] : 0,
                    "TXFORMULAITORCA"       => isset($row["TXFORMULAITORCA"]) ? $row["TXFORMULAITORCA"] : null,
                    "CDOPERULTATU"          => (isset($row["changed"]) && $row["changed"]) ? $cdoperador : null,
                    "NRORGULTATU"           => (isset($row["changed"]) && $row["changed"]) ? $nrorg : null,
                    "DTULTATU"              => (isset($row["changed"]) && $row["changed"]) ? (string) date('d/m/Y H:i') : null,
                    "IDAPARECEPROPOSTA"     => isset($row["IDAPARECEPROPOSTA"]) ? $row["IDAPARECEPROPOSTA"] : "S",
                    "NRMOEDA"               => $proposta["NRMOEDA"]
                );

                $this->propostaFactory->inserirItensProposta($params);
            }
        }
        unset($row);
        return $arrayItensPai;
    }
    
    /**
     * Retorna o código das propostas filhas da proposta de código informado.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     * 
     * @return mixed[]
     */
    public function getCodigoPropostasFilhas($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTOPAI" => $nrseqorcamento,
            "NRORG" => $nrorg
        );
        $dataset = $this->propostaFactory->getPropostasFilhas($params);
        if (count($dataset) > 0) {
            $propostas = array();
            foreach ($dataset as $linha) {
                $propostas[] = $linha["NRSEQORCAMENTO"];
            }
            return $propostas;
        }
        else {
            return null;
        }
    }
    
    /**
     * Atualiza a situação das propostas informadas.
     * 
     * @param string    $situacao
     * @param integer[] $nrseqorcamento
     * @param integer   $nrorg
     */
    public function atualizarSituacaoPropostas($situacao, array $nrseqorcamento, $nrorg) {
        $nrseqorcamento = implode(",", $nrseqorcamento);
        $this->propostaFactory->atualizarSituacaoPropostas($situacao, $nrseqorcamento, $nrorg);
        //$this->atualizaDocumentoSituacao($nrseqorcamento, $nrorg, $situacao);
    }
    
    /**
     * Atualiza a Proposta ao aceitá-la.
     * 
     * @param integer $nrseqorcamento
     * @param string  $dataAceite
     * @param integer $nrorg
     */
    public function atualizarPropostaAceite($nrseqorcamento, $dataAtual, $nrorg,  $cdoperador, $dataAceite = null) {
        $params = array(
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "IDSITUACAOORCAMENTO" => "ACEITO",
            "DTACEITEORCA"        => (!$dataAceite) ? $dataAtual : $dataAceite,
            "NRORG"               => $nrorg,
            "CDOPERULTATU"        => $cdoperador
        );
        
        $this->propostaFactory->atualizarPropostaAceite($params);
        //$this->atualizaDocumentoSituacao($nrseqorcamento, $nrorg, "ACEITO");
    }
     /**
     * Retorna os dados que irar compor o assunto e corpo do email  
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getCorpoParaEmailProposta($nrseqorcamento, $nrorg) {
    
        $params = array(
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "NRORG"               => $nrorg
        );
        
       $dados =  $this->propostaFactory->getCorpoParaEmailProposta($params);
        return $dados;
    }
    
    /**
     * Executa a procedure GERA_CONTRATO.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     * 
     * @return integer
     */
    public function executarProcedureGeraContrato($nrseqorcamento, $nrorg) {
        $procedure = new FctGeraContrato($this->connection);
        $cdoperador = $this->environment->getCdOperador();
        $nrseqcontrato = $procedure->executar($nrorg, $nrseqorcamento,$cdoperador);
        return $nrseqcontrato;
    }
    
    /**
     * 
     */
    public function excluirRelacionamentoEstruturaAprop($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirRelacionamentoEstruturaAprop($params);
    }
    
    /**
     * Executa a procedure FCT_GERA_PROPOSTAS_FILHAS.
     * 
     * @param integer $nrseqorcamento
     * @param string  $cdoperador
     * @param integer $nrorg
     */
    public function gerarPropostasFilhas($nrseqorcamento, $cdoperador, $nrorg) {
        $procedure = new FctGeraPropostasFilhas($this->connection);
        $procedure->executar($nrseqorcamento, $cdoperador, $nrorg);
    }
    
    /**
     * Executa a procedure FCT_SUB_MNE_DOC.
     * 
     * @param integer $nrseqorcamento
     * @param string  $nrseqorcadoc
     * @param integer $nrorg
     * @param string  $idtipodoc
     * @param string  $submnedoc
     */
    public function executarProcedureFctSubMneDoc($nrseqorcamento, $nrseqorcadoc, $nrorg, $idtipodoc, $submnedoc) {
        $procedure = new FctSubMneDoc($this->connection);
        $procedure->executar($nrseqorcamento, $nrseqorcadoc, $nrorg, $idtipodoc, $submnedoc);
    }
    
    /**
     * Retorna os documentos da Proposta.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getDocumentosProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getDocumentosProposta($params);
    }
    
    /**
     * Retorna o e-mail do Vendedor da Proposta informada.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getEmailVendedorProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $dataset = $this->propostaFactory->getEmailVendedorProposta($params);

        return $dataset;
    }
    /**
     * Retorna os daedos de e-mail da Parametrização SM
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getEmailParametrizado($nrorg, $cdfilial) {
        $params = array(
            "NRORG"     => $nrorg,
            "CDFILIAL"  => $cdfilial
        );
        
        $dados = $this->propostaFactory->getEmailParametrizado($params);
        return $dados;
    }
    
    /**
     * Retorna o e-mail da Empresa da Proposta informada.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getEmailEmpresaProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getEmailEmpresaProposta($params);
        
        return (count($dataset) > 0) ? $dataset[0]["DSEMAILEMPRESA"] : null;
    }
    
   
    /**
     * Retorna o e-mail do Interlocutor da Proposta informada.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getEmailInterlocutorProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getEmailInterlocutorProposta($params);
        
        return (count($dataset) > 0) ? $dataset[0]["DSEMAIL"] : null;
    }
    
    /**
     * Executa a procedure FCT_CONVERSAO_CLIENTE.
     * 
     * @param integer $nrorg
     * @param string  $operador
     * @param integer $nrparcnegocio
     */
    public function executarProcedureFctConversaoCliente($nrorg, $operador, $nrparcnegocio) {
        $procedure = new FctConversaoCliente($this->connection);
        $procedure->executar($nrorg, $operador, $nrparcnegocio);
    }
    /**
     * Valida se os modelos de propostas e contratos possuem restrição de perfil de acesso 
     * e caso haja retorna apenas os que o operador logado pode acessas.
    **/
    public function validarPerfilAcesso($nrparcnegocio, $nrorg, $propostaoucontrato) {
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG"         => $nrorg
        );
        $paramPerfilModelo = false;
        $paramPerfilOperador = $this->propostaFactory->getPerfisOperador($params);
        $perfis = "";
        foreach ($paramPerfilOperador as $operador) 
           $perfis = $perfis . "," . $operador["NRPERFILACESSO"];
        
        
        $perfis = substr($perfis, 1);
        $params = array (
            "NRORG" => $nrorg
        );

        if($propostaoucontrato == 'P') 
            $paramPerfilModelo = $this->propostaFactory->getPerfisParamModelo($params, $perfis);
        else if($propostaoucontrato == 'C')
            $paramPerfilModelo = $this->propostaFactory->getPerfisParamContrato($params, $perfis);

        return ($paramPerfilModelo) ? $paramPerfilModelo : false;
    }
    
    /**
     * Exclui os itens da proposta.
     */
    public function excluirItensProposta($nrseqorcamento) {
        $nrorg =  $this->environment->getNrOrg();
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirItensProposta($params);
    }
    
    /**
     * Atualiza o valor total da proposta com a soma dos itens.
     */
    public function atualizarValorProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $valor = $this->propostaFactory->getSomaValorNegociacoesProposta($params);
        $valor = $valor[0]["VRTOTITEMCOMDESC"];
        
        $params["VRORCAMENTO"] = $valor;
        $this->propostaFactory->atualizarValorProposta($params);
        
        return $valor;
    }
    
    /**
     * Insere os elementos, tipo de medida variável e itens da proposta.
     */
    public function inserirTudo($nrseqorcamento, $escopos, $nrorcamentomodelo, $medidas, $itens, $idSituacao = null, $interlocutor = null) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        $arrayItensPai = array();
        $this->connection->beginTransaction();
        try {

            $medidas = $this->vincularEscopoAoTipoDeMedida($medidas, $itens, $escopos);
            $this->inserirTipoDeMedidaProposta($medidas, $nrseqorcamento);
            
            $elementos = $this->session->get("inserir_elementos_proposta");
            if (!empty($elementos)) {
                $this->inserirElementosProposta($elementos, $nrseqorcamento);
            }
            
            $composicoes = $this->session->get("inserir_composicoes_proposta");
            if (!empty($composicoes)) {
                $this->inserirComposicoesProposta($composicoes, $nrseqorcamento);
            }
            
            $servicosVariaveis = $this->session->get("inserir_medidas_variaveis_servicos");
            foreach ($servicosVariaveis as &$row) {
                $row["NRSEQORCAMENTO"] = $nrseqorcamento;
                $row["QTMEDIDAORCA"]   = $this->getQuantidadeMedidaServico($row["CDSERVORCA"], $row["CDTPMEDIDAVARIAVEL"], $row["QTMEDIDAORCA"], $itens);
                $this->inserirOuAtualizarMedidaVariavelServico($row, $nrorg, $cdoperador);
            }
            unset($row);

            $itensElemento = $this->session->get("inserir_itens_tipo_elementos_proposta");
            $itensElemento = $this->setAlteracoesItensTipoElemento($itensElemento, $itens);
            
            $itens         = $this->getItensTipoIParaInserir($itens);
            $arrayItensPai = $this->inserirItensProposta($itens, $nrseqorcamento, array());
            
            $this->inserirItensProposta($itensElemento, $nrseqorcamento, $arrayItensPai);
            
            // Tratamento para inserir na proposta os elementos, itens e medidas dos itens de composição que são invisíveis na proposta
            $this->inserirDadosDosElementosInvisiveisNaProposta($escopos, $composicoes, $nrseqorcamento, $arrayItensPai, $medidas, $nrorg);
            
            $this->inserirNegociacaoProposta($escopos, $nrorcamentomodelo, $itens, $nrseqorcamento, $nrorg);
            
            $this->atualizarValorProposta($nrseqorcamento, $nrorg);

            $this->session->set("inserir_itens_tipo_elementos_proposta", "");
            $this->session->set("inserir_elementos_proposta", "");
            $this->session->set("inserir_composicoes_proposta", "");
            $this->session->set("inserir_medidas_variaveis_servicos", "");
            
            $this->inserirAssinaturasOrca($nrorcamentomodelo, $nrseqorcamento, $interlocutor, $nrorg, $cdoperador);
            
            $this->connection->commit();
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            
            if($idSituacao == null)
                $this->excluirProposta($nrseqorcamento, $nrorg);
            
            throw $e;
        }
    }
    /**
     * Seta todas as altererações realizadas nos elementos que 
     * serão inseridos na tabela de itens
    **/
    public function setAlteracoesItensTipoElemento($itensElemento, $itens){
        foreach($itens as $itemTela){
            if($itemTela["IDTIPO"] == "M"){
                foreach($itensElemento as &$itemElemento){
                    if($itemElemento["IDARVORE"] == $itemTela["IDARVORE"]){
                        $itemElemento["NMCONTRATUALITEMORCA"] = $itemTela["NMCONTRATUALITEMORCA"];
                        $itemElemento["QTMEDIDASERV"]         = $itemTela["QTMEDIDASERV"];
                        $itemElemento["VRUNITITEMORCA"]       = $itemTela["VRUNITITEMORCA"];
                        $itemElemento["VRTOTALITEMORCA"]      = $itemTela["VRTOTALITEMORCA"];
                        $itemElemento["changed"]              = $itemTela["changed"];
                        
                        break;
                    }
                }
            }
        }
        unset($itemElemento);
        
        return $itensElemento;
    }
    /**
     * Insere os tipos de medida variáveis da proposta.
     */
    public function inserirTipoDeMedidaProposta($rows, $nrseqorcamento, $idApareceProposta = "S") {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        foreach ($rows as $row) {
            $novoCodigo = $this->newCode->getCodeByTableName("FCT_RELACMEDIDAPROPOSTA", $nrorg, 1, 10, true);
            $params = array(
                "NRRELACMEDIDAPROPOSTA" => $novoCodigo,
                "NRSEQORCAMENTO"        => $nrseqorcamento,
                "CDTPMEDIDAVARIAVEL"    => $row["CDTPMEDIDASERV"],
                "QTMEDIDAVARIAVEL"      => $row["QUANTIDADE"],
                "NRORG"                 => $nrorg,
                "NRORGINCLUSAO"         => $nrorg,
                "CDOPERINCLUSAO"        => $cdoperador,
                "IDATIVO"               => "S",
                "IDELEMENTORAIZ"        => $row["IDELEMENTORAIZ"],
                "QTFRANQUIA"            => $row["QTFRANQUIA"],
                "NRTIPOORCAMENTO"       => array_key_exists("NRTIPOORCAMENTO", $row) ? $row["NRTIPOORCAMENTO"] : null,
                "IDAPARECEPROPOSTA"     => $idApareceProposta
            );
            
            $this->propostaFactory->inserirTipoDeMedidaProposta($params);
        }
    }
    
    /**
     * Exclui a proposta.
     */
    public function excluirProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirProposta($params);
    }

    public function validaOrcamentoValidos($nrorcamentomodelo, $nrorg) {
        $params = array(
            "NRORCAMENTOMODELO" => $nrorcamentomodelo,
            "NRORG"          => $nrorg
        );

        return $this->propostaFactory->validaOrcamentoValidos($params);
    }
    
    /**
     * Exclui os escopos da proposta.
     */
    public function excluirEscopos($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirEscopos($params);
    }
    /**
     * Valida os elementos que compõe o item da proposta
    **/
    public function validarItensOrcamento($elementos, $elementosEscolhidos, $variacoesPreco, $medidas, $break = true) {
        $novosElementos = array();
        foreach ($elementos as $key=>$elemento) {
            $elemento = $this->atualizarValoresElementosComposicao($variacoesPreco, $elemento, $medidas);
            foreach ($elementosEscolhidos as $escolhido) {
                if ($elemento["IDELEMENTO"] == $escolhido["IDELEMENTO"]) {
                    $elemento["IDESCOLHIDO"] = "S";
                    if (isset($escolhido["CDCENTCUST"]) && !empty($escolhido["CDCENTCUST"]) &&
                    (isset($elemento["NRCOMPSERVICO"]) && $elemento["NRCOMPSERVICO"] == $escolhido["NRCOMPSERVICO"])) {
                        $elemento["CDCENTCUST"] = $escolhido["CDCENTCUST"];
                    }
                    if ($break) break;
                }
            }
            $novosElementos[$key] = $elemento;
       } 
       return $novosElementos;
    }
    
    /**
     * Retorna os itens da proposta já com os preços corretos para exibir no momento de inserção.
     * 
     * @param mixed[] $proposta - Array de coluna => valor da proposta que está sendo salva
     * @param mixed[] $elementos - Array com todos os elementos da proposta
     * @param mixed[] $codElementosEscolhidos - Array com o código dos elementos que foram escolhidos
     * @param mixed[] $composicoes - Array com as composições de serviço da proposta
     * @param mixed[] $medidas - Array com todas as medidas variáveis da proposta
     * 
     * @return mixed[]
     */
    public function getItensPropostaParaInserir($propostaOuContrato, $elementosEscolhidos, $composicoes, $medidas, $codServicosNaoConsiderados = null, $contratoRenegociado = "N") {
        $nrorg = $this->environment->getNrOrg();

        $escopos = $propostaOuContrato["NRTIPOORCAMENTO"];
        if (!is_array($escopos)) 
            $escopos = array($escopos);
        
        $buscaSomenteElementosVisiveis = isset($propostaOuContrato["NRSEQCONTRATO"]) ? null : "S";
        
        $nrmoeda = isset($propostaOuContrato["NRMOEDA"]) ? $propostaOuContrato["NRMOEDA"] : null;

        if ($contratoRenegociado == "N") {
            $elementos = $this->getElementosComposicao($escopos, $composicoes, $buscaSomenteElementosVisiveis, $nrmoeda);
        }
        else {
            $elementos = $this->getElementosComposicaoContrRenegociado($escopos, $composicoes, $propostaOuContrato["NRSEQCONTRATOPAI"], $buscaSomenteElementosVisiveis, $nrmoeda);  
        }

        $variacoesPreco = $this->getVariacoesPreco($escopos, $nrorg, $medidas, $nrmoeda);
        $elementos      = $this->validarItensOrcamento($elementos, $elementosEscolhidos, $variacoesPreco, $medidas, false);
        
    
        $existePrecoVencido = $this->validarDataValidadePrecoServico($elementos);
        if ($existePrecoVencido) {
            throw new \Exception("Operação bloqueada.<br/><br/>Existem serviços utilizando tabela de preço fora da data de validade.");
        }
        
        $this->session->set("inserir_elementos_proposta", $elementos);
        $this->session->set("inserir_composicoes_proposta", $composicoes);

        if ($contratoRenegociado == "N") {
            $elementosSemCodComposicao = $this->getElementosComposicaoSemCodigoComposicao($escopos, $composicoes, $nrorg, $buscaSomenteElementosVisiveis, $nrmoeda);
        }
        else {
            $elementosSemCodComposicao = $this->getElementosComposicaoSemCodigoComposicaoContrRenegociado($escopos, $composicoes, $nrorg, $buscaSomenteElementosVisiveis, $nrmoeda, $propostaOuContrato["NRSEQCONTRATO"]);
        }

        $elementosSemCodComposicao = $this->eliminarElementosDuplicados($elementosSemCodComposicao);
        $elementosSemCodComposicao = $this->validarItensOrcamento($elementosSemCodComposicao, $elementosEscolhidos, $variacoesPreco, $medidas, true);
        $itensMedida = array();
        
        $servicos = $this->getServicos($elementosSemCodComposicao);
        $servicos = $this->setValoresGridServicos($servicos);
        
        $itensMedida = $this->getItensMedida($elementosSemCodComposicao, $nrorg);
        $itensMedida = $this->setValoresGridItensMedida($itensMedida);
        $this->session->set("inserir_itens_tipo_elementos_proposta", $itensMedida);
        
        $servicosVariaveis = $this->getServicosComMedidaVariavel($itensMedida, $nrorg);
        $this->session->set("inserir_medidas_variaveis_servicos", $servicosVariaveis);
        
        $arrItens = array_merge($servicos, $itensMedida);
        
        if (is_array($codServicosNaoConsiderados) && count($codServicosNaoConsiderados) > 0) {
            foreach ($arrItens as $key => $value) {
                if (in_array($value["CDSERVORCA"], $codServicosNaoConsiderados)) {
                    unset($arrItens[$key]);
                }
            }
            $arrItens = array_values($arrItens);
        }
        
        return $arrItens;
    }
    
    public function getServicosComMedidaVariavel(array $itensMedida, $nrorg) {
        $itensRelacMedidaProposta = array();
        foreach ($itensMedida as $item) {
            if (isset($item["CDTPMEDVARESCOPO"]) && !is_null($item["CDTPMEDVARESCOPO"])) {
                $cdservorca = (int)$item["CDSERVORCA"];
                if (array_key_exists($cdservorca, $itensRelacMedidaProposta)) {
                    $itensRelacMedidaProposta[$cdservorca]["QTMEDIDAORCA"] += $item["QTMEDIDASERV"];
                }
                else {
                    $itensRelacMedidaProposta[$cdservorca] = array(
                        "NRSEQORCAMENTO"     => null,
                        "CDTPMEDIDAVARIAVEL" => $item["CDTPMEDVARESCOPO"],
                        "CDSERVORCA"         => $item["CDSERVORCA"],
                        "QTMEDIDAORCA"       => $item["QTMEDIDASERV"],
                        "NRTIPOORCAMENTO"    => $item["NRTIPOORCAMENTO"],
                        "NRORG"              => $nrorg
                    );
                }
            }
        }
        
        return $itensRelacMedidaProposta;
    }
    
    /**
     * Cria um item contendo o somatório das informações do array de elementos
    **/
    public function getItensMedida($elementosSemCodComposicao, $nrorg) {
        $elementosRaiz = array();
        foreach ($elementosSemCodComposicao as $elemento) {
            if ($elemento["IDESCOLHIDO"] == "S" && !in_array($elemento["IDELEMENTORAIZ"], $elementosRaiz)) {
                $elementosRaiz[] = $elemento["IDELEMENTORAIZ"];
            }
        }
        
        $itensMedida = array();
        foreach ($elementosSemCodComposicao as $elemento) {
            
            if ($elemento["IDESCOLHIDO"] == "S" && $elemento["CDSERVORCARELAC"] != null) {
                
                $chave = $elemento["IDELEMENTORAIZ"] . "_" . $elemento["CDSERVORCARELAC"] . "_" . $elemento["NRTIPOORCAMENTO"]. "_". $elemento["CDTPMEDIDAVARIAVEL"];
                $qtmedidaserv = $elemento["QTMEDIDASERV"];
                
                if (array_key_exists($chave, $itensMedida)) {
                    if ($elemento["IDMULTIPVARIACAO"] == "S" && $elemento["IDMEDIDAFIXA"] == "N" && $elemento["IDPREVCOBRFUT"] == "N") {
                        $itensMedida[$chave]["VRUNITITEMORCA"] += $elemento["VRPRECO"];
                    }
                    else {
                        $itensMedida[$chave]["QTMEDIDASERV"]     += $qtmedidaserv;
                        $itensMedida[$chave]["QTMEDIDAVARIAVEL"] += $qtmedidaserv;
                        $itensMedida[$chave]["QTMEDIDACALC"]     += $qtmedidaserv;
                    }
                }
                else {
                    $itensMedida[$chave] = array(
                        "IDARVORE"              => $elemento["IDELEMENTORAIZ"] . "_" . $elemento["CDTPMEDIDAVARIAVEL"] . "_" . $elemento["CDSERVORCARELAC"] . "_" . $elemento["NRTIPOORCAMENTO"],
                        "IDARVOREPAI"           => $elemento["CDSERVORCARELAC"] . "_" . $elemento["NRTIPOORCAMENTO"],
                        "IDTIPO"                => "M",
                        "CDSERVORCA"            => $elemento["CDSERVORCARELAC"],
                        "NMSERVORCA"            => $elemento["NMELEMENTORAIZ"],
                        "QTITEMORCAMENTO"       => 1,
                        "CDTPMEDIDASERV"        => $elemento["CDTPMEDIDASERV"],
                        "QTMEDIDASERV"          => $qtmedidaserv,
                        "QTMEDIDASERV_GRID"     => $qtmedidaserv,
                        "QTMEDIDAVARIAVEL"      => $qtmedidaserv,
                        "QTMEDIDACALC"          => $qtmedidaserv,
                        "DSTPMEDIDASERV"        => $elemento["DSTPMEDIDASERV"],
                        "VRUNITITEMORCA"        => $elemento["VRPRECO"],
                        "VRUNITITEMORCA_GRID"   => $elemento["VRPRECO"],
                        //"VRTOTALITEMORCA"       => $valor * $qtmedidaserv,
                        "NRTIPOORCAMENTO"       => $elemento["NRTIPOORCAMENTO"],
                        "NMTIPOORCAMENTO"       => null,
                        "IDFATURACONTR"         => null,
                        "CDMODPGTO"             => null,
                        "NRGRUPOFATURA"         => null,
                        "NRORG"                 => $nrorg,
                        "QTPARCELASFATU"        => null,
                        "NRDIAVENCPARCELASFATU" => null,
                        "CDTPMEDIDAVARIAVEL"    => $elemento["CDTPMEDIDAVARIAVEL"],
                        "IDMULTIPVARIACAO"      => $elemento["IDMULTIPVARIACAO"],
                        "IDTIPOELEMENTO"        => $elemento["IDTIPOELEMENTO"],
                        "IDALTQTDMEDIDAPROP"    => $elemento["IDALTQTDMEDIDAPROP"],
                        "IDELEMENTO"            => $elemento["IDELEMENTORAIZ"],
                        "IDMEDIDAFIXA"          => $elemento["IDMEDIDAFIXA"],
                        "NMCONTRATUALITEMORCA"  => $elemento["NMELEMENTORAIZ"],
                        "VRPERCDESCORCA"        => 0,
                        "QTMEDIDACALCULADA"     => 0,
                        "VRDESCORCA"            => 0,
                        "IDTPDESCORCA"          => 'N',
                        "IDMULTMEDVRTOT"        => 'S',
                        "changed"               => false,
                        "CDTPMEDVARESCOPO"   => isset($elemento["CDTPMEDVARESCOPO"]) ? $elemento["CDTPMEDVARESCOPO"] : null,
                        "DSTPMEDVARESCOPO"   => isset($elemento["DSTPMEDVARESCOPO"]) ? $elemento["DSTPMEDVARESCOPO"] : null
                    );
                }
            }
        }

        foreach ($itensMedida as &$item) {
            $item["VRUNITITEMORCATBLPRECO"] = $item["VRUNITITEMORCA"];
            $item["VRTOTALITEMORCA"]        = $item["VRUNITITEMORCA"] * $item["QTMEDIDASERV"];
            $item["VRITEMSEMDESC"]          = $item["VRTOTALITEMORCA"];
            $item["QTMEDIDACALCULADA"]      = $item["QTMEDIDASERV"];
            $item["VRUNITITEMORCA_GRID"]    = number_format($item["VRUNITITEMORCA"], 4, ",", ".");
            $item["QTMEDIDASERV_GRID"]      = number_format($item["QTMEDIDASERV"], 2, ",", ".");
        }
        
        unset($item);
    	ksort($itensMedida);
    	return array_values($itensMedida);
    }
    
    /**
     * Filtra as variações para trazer somente aquelas que batem com as medidas informadas.
     * 
     * @param mixed[] $medidas
     * @param mixed[] $variacoesPreco
     */
    public function filtrarVariacoesPreco(array $medidas, array $variacoesPreco) {
        $arr = array();
        foreach ($medidas as $medida) {
            $cdtpmedidaserv   = $medida["CDTPMEDIDASERV"];
            $quantidade       = $medida["QUANTIDADE"];
            $idElementoRaiz   = $medida["IDELEMENTORAIZ"];
            $nomeElementoRaiz = $medida["NMELEMENTORAIZ"];
            foreach ($variacoesPreco as $variacao) {
                if ( ($variacao["CDTPMEDIDAVARIAVEL"] == $cdtpmedidaserv) && 
                    (($quantidade >= $variacao["QTMEDIDAINIVARIACAO"] && $quantidade <= $variacao["QTMEDIDAFIMVARIACAO"]) || $quantidade == 0) ) {
                    $qtComFranquia =  $quantidade - $medida["QTFRANQUIA"];
                    
                    $variacao["QUANTIDADE"]     = ($qtComFranquia >= 0) ? $qtComFranquia :  0;
                    $variacao["IDELEMENTORAIZ"] = $idElementoRaiz;
                    $variacao["NMELEMENTORAIZ"] = $nomeElementoRaiz;
                    $arr[] = $variacao;
                }
            }
        }
        return $arr;
    }
    
    /**
     * Retorna todas as variações de preço para as tabelas de preço ligadas aos escopos informados.
     * 
     * @param integer[] $escopo
     * @param integer $nrorg
     * 
     * @return mixed[]
     */
    public function getVariacoesPreco(array $escopos, $nrorg, $medidas, $nrmoeda = null) {
        $escopos = implode(",", $escopos);
        $params = array(
            "NRMOEDA" => $nrmoeda,
            "NRORG"   => $nrorg
        );
        $variacoesPreco = $this->propostaFactory->getVariacoesPreco($escopos, $params);
        return $this->filtrarVariacoesPreco($medidas, $variacoesPreco);
    }


    public function getConfiguracoesEmail($nrorg) {

        $params = array(
            "NRORG" => $nrorg
        );

        return $this->propostaFactory->getConfiguracoesEmail($params);
    }
    
    /**
     * Retorna os elementos atualizados com os valores da variação de preço.
     * 
     * @param mixed[] $variacoesPreco - Variações de Preço
     * @param mixed[] $elementos - Elementos da proposta com seus serviços 
     * (o que será inserido na FCT_TRABSERVORCAMENTO)
     * 
     * @return mixed[]
     */
    public function atualizarValoresElementosComposicao(array $variacoesPreco, $item, array $medidas) {
        $newItem = $item;
        foreach ($variacoesPreco as $variacao) {
            if (($item["CDMEDVARIAVELRELAC"] == $variacao["CDTPMEDIDASERV"]) &&
                ($item["CDSERVORCARELAC"]    == $variacao["CDSERVORCA"]) &&
                ($item["CDTPMEDIDAVARIAVEL"] == $variacao["CDTPMEDIDAVARIAVEL"]) &&
                ($item["IDELEMENTORAIZ"]     == $variacao["IDELEMENTORAIZ"])) {
                    
                if ($item["IDPREVCOBRFUT"] == "S") {
                    $vrpreco      = $variacao["VRPRECOVARIACAO"];
                    $qtmedidaserv = 0;
                }
                else if($variacao["IDMULTIPVARIACAO"] == "N") {
                    $vrpreco      = $variacao["VRPRECOVARIACAO"];
                    $qtmedidaserv = $item["QTMEDIDASERV"];
                }
                else {
                    $vrpreco = $variacao["VRPRECOVARIACAO"] * $item["QTMEDIDASERV"] ;
                    foreach ($medidas as $medida) {
                        if($medida["CDTPMEDIDASERV"] == $item["CDTPMEDIDAVARIAVEL"] && $variacao["IDMULTIPVARIACAO"] == 'S' && $medida["IDELEMENTORAIZ"] == $item["IDELEMENTORAIZ"]){
                            $qtFranquia   = ($medida["QTFRANQUIA"]) ? $medida["QTFRANQUIA"] : 0;
                            $qtmedidaserv = $medida["QUANTIDADE"] - $qtFranquia;
                            if($qtmedidaserv < 0)
                                $qtmedidaserv = 0;
                            
                            break;
                        }
                    }
                }
                
                if (isset($item["CDTPMEDVARESCOPO"]) && !is_null($item["CDTPMEDVARESCOPO"])) {
                    $newItem["CDTPMEDIDASERV"] = $item["CDTPMEDVARESCOPO"];
                    $newItem["CDTPMEDIDAVARIAVEL"] = $item["CDTPMEDVARESCOPO"];
                    $newItem["DSTPMEDIDASERV"] = $item["DSTPMEDVARESCOPO"];
                }
                else if ($item["IDMEDIDAFIXA"] == "S") {
                    $newItem["CDTPMEDIDASERV"] = $item["CDMEDVARIAVELRELAC"];
                    $newItem["DSTPMEDIDASERV"] = $item["DSTPMEDIDASERVRELAC"];
                }
                
                $newItem["VRPRECO"]          = $vrpreco;
                $newItem["DTFIMVALPBSERV"]   = $variacao["DTFIMVALPBSERV"];
                $newItem["QTMEDIDASERV"]     = $qtmedidaserv;
                $newItem["QTMEDIDACALC"]     = $qtmedidaserv;
                $newItem["QTMEDIDAVARIAVEL"] = $qtmedidaserv;
                $newItem["IDMULTIPVARIACAO"] = $variacao["IDMULTIPVARIACAO"];
                unset($medida);
                return $newItem;
            }
        }
        
        if (isset($item["CDTPMEDVARESCOPO"]) && !is_null($item["CDTPMEDVARESCOPO"])) {
            $newItem["CDTPMEDIDASERV"] = $item["CDTPMEDVARESCOPO"];
            $newItem["CDTPMEDIDAVARIAVEL"] = $item["CDTPMEDVARESCOPO"];
            $newItem["DSTPMEDIDASERV"] = $item["DSTPMEDVARESCOPO"];
        }
        else if ($item["IDMEDIDAFIXA"] == "S") {
            $newItem["CDTPMEDIDASERV"] = $item["CDMEDVARIAVELRELAC"];
            $newItem["DSTPMEDIDASERV"] = $item["DSTPMEDIDASERVRELAC"];
        }

        $newItem["VRPRECO"] = $item["VRUNITARIO"];
        return $newItem;
    }
    
    /**
     * Retorna os serviços com os valores somados dos itens da composição da proposta.
     * 
     * @param mixed[] $elementos - Elementos da proposta com seus serviços 
     * (o que será inserido na FCT_TRABSERVORCAMENTO)
     * 
     * @return mixed[]
     */
    public function getServicos(array $elementos) {
        $servicos = array();
        foreach ($elementos as $item) {
            if ($item["IDESCOLHIDO"] == "S") {
                if (!empty($item["CDSERVORCARELAC"]) && !empty($item["NRTIPOORCAMENTO"])) {
                    $posicao = $item["NRTIPOORCAMENTO"] . "-" . $item["CDSERVORCARELAC"] . "-" . $item["CDTPMEDIDAVARIAVEL"]. "-" .$item["IDELEMENTORAIZ"] . "-";

                    if (array_key_exists($posicao, $servicos)) {
                        if($item["IDMULTIPVARIACAO"] == "S" && $item["IDMEDIDAFIXA"] == 'N'){
                            $servicos[$posicao]["VRUNITITEMORCA"] += $item["VRPRECO"];
                        } else {
                            $servicos[$posicao]["QTMEDIDASERV"] += $item["QTMEDIDASERV"]; 
                            $servicos[$posicao]["QTMEDIDACALC"] += $item["QTMEDIDACALC"]; 
                        }
                    } else {
                        $servicos[$posicao] = array(
                            "IDARVORE"              => $item["CDSERVORCARELAC"] . "_" . $item["NRTIPOORCAMENTO"],
                            "IDARVOREPAI"           => null,
                            "IDTIPO"                => "I",
                            "QTITEMORCAMENTO"       => 1,
                            "CDSERVORCA"            => $item["CDSERVORCARELAC"],
                            "NMSERVORCA"            => $item["NMSERVORCARELAC"],
                            "NRTIPOORCAMENTO"       => $item["NRTIPOORCAMENTO"],
                            "NMTIPOORCAMENTO"       => $item["NMTIPOORCAMENTO"],
                            "IDFATURACONTR"         => $item["IDFATURACONTR"],
                            "CDMODPGTO"             => $item["CDMODPGTO"],
                            "NRGRUPOFATURA"         => $item["NRGRUPOFATURA"],
                            "QTPARCELASFATU"        => $item["QTPARCELASFATU"],
                            "NRDIAVENCPARCELASFATU" => $item["NRDIAVENCPARCELASFATU"],
                            "CDTPMEDIDASERV"        => $item["CDTPMEDIDASERV"],
                            "DSTPMEDIDASERV"        => $item["DSTPMEDIDASERV"],
                            "QTMEDIDASERV"          => $item["QTMEDIDASERV"],
                            "VRUNITITEMORCA"        => $item["VRPRECO"],
                            "VRPRECO"               => $item["VRPRECO"],
                            "NRORG"                 => $item["NRORG"],
                            "CDTPMEDIDAVARIAVEL"    => $item["CDTPMEDIDAVARIAVEL"],
                            "QTMEDIDACALC"          => $item["QTMEDIDASERV"],
                            "QTMEDIDAVARIAVEL"      => $item["QTMEDIDASERV"], 
                            "IDMULTIPVARIACAO"      => $item["IDMULTIPVARIACAO"],
                            "IDTIPOELEMENTO"        => null,
                            "IDALTQTDMEDIDAPROP"    => $item["IDALTQTDMEDIDAPROP"],
                            "IDELEMENTO"            => null,
                            "IDMEDIDAFIXA"          => $item["IDMEDIDAFIXA"]
                        );
                    }
                }
            }
        }
        
        $novosServicos = array();
        foreach ($servicos as &$servico) {
            $valor = $servico["VRUNITITEMORCA"] * $servico["QTMEDIDACALC"];
            $servico["VRUNITITEMORCA"]  = "";
            $servico["VRTOTALITEMORCA"] = $valor;

            $posicao = $servico["NRTIPOORCAMENTO"] . "-" . $servico["CDSERVORCA"] . "-";
            $pos     = strrpos($posicao, "-");
            $codigo  = substr($posicao, 0, $pos);
            
            if (array_key_exists($codigo, $novosServicos)) {
                $novosServicos[$codigo]["QTMEDIDASERV"]     = 1;
                $novosServicos[$codigo]["VRUNITITEMORCA"]   = "";
                $novosServicos[$codigo]["VRTOTALITEMORCA"] += $servico["VRTOTALITEMORCA"];
            } else {
                $novosServicos[$codigo] = $servico;
            }
            
            $novosServicos[$codigo]["QTMEDIDACALC"]   = $novosServicos[$codigo]["QTMEDIDASERV"];
        }
        unset($servico);
        ksort($novosServicos);
        return array_values($novosServicos);
    }
    
    /**
     * Retorna alguns dados da proposta para inserir nos itens.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    private function getDadosPropostaParaItens($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getDadosPropostaParaItens($params);
        return $dataset[0];
    }
    
    /**
     * Returna true se existir um preço com data de vigência inferior a data atual, e false se não existir.
     * 
     * @param mixed[] $dataset
     * 
     * @return boolean
     */
    private function validarDataValidadePrecoServico(array $dataset) {
        $dataAtual = date_create();
        $dataAtual = date_create_from_format("d/m/Y H:i:s", $dataAtual->format("d/m/Y") . "00:00:00");
        
        foreach ($dataset as $linha) {
            if (!empty($linha["DTFIMVALPBSERV"])) {
                $dataFinalVigencia = date_create_from_format("d/m/Y H:i:s", $linha["DTFIMVALPBSERV"] . "00:00:00");
                $diff = $dataFinalVigencia->diff($dataAtual);
                $diff = (int)$diff->format("%R%a");
                
                if ($diff > 0) {
                    return true;
                }
            }
        }
        
        return false;
    }
    
    /**
     * Atualiza os preços dos Elementos da proposta (FCT_TRABSERVORCAMENTO).
     */
    public function atualizarPrecos($nrseqorcamento, $nrorg) {
        $dataset = $this->getVariacaoPreco($nrseqorcamento, $nrorg);
        foreach ($dataset as $row) {
            $this->atualizarPrecosAux($row["VRPRECOVARIACAO"], $row["NRTRABSERVORCA"], $row["NRORG"]);
        }
    }
    
    /**
     * Retorna as variações de preço da proposta.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    private function getVariacaoPreco($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getVariacaoPreco($params);
    }
    
    /**
     * Atualiza os preços dos Elementos da proposta (FCT_TRABSERVORCAMENTO).
     */
    private function atualizarPrecosAux($vrprecovariacao, $nrtrabservorca, $nrorg) {
        $params = array(
            "VRUNITSERVORCA" => $vrprecovariacao,
            "NRTRABSERVORCA" => $nrtrabservorca,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->atualizarPrecos($params);
    }
    
    /**
     * Atualiza os itens e os elementos da proposta.
     */
    public function atualizarItensProposta($proposta, $elementos, $composicoes, $nrorg, $cdoperador, $idMantemDescAcres = 'N', $alteraMedida = false) {
        $this->connection->beginTransaction();
        try {
            $mensagem          = null;
            $nrseqorcamento    = $proposta["NRSEQORCAMENTO"];
            $itensProposta     = $this->getItensProposta($nrseqorcamento, $nrorg);
            $medidasProposta   = $this->getVariacoesPrecoProposta($nrseqorcamento, $nrorg);
            
            $params = array(
                "NRSEQORCAMENTO" => $nrseqorcamento,
                "NRORG"          => $nrorg
            );
            
            $negociacoes = $this->propostaFactory->getParametrosFaturaNegociacoesProposta($params);
            $parcelas    = $this->propostaFactory->getParcelasProposta($params);
            
            if($idMantemDescAcres == 'S')
                $descontosProposta = $this->getDescontosProposta($nrseqorcamento, $nrorg);
            
            $this->deletarTiposMedidaDaProposta($nrseqorcamento, $nrorg);
            $this->excluirElementosProposta($nrseqorcamento, $nrorg);
            $this->excluirComposicoesProposta($nrseqorcamento, $nrorg);
            $this->excluirItensProposta($nrseqorcamento);

            $idelementos = array();
            foreach ($elementos as $elemento) {
                array_push($idelementos, $elemento["IDELEMENTO"]);
            }
            
            $escoposProposta = $this->getEscoposProposta($nrseqorcamento, $nrorg);
            
            $tiposMedida = $this->getTiposMedidaVariaveisDosElementos(null, $idelementos, $escoposProposta, $nrorg);
            foreach($tiposMedida as &$tpMedida){
                foreach ($medidasProposta as $medidaProp) {
                    if($tpMedida["CDTPMEDIDASERV"] == $medidaProp["CDTPMEDIDASERV"] && $tpMedida["IDELEMENTORAIZ"] == $medidaProp["IDELEMENTORAIZ"]){
                        $tpMedida["QUANTIDADE"] = $medidaProp["QUANTIDADE"];
                    }
                }
            }
            unset($tpMedida);
            
            $itens = $this->getItensPropostaParaInserir($proposta, $elementos, $composicoes, $tiposMedida);
            
            $this->inserirTudo($proposta["NRSEQORCAMENTO"], $proposta["NRTIPOORCAMENTO"], $proposta["NRORCAMENTOMODELO"], $tiposMedida, $itens, $proposta["IDSITUACAOORCAMENTO"], null);
            $this->atualizarNomeContratualItens($itensProposta, $nrseqorcamento, $nrorg);
            
            $possuiAlteracaoValor = false;
            foreach($itensProposta as $item) {
                if($item["VRACRESCIMOITEM"] > 0) {
                    $possuiAlteracaoValor = true;
                    break;
                }
            }
            
            if($idMantemDescAcres == 'S' && (count($descontosProposta) > 0 || $possuiAlteracaoValor)) {
                $this->atualizarDescontosAcrescimosProposta($itensProposta, $descontosProposta, $nrseqorcamento, $nrorg, $negociacoes, $alteraMedida, $proposta["IDSITUACAOORCAMENTO"], $parcelas);
            }
            
            $this->atualizarParcelasProposta($negociacoes, $nrseqorcamento, $parcelas, $nrorg);
           
            //manipula as informações no contrato 
            if($proposta["IDSITUACAOORCAMENTO"] === "ACEITO")
                $this->inserirInformacoesVariacaoServ($composicoes, $nrorg, $nrseqorcamento, $cdoperador, $proposta["NRTIPOORCAMENTO"]);
            
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
        
        return $mensagem;
    }
    /**
     * Atualiza as informações dos itens no contrato
     */
    /*public function atualizarItensContrato($nrseqorcamento, $nrorg, $itens){
        $paramsSelect = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $contratos = $this->propostaFactory->getContratos($paramsSelect);
        foreach ($contratos as $contrato) {
            $paramsDelete = array(
                "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"],
                "NRORG"         => $nrorg
            );
            $this->propostaFactory->deletarItensContrato($paramsDelete);
            foreach ($itens as $item) {
                if($item["NRTIPOORCAMENTO"] == $contrato["NRTIPOORCAMENTO"] && !isset($item["IDELEMENTO"])){
                    $paramsSelect = array_merge($paramsSelect, array("CDSERVORCA" => $item["CDSERVORCA"]));
                    $vrtotal = $this->propostaFactory->getValorTotalItensTipoElemento($paramsSelect);
                    $nritemcontrato = $this->newCode->getCodeByTableName("FCT_ITEMCONTRATO", $nrorg, 1, 10, true);
                    $params = array(
                        "NRORG"                 => $nrorg,
                        "NRITEMOCONTRATO"       => $nritemcontrato,
                        "NRSEQCONTRATO"         => $contrato["NRSEQCONTRATO"],
                        "CDSERVORCA"            => $item["CDSERVORCA"],
                        "NMITEMCONTRATO"        => $item["NMSERVORCA"],
                        "QTITEMCONTRATO"        => $item["QTITEMORCAMENTO"],
                        "CDTPMEDIDASERV"        => $item["CDTPMEDIDASERV"],
                        "QTMEDIDACONTR"         => $item["QTMEDIDASERV"],
                        "QTPARCELASFATU"        => $item["QTPARCELASFATU"],
                        "NRDIAVENCPARCELASFATU" => $item["NRDIAVENCPARCELASFATU"],
                        "CDPRODUTO"             => null,
                        "SGUNIDADE"             => null,
                        "IDUNIDTEMPOSERV"       => null,
                        "QTTEMPOSERV"           => null,
                        "DTINICFATCONTR"        => null,
                        "IDITEMATIVO"           => 'S',
                        "VRUNITITEMCONT"        => $vrtotal,
                        "VRTOTITEMCONT"         => $vrtotal,
                        "IDMULTMEDVRTOT"        => 'S',
                        "IDADICITEMCONT"        => 'N',
                        "IDADICCOBRCONT"        => 'N',
                        "IDFATURAITEM"          => 'SIM',
                        "VRDESCONTO"            => 0,
                        "IDTPDESCONTO"          => 'S'
                    );
                    $this->propostaFactory->inserirItensContrato($params);
                }
            }
        }
    }*/

    /**
     * Atualiza o tipo de medida dos itens da proposta
    **/
    public function atualizarTipoDeMedidaProposta($proposta, $nrorg, $cdoperador, $tptratamento){
        $nrseqorcamento  = $proposta["NRSEQORCAMENTO"];
        $elementos   = $this->getElementosEscolhidos($nrseqorcamento, $nrorg);
        $composicoes = $this->getComposicoesProposta($nrseqorcamento, $nrorg);
        $this->atualizarItensProposta($proposta, $elementos, $composicoes, $nrorg, $cdoperador, $tptratamento, true);
    }
    /**
     * Altera o nome contratual do item
    **/
    public function atualizarNomeContratualItens($itens, $nrseqorcamento, $nrorg){
        $cdservorcas = array();
        foreach($itens as $item){
            if($item["IDELEMENTO"]){
                $params = array(
                    "NRORG"                => $nrorg, 
                    "NRSEQORCAMENTO"       => $nrseqorcamento,
                    "IDELEMENTO"           => $item['IDELEMENTO'],
                    "NMCONTRATUALITEMORCA" => $item["NMCONTRATUALITEMORCA"]
                );
                $this->propostaFactory->atualizarNomeContratualItens($params);
            }
        }
    }

    /**
     * Retorna as variações de preço da proposta.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getVariacoesPrecoProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getVariacoesPrecoProposta($params);
    }
    /**
     * Retorna as variações de preço ligadas a proposta após a sua conclusao.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getVariacaoPrecoLigadaAoOrca($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getVariacaoPrecoLigadaAoOrca($params);
    }
    
    /**
     * Exclui os elementos da proposta (FCT_TRABSERVORCAMENTO)
     */
    public function excluirElementosProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->excluirElementosProposta($params);
    }
    
    /**
     * Retorna os Elementos escolhidos.
     */
    public function getElementosEscolhidos($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $escolhidos = array();
        $dataset = $this->propostaFactory->getElementosEscolhidos($params);
        
        /*foreach ($dataset as $row) {
            $escolhidos[] = array(
                "IDELEMENTO"    => $row["IDELEMENTO"],
                "NRCOMPSERVICO" => $row["NRCOMPSERVICO"]
            );
        }
        
        return $escolhidos;*/
        
        return $dataset;
    }
    
    /**
     * Retorna os Itens da Proposta.
     */
    public function getItensProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getItensProposta($params);
    }
    
    /**
     * A função "verificaDesconto" verifica se algum item do orcaçamento possui desconto, 
     * para chamar o relatório de prévia corretamente.
     */
    public function verificaDesconto($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG" => $nrorg
        );
        
        $return = $this->propostaFactory->verificaDesconto($params);
        
        return $return[0]["DESCONTO"] != 0;
    }
    
    /**
     * A função "buscaModeloDocumento" busca o modelo de documentos para cada escopo 
     * a fim de ser inserido na tabela FCT_RELACESCOPOPROPOSTA
     */
    public function buscaModeloDocumento($modelo, $escopo, $nrorg) {
        $params = array(
            "NRORCAMENTOMODELO" => $modelo,
            "NRTIPOORCAMENTO"   => $escopo,
            "NRORG"             => $nrorg
        );
        
        $dataset = $this->propostaFactory->buscaModeloDocumento($params);
        return $dataset;
    
    }
    
    
    /**
     * A função "buscaFilialHierarquia" busca a filial vinculado ao operador na hierarquiia de operadores (CRM_HIERARQUIAOPER)
     * a fim de ser inserido na tabela FCT_RELACESCOPOPROPOSTA
     */
    public function buscaFilialHierarquia($operador, $nrorg) {
        $params = array(
            "CDOPERADOR" => $operador,
            "NRORG"      => $nrorg
        );
        
        $dataset = $this->propostaFactory->buscaFilialHierarquia($params);
        return $dataset;
    
    }
    
    /**
     * Executa a procedure FCT_SUB_MNE_DOC_PROV.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrtipoorcamento
     * 
     * @return string
     */
    public function executarProcedureFctSubMneDocProv($nrseqorcamento, $nrtipoorcamento) {
        $nrorg = $this->environment->getNrOrg();

        $procedure = new FctSubMneDocProv($this->connection);
        $mnemonico = $procedure->executar($nrseqorcamento, $nrtipoorcamento, $nrorg);
    }
    
    /**
     * Verifica se o parceiro de negócio é um vendedor.
     */
    public function verificarSeEVendedor($nrparcnegocio) {
        $nrorg = $this->environment->getNrOrg();
        
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG"         => $nrorg
        );
            
        $dataset = $this->propostaFactory->verificarSeEVendedor($params);
        return ((int)$dataset[0]["EXISTE"] > 0);
    }
    
    /**
     * Retorna os tipos de medida variáveis relacionados aos elementos informados.
     */
    public function getTiposMedidaVariaveisDosElementos($elementosRaiz, array $idElementos, array $nrtipoorcamento, $nrorg, $nrmoeda = null) {
        if ($nrtipoorcamento) {
            $nrtipoorcamento = implode(",", $nrtipoorcamento);
        }
        else {
            $nrtipoorcamento = "NULL";
        }
        
        if (is_null($elementosRaiz)) {
            $elementosRaiz = $this->propostaFactory->filtrarElementosRaiz($idElementos, $nrorg);
        }
        
        $idElementosRaiz = array();
        if (!empty($elementosRaiz) && count($elementosRaiz) > 0) {
            foreach ($elementosRaiz as $elem) {
                $idElementosRaiz[] = $elem["IDELEMENTO"];
            }
        }
        $idElementosRaiz = "'" . implode("','", $idElementosRaiz) . "'";

        return $this->propostaFactory->getTiposMedidaVariaveisDosElementos($idElementos, $nrtipoorcamento, $nrorg, $idElementosRaiz, $nrmoeda);
    }
    
    /**
     * Cria uma linha de tipo de medida variável para cada elemento raiz da árvore
     **/
    public function duplicarMedidasParaElementosRaiz($tiposMedida, $elementosRaiz) {
        $dataset = array();
        foreach ($elementosRaiz as $elemento) {
            foreach ($tiposMedida as $tipoMedida) {
                if($tipoMedida["IDELEMENTO"] == $elemento["IDELEMENTO"]){
                    $tipoMedida["NMELEMENTORAIZ"] = $elemento["NMELEMENTO"];
                    $tipoMedida["IDELEMENTORAIZ"] = $elemento["IDELEMENTO"];
                    $dataset[] = $tipoMedida;
                }
            }
        }
        return $dataset;
    }
    /**
     * Quando houver item repetido, permanece apenas aquele que é obrigatório.
     */
    public function eliminarElementosDuplicados(array $composicao) {
        $elementos = array();
        for ($i = 0; $i < count($composicao); $i++) {
            $cdelemento         = (int)$composicao[$i]["CDELEMENTO"];
            $servicoRelacionado = $composicao[$i]["CDSERVORCARELAC"];
            
            if (array_key_exists($cdelemento, $elementos) && $elementos[$cdelemento]["SERVICO"] == $servicoRelacionado) {
                $pos = $elementos[$cdelemento]["POSICAO"];
                $composicao[$pos]["IDSERVOBRIGCOMP"] = "S";
                unset($composicao[$i]);
            } else {
                $elementos[$cdelemento] = array(
                    "POSICAO"    => $i,
                    "SERVICO"    => $servicoRelacionado
                );
            }
        }
        
        $novosElementos = array();
        foreach ($composicao as $item) {
            $novosElementos[] = $item;
        }
        
        return $composicao;
    }
    
    /**
     * Retorna a previsão de faturamento dos itens da proposta.
     */
    public function gerarPrevisaoFaturamento($nrseqorcamento, $nrtipoorcamento, $nrorg) {
        $paramsFatEscopo = $this->paramFatEscopoFactory->getParametrosDeFaturamentoDoEscopo($nrseqorcamento, $nrtipoorcamento, $nrorg);
        
        
    }
    
    /**
     * Insere os modelo de documento nos documentos da proposta.
     */
    
    public function inserirDocumentoProposta($nrseqorcamento, $nrorg){
        
        $operador = $this->environment->getCdOperador();
        
        /* Recebe documento */
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG" => $nrorg
        ); 
         
        $modelodoc = $this->propostaFactory->getModeloDocumento($params);
        
        if (count($modelodoc) > 0) {
            $nrSeqModDocFct = $modelodoc[0]["NRSEQMODDOCFCT"];
            $documento = $modelodoc[0]["TXMODELODOCORCA"];
            
            /* Insere documento */
            
            $novoCodigo = $this->newCode->getCodeByTableName("NRSEQORCADOC", $nrorg, 1, 10, true);
            
            $params = array(
                "NRSEQORCADOC" => $novoCodigo,
                "NRSEQORCAMENTO" => $nrseqorcamento,
                "NRSEQMODDOCFCT" => $nrSeqModDocFct,
                "TXMODELOORCADOC" => $documento,
                "NRORG" => $nrorg,
                "OPERADOR" => $operador
            ); 
             
            $this->propostaFactory->inserirDocumentoProposta($params); 
        }
    }
    /**
     * Insere as composições da proposta.
     */
    public function inserirComposicoesProposta(array $composicoes, $nrseqorcamento) {
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        foreach ($composicoes as $comp) {
            $nrcompservorcamento = $this->newCode->getCodeByTableName("FCT_COMPSERVORCAMENTO", $nrorg, 1, 10, true);
            $params = array(
                "NRCOMPSERVORCAMENTO" => $nrcompservorcamento,
                "NRSEQORCAMENTO"      => $nrseqorcamento,
                "NRCOMPSERVICO"       => $comp["NRCOMPSERVICO"],
                "NMCOMPSERVICO"       => $comp["NMCOMPSERVICO"],
                "NRCOMPSERVICOPAI"    => $comp["NRCOMPSERVICOPAI"],
                "IDCOMPOBRIGATORIA"   => $comp["IDCOMPOBRIGATORIA"],
                "IDESCOLHIDO"         => $comp["IDESCOLHIDO"],
                "IDATIVO"             => "S",
                "NRORG"               => $nrorg,
                "CDOPERINCLUSAO"      => $cdoperador,
                "NRORGINCLUSAO"       => $nrorg,
                "CDCENTCUST"          => isset($comp["CDCENTCUST"]) ? $comp["CDCENTCUST"] : null
            );
            
            $this->propostaFactory->inserirComposicoesProposta($params);
        }
    }
    
    public function getComposicoesProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getComposicoesProposta($params);
    }
    
    /**
     * Exclui as composições da proposta
     */
    public function excluirComposicoesProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirComposicoesProposta($params);
    }
    
    /* Anexa o novo documento do orçamento */
    public function anexaOrcamentoDoc($arquivoDoc, $nome, $tipo, $tamanho){
         $fileData = array(
            'b64File' => 'data:'.$tipo.';base64,'.$arquivoDoc,
            'name' => $nome,
            'size' => $tamanho * 1024,
            'type' => $tipo,
            'webkitRelativePath' => ''
        );

        $row = new Row(array('FILE' => array($fileData)));
        $this->zhFileUploader->uploadFilesInRow($row, 'FILE', 'anexo_documento_proposta');
        
        return $row["FILE"][0];
    }
    
    /**
     * Retorna os escopos da proposta.
     */
    public function getEscoposProposta($nrseqorcamento, $nrorg) {
    	$params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
    	
    	$dataset = $this->propostaFactory->getEscoposProposta($params);
        if (count($dataset) > 0) {
            
            $escopos = array();
            foreach ($dataset as $row) {
                $escopos[] = $row["NRTIPOORCAMENTO"];
            }
            
            return $escopos;
        }
        else {
            return $dataset;
        }
    }
    
    public function anexarDocumentosProposta($caminhoArquivos) {
        $links = array();
        $customFolder = "anexo_documento_proposta";
        
        $nrorg = $this->environment->getNrOrg();
        
        foreach ($caminhoArquivos as $chave => $caminho) {
            $file = Utilities::uploadArquivoFileServer($this->zhFileUploader, $customFolder, $caminho);
            $links[] = $file["path"];
            
            $caminhoDocumentoGeradoPDF = $this->getCaminhoDocumentoGeradoPDFProposta($chave, $nrorg);
            if (!empty($caminhoDocumentoGeradoPDF)) {
                $this->zhFileUploader->deleteFile($caminhoDocumentoGeradoPDF);
            }
            
            //atualizar o link PDF no documento
            $params = array(
                "DSCAMINHODOCGERADOPDF" => $file["path"],
                "NRSEQORCADOC"          => $chave,
                "NRORG"                 => $nrorg
            );
            
            $this->propostaFactory->atualizarCaminhoDocumentoGeradoPDFProposta($params);
        }
        
        return $links;
    }
    
    public function anexarDocumentosContratosGerados($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->propostaFactory->getDocumentosContratosGerados($params);
        foreach ($dataset as $row) {
            $nomeArquivo   = $row["NMARQUIVO"];
            $tipo          = $row["DSTIPO"];
            $tamanhoBytes  = $row["VRTAMANHO"] * 1024;
            $urlFileServer = $row["DSCAMINHOARQ"];
            
            if (!empty($urlFileServer)) {
                //$conteudo = @file_get_contents($this->fileServerBaseUrl . $urlFileServer);
                $conteudo = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $urlFileServer, $nrorg);
                if ($conteudo !== false) {
                    $file = Utilities::uploadFileServer($this->zhFileUploader, "anexo_documento_contrato", $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                    $caminhoNovo = $file["path"];
                    
                    $params = array(
                        "DSCAMINHOARQ"  => $caminhoNovo,
                        "NRSEQCONTDOC"  => $row["NRSEQCONTDOC"],
                        "NRSEQCONTRATO" => $row["NRSEQCONTRATO"],
                        "NRORG"         => $nrorg
                    );
                    
                    $this->propostaFactory->atualizarCaminhoDocumentoContrato($params);
                }
            }
        }
    }
    
    public function anexarDocumentosPropostaCopiada($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG" => $nrorg
        );
        
        $dataset = $this->propostaFactory->getDocumentosProposta($params);
        foreach ($dataset as $row) {
            $nomeArquivo   = $row["NMARQUIVO"];
            $tipo          = $row["DSTIPO"];
            $tamanhoBytes  = $row["VRTAMANHO"] * 1024;
            $urlFileServer = $row["DSCAMINHOARQ"];

            $nrorcadoc = $row["NRSEQORCADOC"];
            
            $caminhoArquivoNovo = null;

            if (!empty($urlFileServer)) {
                $conteudo = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $urlFileServer, $nrorg);
                if ($conteudo !== false) {
                    $file = Utilities::uploadFileServer($this->zhFileUploader, "anexo_documento_proposta", $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                    $caminhoNovo = $file["path"];
                    $params = array(
                        "DSCAMINHOARQ"   => $caminhoNovo,
                        "NRSEQORCAMENTO" => $nrseqorcamento,
                        "NRORG"          => $nrorg
                    );

                    $caminhoArquivoNovo = $caminhoNovo;
                    
                    $this->propostaFactory->atualizarCaminhoDocumentoProposta($params, $nrorcadoc);
                }
            }

            $this->atualizarAnexoDocumentosIdiomaPropostaCopiada($nrorcadoc, $urlFileServer, $caminhoArquivoNovo, $nrorg);
        }
    }

    public function atualizarAnexoDocumentosIdiomaPropostaCopiada($nrseqorcadoc, $caminhoArquivoAntigo, $caminhoArqivoOrcaDoc, $nrorg) {
        $params = [
            "NRSEQORCADOC" => $nrseqorcadoc
        ];
        $dataset = $this->propostaFactory->getDocumentosIdiomaProposta($params);
        foreach ($dataset as $anexo) {
            if (!empty($anexo["DSCAMINHOARQ"])) {
                if ($anexo["DSCAMINHOARQ"] == $caminhoArquivoAntigo) {
                    $caminhoAnexo = $caminhoArqivoOrcaDoc;
                }
                else {
                    $arquivoDocIdioma = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $anexo["DSCAMINHOARQ"], $nrorg);
                    if ($arquivoDocIdioma !== false) {
                        $arquivoDocIdioma = base64_encode($arquivoDocIdioma);
    
                        $anexoNovo = $this->anexaOrcamentoDoc($arquivoDocIdioma, $anexo["NMARQUIVO"], $anexo["DSTIPO"], $anexo["VRTAMANHO"]);
                        $caminhoAnexo = $anexoNovo["path"];
                    }
                }

                $params = array(
                    "DSCAMINHOARQ"         => $caminhoAnexo,
                    "NRORCAMENTODOCIDIOMA" => $anexo["NRORCAMENTODOCIDIOMA"]
                );
                $this->propostaFactory->atualizarCaminhoDocumentoIdiomaProposta($params);
            }
        }
    }
    
    /** Aceita a proposta 
     * @param nrseqorcamento - id do orcamento 
     * @param nrorg - numero da organizacao 
     * @param utilizacomposicao - utiliza integracao 
     * @param nrparcnegocio - id do parceiro de negocio 
     * @param cdoperador - codigo do operador 
     */
    public function aceitarProposta($nrseqorcamento, $nrorg, $nrparcnegocio, $cdoperador, $dtAceite = null){
        try{
            $dataAtual = date_create();
            $dataAtual = $dataAtual->format("d/m/Y");
            if(!$dtAceite) $dtAceite = $dataAtual;

            $this->popularDatasFinaisDescontoPorPeriodoNegociacaoValores($dtAceite, $nrseqorcamento, $nrorg);
                
            // Atualiza a Proposta
            $this->atualizarPropostaAceite($nrseqorcamento, $dataAtual, $nrorg, $cdoperador, $dtAceite);
            //"true" se converte, "false" se não converte
            $converteProspectEmCliente = $this->verificaConverteProspectEmCliente($nrorg);
            //"true" se o prospect já for cliente, "false" se não for
            $validaCliente = $this->validaClienteProspect($nrparcnegocio, $nrorg);
            /* Se o parceiro de negócio for do tipo "PROSPECT", converte para "CLIENTE". (A validação do parametro
               "Converter Prospect em Cliente no aceite da proposta?"" da Parametrização SM é feita dentro da procedure. ) */
            if ($converteProspectEmCliente && $validaCliente == false) {
                $this->executarProcedureFctConversaoCliente($nrorg, $cdoperador, $nrparcnegocio);
            }
            
            // Gera o Contrato
            $nrseqcontrato = $this->executarProcedureGeraContrato($nrseqorcamento, $nrorg);
            $this->anexarDocumentosContratosGerados($nrseqorcamento, $nrorg);
            $itensDoOrcamneto = $this->getItensProposta($nrseqorcamento, $nrorg);
            foreach ($itensDoOrcamneto as $itemOrcamneto) {
                $ItensContrato = $this->getItemContratos($nrseqorcamento, $itemOrcamneto["CDSERVORCA"], $nrorg);
                foreach ($ItensContrato as $ItemContrato) {
                    $this->agedRecPendente->atualizarAgendamentoPendente('5', $ItemContrato["NRITEMOCONTRATO"], $ItemContrato["NRSEQCONTRATO"], $nrseqorcamento, $itemOrcamneto["NRITEMORCAMENTO"], $nrorg);
                }
            }
        } catch (\Exception $e1) {
            try {
                $this->reverterAceiteProposta($nrseqorcamento, $nrorg);
                if ($converteProspectEmCliente && $validaCliente == false)
                    $this->reverterConversaoCliente($nrparcnegocio, $nrorg);
            } catch (\Exception $e2) {
                $erro1 = $e1->getMessage();
                $erro2 = $e2->getMessage();
                throw new \Exception($erro1 . "<br/><br/>Falha ao reverter aceite da proposta:<br/>" . $erro2);
            }
            
            throw $e1;
        }
    }
    

    /**
     * Validação com o OM ao Concluir as Propostas
     */
    public function concluirProposta($nrseqorcamento, $nrorg) {
        try {
            $utilizaIntegracao = $this->integracaoOmService->verificarUtilizaIntegracao($nrorg);
            if ($utilizaIntegracao) {
                $url   = $this->integracaoOmService->getUrlIntegracao($nrorg);
                $dados = $this->integracaoOmService->montarArrayIntegracao($nrseqorcamento, $nrorg);
                if(!empty($dados) && array_key_exists("products", $dados) && !empty($dados["products"]) && array_key_exists("elements", $dados["products"][0]) && count($dados["products"][0]["elements"]) > 0){
                    $this->salvarDadosIntegracaoOMConclusaoProposta($dados, $nrseqorcamento, $nrorg);
                    $retorno = $this->integracoesTeknisaService->enviarDadosIntegracaoOM($url, "/validateOrganizationByElements/find", $dados);
                    if (isset($retorno["validation"]) && is_array($retorno["validation"])) {
                        $validation = array_values($retorno["validation"]);
                        
                        if ($validation[0]["ValidatedElements"] == false) {
                            $invalidElements = "";
                            $product = ($validation[0]["product"]);
                            foreach($validation[0]["element"] as $element) {
                                $invalidElements = $invalidElements . ", " . $element["element"][0];
                            }
            
                            $invalidElements = substr($invalidElements, 1);
                            //$message = Messages::ERR_NOT_VALIDATE_ORGANIZATION_BECAUSE_ELEMENT_NOT_FOUND_EXPLANATION . $invalidElements;
                            $message = "Operação bloqueada. <br/><br/>Os seguintes elementos do produto {{productName}} não foram encontrados no OM: <br/>" . $invalidElements;
                            throw new \Exception(str_replace("{{productName}}", $product , $message));
                        }
                        return $validation;
                    }
                    else {
                        throw new \Exception("Falha na integração com o módulo OM. Retorno:<br/>" . print_r($retorno, true));
                    }
                }
                return true;
            }
        }  catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * retorna o item do contrato correpondente ao item da proposta
     **/
    public function getItemContratos($nrseqorcamento, $cdservorca, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "CDSERVORCA"     => $cdservorca,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getItemContratos($params);
    }
    
    /**
     * Limpa a data de aceite da proposta e atualiza sua situação para "Concluída".
     */
    public function reverterAceiteProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->reverterAceiteProposta($params);
    }
    
    /**
     * Reverte a conversão do parceiro de negócio da proposta em cliente.
     */
    public function reverterConversaoCliente($nrparcnegocio, $nrorg) {
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG"         => $nrorg
        );
        
        $this->propostaFactory->excluirEnderecoCliente($params);
        $this->propostaFactory->excluirInterlocutorCliente($params);
        $this->propostaFactory->excluirParceriaCliente($params);
        $this->propostaFactory->ativarParceriaProspect($params);
        $this->propostaFactory->atualizarTipoPrincipalParceiro($params);
        $this->propostaFactory->excluirCliente($params);
    }
    
    /**
     * Envia os dados de evolução de oportunidade para o CRM
     * @params{Array} rowDados dados que serão enviados
    **/
    public function enviarDadosCRM($nrorg, $rowDados) {
        try{
            //$urlintegracao = "http://arthurmelo.zeedhi.com/workfolder/crm/backend/service/index.php";
            $urlintegracao = $this->getUrlIntegracaoCrm($nrorg);
            $rota = "/IntegracaoSm/geraEvolucaoOportunidade";
            $retorno = $this->integracoesTeknisaService->enviarDadosIntegracao($urlintegracao, $rota,  $rowDados);
    
            if (isset($retorno["EVOLUCAO"])) {
                return true;
            } else {
                return false;
            }
            
        } catch(\Exception $e){
            throw $e;
        }
    }
   
    /**
     * Retorna a url de integração com o crm
     * @params $nrorg nr do modelo
    **/
    public function getUrlIntegracaoCrm($nrorg){
        $param = array(
            "NRORG" => $nrorg
        );
        
        $dataset = $this->propostaFactory->getUrlIntegracaoCrm($param);
        return $dataset[0]["URLINTEGRACAOCRM"];
    }
    
    /*public function getElementosComQuantidadeMedidaAlterada($itens) {
        $elementosAlterados = array();
        foreach ($itens as $item) {
            if ($item["QTMEDIDACALC"] != "" && $item["QTMEDIDASERV"] != $item["QTMEDIDACALC"]) {
                $elemento = $item;
                $elemento["QTMEDIDASERV"] = $item["QTMEDIDASERV"] - $item["QTMEDIDACALC"];
                $elementosAlterados[] = $elemento;
            }
        }
        return $elementosAlterados;
    }*/
    
    public function getItensTipoI($itens) {
        $novosItens = array();
        foreach ($itens as $item) {
            if ($item["IDTIPO"] == "I") {
                $novosItens[] = $item;
            }
        }
        
        return $novosItens;
    }
    
    public function salvarElementosAlteradosPeloUsuario($elementos) {
        foreach ($elementos as $elemento) {
            $nrseqorcamento  = $elemento["NRSEQORCAMENTO"];
            $nrtipoorcamento = $elemento["NRTIPOORCAMENTO"];
            $qtmedidaserv    = (float)$elemento["QTMEDIDAORCA_GRID"];
            $vrunititemorca  = (float)$elemento["VRUNITITEMORCA"];
            
            $cdservorca = substr($elemento["IDARVOREPAI"], 0, strrpos($elemento["IDARVOREPAI"], "_"));
            
            $nrorg      = $this->environment->getNrOrg(); //$elemento["NRORG"];
            $cdoperador = $this->environment->getCdOperador();
            
            //$itemProposta = $this->getItemPropostaPorCodServico($nrseqorcamento, $nrtipoorcamento, $cdservorca, $nrorg);
            $somatoriaItensComposicao = $this->getSomatoriaElementosComposicaoPropostaPorElementoRaiz($nrseqorcamento, $nrorg, $cdservorca);
            $totalQtdMedidaAtual = 0;
            $qtdMedidaAtual = 0;
            
            foreach ($somatoriaItensComposicao as $item) {
                $totalQtdMedidaAtual += $item["QTMEDIDAORCA"];
                if ($elemento["IDARVORE"] == $item["IDARVORE"]) {
                    $qtdMedidaAtual = $item["QTMEDIDAORCA"];
                }
            }
            
            $idelementopai = explode("_", $elemento["IDARVORE"]);
            array_pop($idelementopai);
            $idelementopai = implode("_", $idelementopai);
            $idelementopai = substr($idelementopai, 0, strrpos($idelementopai, "_"));
            $elementoAlterado = $this->getElementoAlteradoPeloUsuarioNaComposicaoServico($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrorg, $elemento["CDTPMEDIDASERV"]);
            if ($elementoAlterado) {
                $nrtrabservorca = $elementoAlterado["NRTRABSERVORCA"];
                $qtMedidaItens = $totalQtdMedidaAtual - $elementoAlterado["QTMEDSERVORCA"];
                
                if($qtMedidaItens > $qtmedidaserv)
                    $qtDiferenca = $qtMedidaItens - $qtmedidaserv;
                else 
                    $qtDiferenca = $qtmedidaserv - $qtMedidaItens;
                
                $multiplicaVariacao = $elemento["IDMULTIPVARIACAO"];
                $countElemento = $this->getCountElementos($nrtipoorcamento, $nrseqorcamento, $idelementopai, $elemento["CDTPMEDIDASERV"], $nrorg, $cdservorca);
                $this->atualizarElementoAlteradoPeloUsuarioNaComposicaoServico($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrtrabservorca, $nrorg, $cdoperador, $multiplicaVariacao, $qtDiferenca, $elemento["VRPERCDESCORCA"], $elemento["IDTPDESCORCA"], $elementoAlterado["VRTOTSAJUSTE"], $countElemento["QTELEMENTOS"]);
            } else {
                $qtdMedida = $qtmedidaserv - $qtdMedidaAtual;
                $this->inserirElementoAlteradoPeloUsuarioNaComposicaoServico($elemento, $qtdMedida, $nrorg, $cdoperador);
                $this->inativaElemento($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrorg, $elemento["CDTPMEDIDASERV"]);
            }
        }
    }
    /**
     * Retorna a quantidade de elementos de uma composição de serviço
    **/
    public function getCountElementos($nrtipoorcamento, $nrseqorcamento, $idelementopai, $cdtpmedidaserv, $nrorg, $cdservorca){
         $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRORG"           => $nrorg,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDTPMEDIDASERV"  => $cdtpmedidaserv
        );
        
        return $this->propostaFactory->getCountElementos($params);
    }
    /**
     * Inativa o elementos da composição de serviço quando se cria outro do tipo 
     * Alterado pelo Usuário
    **/
    public function inativaElemento($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrorg, $cdtpmedida){
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRORG"           => $nrorg,
            "CDTPMEDIDASERV"  => $cdtpmedida,
        );
        $dataset = $this->propostaFactory->inativaElemento($params);    
    }
    
    /**
     * Verifica se o elemento alterado já está inserido na tabela 
     * com o tipo Alterado Pelo Usuário
    **/
    public function getElementoAlteradoPeloUsuarioNaComposicaoServico($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrorg, $cdtpmedida) {
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDSERVORCA"      => $cdservorca,
            "CDTPMEDIDASERV"  => $cdtpmedida,
            "NRORG"           => $nrorg
        );
        
        $dataset = $this->propostaFactory->getElementoAlteradoPeloUsuarioNaComposicaoServico($params);
        return (count($dataset) > 0) ? $dataset[0] : null;
    }
    
    public function atualizarElementoAlteradoPeloUsuarioNaComposicaoServico($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrtrabservorca, $nrorg, $cdoperador, $multiplicaVariacao, $qtmedidaserv, $vrpercajuste, $idtpajuste, $oldTotalSajuste, $countElemento) {
        $params = array(
            "QTMEDSERVORCA"   => $qtmedidaserv,
            "CDOPERULTATU"    => $cdoperador,
            "NRTRABSERVORCA"  => $nrtrabservorca,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRORG"           => $nrorg
        );
        $this->propostaFactory->atualizarElementoAlteradoPeloUsuarioNaComposicaoServico($params, $multiplicaVariacao, $vrpercajuste, $idtpajuste, $oldTotalSajuste, $countElemento);
    }
    
    public function inserirElementoAlteradoPeloUsuarioNaComposicaoServico($elemento, $qtdMedida, $nrorg, $cdoperador) {
        $nrtrabservorca = $this->newCode->getCodeByTableName("FCT_TRABSERVORCAMENTO", $nrorg, 1, 10, true);
        $idarvore = $elemento["IDARVORE"];
    
        $idelementoraiz = explode("_", $idarvore);
        array_pop($idelementoraiz);
        $idelementoraiz = implode("_", $idelementoraiz);
        $idelementoraiz = substr($idelementoraiz, 0, strrpos($idelementoraiz, "_"));
        
        $valorUnitario = (float)$elemento["VRUNITITEMORCA"];
        $qtdMedida     = $elemento["QTMEDIDAORCA"];
        $valorTotal    = $valorUnitario * $qtdMedida;
        
        /*if ($elemento["IDMULTIPVARIACAO"] == "S") {
            $valorTotal *= $elemento["QTMEDIDAVARIAVEL"];
        }*/
        $params = array(
            "NRTRABSERVORCA"    => $nrtrabservorca,
            "NRSEQORCAMENTO"    => $elemento["NRSEQORCAMENTO"],
            "NRTIPOORCAMENTO"   => $elemento["NRTIPOORCAMENTO"],
            "NRCOMPSERVICO"     => null,
            "NRITCOMPSERVICO"   => null,
            "IDELEMENTO"        => "USUARIO",
            "IDELEMENTOPAI"     => $idelementoraiz,
            "IDTIPOELEMENTO"    => "G",
            "IDESCOLHIDO"       => "S",
            "CDSERVORCA"        => $elemento["CDSERVORCA"],
            "QTSERVORCA"        => $elemento["QTITEMORCAMENTO"],
            "CDTPMEDIDASERV"    => $elemento["CDTPMEDIDASERV"],
            "QTMEDSERVORCA"     => $qtdMedida,
            "VRUNITSERVORCA"    => (float)$valorUnitario,
            "VRTOTSERVORCA"     => $valorTotal,
            "IDATIVO"           => "S",
            "NRORG"             => $nrorg,
            "CDOPERINCLUSAO"    => $cdoperador,
            "NRORGINCLUSAO"     => $nrorg,
            "IDSERVOBRIGCOMP"   => "N",
            "QTMEDIDAVARIAVEL"  => isset($elemento["QTMEDIDAVARIAVEL"]) ? $elemento["QTMEDIDAVARIAVEL"] : null,
            "QTMEDIDACALC"      => null,
            "VRTOTSAJUSTE"      => $valorTotal,
            "IDAPARECEPROPOSTA" => isset($elemento["IDAPARECEPROPOSTA"]) ? $elemento["IDAPARECEPROPOSTA"] : "S"
        );
        
        $this->propostaFactory->inserirElementosProposta($params);
    }
    
    public function getItemPropostaPorCodServico($nrseqorcamento, $nrtipoorcamento, $cdservorca, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRORG"           => $nrorg
        );
        
        $dataset = $this->propostaFactory->getItemPropostaPorCodServico($params);
        return (count($dataset) > 0) ? $dataset[0] : null;
    }
    
    public function getSomatoriaElementosComposicaoPropostaPorElementoRaiz($nrseqorcamento, $nrorg, $cdservorca) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg,
            "CDSERVORCA"     => $cdservorca
        );
        
        return $this->propostaFactory->getSomatoriaElementosComposicaoPropostaPorElementoRaiz($params);
    }
    
    public function excluirElementoAlteradoPeloUsuarioNaComposicaoServico($nrseqorcamento, $idelementopai, $nrtipoorcamento, $cdservorca, $nrtrabservorca, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRTRABSERVORCA"  => $nrtrabservorca,
            "NRORG"           => $nrorg
        );
        
        $this->propostaFactory->excluirElementoAlteradoPeloUsuarioNaComposicaoServico($params);
    }
    
    public function getElementosAlteradosPeloUsuarioNaComposicaoServico($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        return $this->propostaFactory->getElementosAlteradosPeloUsuarioNaComposicaoServico($params);
    }
    
    /*public function formatarElementosAlteradosParaInserir(array $elementosAlterados) {
        foreach ($elementosAlterados as &$elementoAlterado) {
            $elementoAlterado["CDSERVORCARELAC"] = $elementoAlterado["CDSERVORCA"];
            $elementoAlterado["QTMEDIDASERV"]    = $elementoAlterado["QTMEDSERVORCA"];
            $elementoAlterado["VRUNITARIO"]      = $elementoAlterado["VRUNITSERVORCA"];
            $elementoAlterado["VRPRECO"]         = $elementoAlterado["VRTOTSERVORCA"];
        }
        unset($elementoAlterado);
        
        return $elementosAlterados;
    }*/
    
    public function setValoresGridServicos(array $servicos) {
        foreach ($servicos as &$serv) {
            $serv["QTMEDIDASERV"]     = "";
            $serv["QTMEDIDACALC"]     = "";
            $serv["QTMEDIDAVARIAVEL"] = "";
            $serv["DSTPMEDIDASERV"]   = "";
            
            $serv["VRUNITITEMORCA_GRID"]  = $serv["VRUNITITEMORCA"];

            /*$serv["QTITEMORCAMENTO_GRID"] = $serv["QTITEMORCAMENTO"];
            $serv["QTMEDIDASERV_GRID"]    = $serv["QTMEDIDASERV"];
            $serv["DSTPMEDIDASERV_GRID"]  = $serv["DSTPMEDIDASERV"];
            $serv["VRUNITITEMORCA_GRID"]  = $serv["VRUNITITEMORCA"];
            $serv["VRTOTALITEMORCA_GRID"] = $serv["VRTOTALITEMORCA"];
            $serv["NMTIPOORCAMENTO_GRID"] = $serv["NMTIPOORCAMENTO"];*/
        }
        unset($serv);
        
        return $servicos;
    }
    
    public function setValoresGridItensMedida(array $itensMedida) {
        foreach ($itensMedida as &$item) {
            if ($item["IDMULTIPVARIACAO"] == "N")
                $item["QTMEDIDAVARIAVEL"] = "";
            
            /*$item["QTITEMORCAMENTO_GRID"] = $item["QTITEMORCAMENTO"];
            $item["QTMEDIDASERV_GRID"]    = $item["QTMEDIDASERV"];
            $item["DSTPMEDIDASERV_GRID"]  = $item["DSTPMEDIDASERV"];
            $item["VRUNITITEMORCA_GRID"]  = $item["VRUNITITEMORCA"];
            $item["VRTOTALITEMORCA_GRID"] = $item["VRTOTALITEMORCA"];
            $item["NMTIPOORCAMENTO_GRID"] = $item["NMTIPOORCAMENTO"];*/
        }
        unset($item);
        
        return $itensMedida;
    }
    
    public function getItensTipoIParaInserir(array $itens) {
        $novosItens = array();
        foreach ($itens as $item) {
            if ($item["IDTIPO"] == "I") {
                if (!isset($item["QTMEDIDASERV"]) || empty($item["QTMEDIDASERV"]))
                    $item["QTMEDIDASERV"] = 1;
                if (!isset($item["QTMEDIDACALC"]) || empty($item["QTMEDIDACALC"]))
                    $item["QTMEDIDACALC"] = 1;
                $novosItens[] = $item;
            }
        }
        return $novosItens;
    }
    
    public function getCaminhoDocumentoGeradoPDFProposta($nrseqorcadoc, $nrorg) {
        $params = array(
            "NRSEQORCADOC" => $nrseqorcadoc,
            "NRORG"        => $nrorg
        );
        
        $dataset = $this->propostaFactory->getCaminhoDocumentoGeradoPDFProposta($params);
        return $dataset[0]["DSCAMINHODOCGERADOPDF"];
    }
    
    /**
     * busca o código da filial do escopo do documento
    **/
    public function buscaFilialEscopoDocumento($nrtipoorcamento, $nrseqorcamento, $nrorg){
        if (!is_array($nrtipoorcamento)) {
            $nrtipoorcamento = array($nrtipoorcamento);
        }
        
        $nrtipoorcamento = implode(",", $nrtipoorcamento);
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRORG"           => $nrorg
        );
        
        return $this->propostaFactory->buscaFilialEscopoDocumento($params, $nrtipoorcamento);
    }
    
    /**
     * Altera o operador responsável de N propostas
    *
    public function salvaAlteracaoMassaOper($nrseqorcamento, $operador, $nrorg){
        $nrseqorcamento = implode(",", $nrseqorcamento);
        $params = array(
            "CDOPERRESPONSAVEL" => $operador,
            "NRORG"             => $nrorg
        );
        
        $this->propostaFactory->salvaAlteracaoMassaOper($params, $nrseqorcamento);
    }/*
    
    /**
     * Busca o código do prospect a partir do número do parceiro de negócio
    **/
    public function getProspectParceiro($nrparcnegocio, $nrorg){
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG"         => $nrorg
        );
        
        return $this->propostaFactory->getProspectParceiro($params);
    }
    
    /**
     * da um update na tabela de proposta para adicionat o numero do contato gerado
    **/
    public function alteraContatoProposta($nrseqorcamento, $nrorg, $nrcontato){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRCONTATO"      => $nrcontato,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->alteraContatoProposta($params);
    }
    
    /**
     * Retorna o nrorcamento
    **/
    public function getCodigoOrcamento($nrseqorcamento, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $result = $this->propostaFactory->getCodigoOrcamento($params);
        return count($result) > 0 ? $result[0] : null;
    }

    /**
     * Gera um contato para a proposta quando ela não está ligada a uma oportunidade de 
     * negócio.
    **/
    public function geraContato($nrseqorcamento, $nrtipoorcamento, $nrorg, $nrparcnegocio, $dsrefcont, $cdoperador, $nrparcinter){
        $prospect = $this->getProspectParceiro($nrparcnegocio, $nrorg);
        $cdfilial = null;
        
        if(!empty($nrtipoorcamento) || (is_array($nrtipoorcamento) && count($nrtipoorcamento) > 0)){
            $cdfilial = $this->buscaFilialEscopoDocumento($nrtipoorcamento, $nrseqorcamento, $nrorg);
            if(count($cdfilial) >= 1)
                $cdfilial = $cdfilial[0]["CDFILIAL"];
            else 
                $cdfilial = null;
        }
        
        if(!isset($dsrefcont))
            $dsrefcont = $this->getCodigoOrcamento($nrseqorcamento, $nrorg);

        $nrcontato = $this->newCode->getCodeByTableName("NRSEQCONTATO", $nrorg, 1, 10, true);
        $params =  array(
            "DSREFECONT"         => "Referente a Proposta " . $dsrefcont,
            "NRORG"              => $nrorg,
            "NRPARCNEGOCIO"      => $nrparcnegocio,
            "NRPARCINTERLOCUTOR" => $nrparcinter,
            "CDPROSPECT"         => isset($prospect["CDPROSPECT"]) ? $prospect[0]["CDPROSPECT"] : null,
            "NRSEQCONTATO"       => $nrcontato,
            "CDOPERADOR"         => $cdoperador,
            "CDCLIENTE"          => isset($prospect["CDCLIENTE"]) ? $prospect[0]["CDCLIENTE"] : null,
            "CDFILIAL"           => $cdfilial
        );
        $this->propostaFactory->geraContato($params);
        $this->alteraContatoProposta($nrseqorcamento, $nrorg, $nrcontato);
        return $nrcontato;
    }
    
    /**
     * deleta um contato gerado para uma proposta não ligada a uma oportunidade
    **/
    public function deletaContatoProposta($nrseqcontato, $nrorg){
        $params = array(
            "NRSEQCONTATO" => $nrseqcontato,
            "NRORG"        => $nrorg
        );
        
        $this->propostaFactory->deletaContatoProposta($params);
    }
    
    /**
     * inativa uma proposta e um contato com suas evoluções 
     * caso a proposta não seja apagada
    **/
    public function inativaPropContato($nrseqcontato, $nrseqorcamento, $nrorg){
        $paramsCont = array(
            "NRSEQCONTATO"   => $nrseqcontato,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->inativaContato($paramsCont);
        $this->propostaFactory->inativaEvolCont($paramsCont);
        
        $paramsProp = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->inativaProposta($paramsProp);
    }
    
    //Retorna "true" se converte, "false" se não converte
    public function verificaConverteProspectEmCliente($nrorg) {
        $params = array(
            "NRORG" => $nrorg
        );
        
        $dataset = $this->propostaFactory->getIdConverteProspectEmCliente($params);
        return ($dataset[0]["IDCONVCLIENTE"] == "S");
    }
    
    //Retorna "true" se o prospect já for cliente, "false" se não for
    public function validaClienteProspect($nrparcnegocio, $nrorg) {
        $params = array(
            "NRPARCNEGOCIO" => $nrparcnegocio,
            "NRORG"         => $nrorg
        );
        
        $dataset = $this->propostaFactory->getCountClienteProspect($params);
        return ((int)$dataset[0]["QTDE"] > 0);
    }

    /**
     * Retorna o parametro de autorização de 
     * geração de documentos em DOCX
    **/
    public function getParametroExtensaoDoc($nrseqorcamento, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );

        $result = $this->propostaFactory->getParametroExtensaoDoc($params);
        return isset($result) ? $result : "N";
    }
    
    /* Atualiza a conexão do banco de acordo com o connection enviado.
       Atualmente  utilizado para funcionamento da rotina "atualizarMedVariavelOM" do service "Sm00012000MedicaoFaturamentoService"*/
    public function atualizaConnection($connection){

        $this->connection = $connection;
        
        $this->propostaFactory->atualizaConnection($connection);
    }
    
    /**
     * Retorna os dados do documento da proposta de acordo com a situação
    **/
    public function getDadosDocumentoSituacao($nrseqorcamento, $nrorg, $idsituacao){
        $params = array(
            "IDSITUACAOORCAMENTO" => $idsituacao,
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "NRORG"               => $nrorg
        );
        return $this->propostaFactory->getDadosDocumentoSituacao($params);
    }

    /**
     * Atualiza os operadores responsaveis através da ação de 
     * alterar operadores das telas de contrato e prospect
    **/
    public function atualizaOperadorResponsavel($sql, $newcdoperador, $nrorg){
        try{
            $params = array(
                "NEWCDOPERADOR"     => $newcdoperador,
                "NRORG"             => $nrorg
            );
            $this->propostaFactory->atualizaOperadorResponsavel($params, $sql);
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    
    public function preencheParamFatProposta($nrseqorcamento, $escopos, $nrorg){
        try{
            
            $operador = $this->environment->getCdOperador();
            
            foreach ($escopos as $escopo){
                
                $paramsGetCapaFatu = array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRORG"           => $nrorg
                );
                
                $GetCapaFatu = $this->propostaFactory->getCapaFaturamento($paramsGetCapaFatu);    
                
                if (count($GetCapaFatu) != 0) {
                    
                    $nrcapaparamfatprop = $this->newCode->getCodeByTableName("NRCAPAPARAMFATPROP", $nrorg, 1, 10, true);
                    
                    $paramsSetCapaFatu = array(
                        "NRCAPAPARAMFATPROP" => $nrcapaparamfatprop,
                        "NRSEQORCAMENTO"     => $nrseqorcamento,
                        "NRGRUPOFATURA"      => $GetCapaFatu[0]["NRGRUPOFATURA"],
                        "CDPRODFATURA"       => $GetCapaFatu[0]["CDPRODFATURA"],
                        "CDFILIALFATURA"     => $GetCapaFatu[0]["CDFILIALFATURA"],
                        "NRPARCFATURA"       => $GetCapaFatu[0]["NRPARCFATURA"],
                        "IDTPFATURA"         => $GetCapaFatu[0]["IDTPFATURA"],
                        "QTPARCELASFATU"     => $GetCapaFatu[0]["QTPARCELASFATU"],
                        "IDTPCALCPARCINC"    => $GetCapaFatu[0]["IDTPCALCPARCINC"],
                        "IDGERARATEIO"       => $GetCapaFatu[0]["IDGERARATEIO"],
                        "IDAPURAAPONTAMENTO" => $GetCapaFatu[0]["IDAPURAAPONTAMENTO"],
                        "NRORG"              => $nrorg,
                        "OPERADOR"           => $operador 
                    );
                    
                    $this->propostaFactory->setCapaFaturamento($paramsSetCapaFatu);
                    
                };
            
            
                $paramsGetDadosFatu = array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRORG"           => $nrorg
                );
                
                $GetDadosFatu = $this->propostaFactory->getDadosFaturamento($paramsGetDadosFatu);   
                
                
                if (count($GetDadosFatu) != 0) {
                    
                    foreach ($GetDadosFatu as $dadosFatu){
                        
                        $nrparamfatprop = $this->newCode->getCodeByTableName("NRPARAMFATPROP", $nrorg, 1, 10, true);
                        
                        $paramsSetDadosFatu = array(
                            "NRPARAMFATPROP" => $nrparamfatprop,
                            "NRSEQORCAMENTO" => $nrseqorcamento,
                            "NRDIACOMPETINI" => $dadosFatu["NRDIACOMPETINI"],
                            "NRDIACOMPETFIN" => $dadosFatu["NRDIACOMPETFIN"],
                            "IDMESCOMPETINI" => $dadosFatu["IDMESCOMPETINI"],
                            "IDMESCOMPETFIN" => $dadosFatu["IDMESCOMPETFIN"],
                            "QTDIASAPURACAO" => $dadosFatu["QTDIASAPURACAO"],
                            "IDTPCALCVENC"   => $dadosFatu["IDTPCALCVENC"],
                            "NRDIACALCVENC"  => $dadosFatu["NRDIACALCVENC"],
                            "IDMESCALCVENC"  => $dadosFatu["IDMESCALCVENC"],
                            "QTDIASFATUVENC" => $dadosFatu["QTDIASFATUVENC"],
                            "NRORG"          => $nrorg,
                            "OPERADOR"       => $operador 
                        );
                        
                        $this->propostaFactory->setDadosFaturamento($paramsSetDadosFatu);
                    }
                    
                };
            };
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    /**
     * retorna se a arvore de elementos do serviço relacionado usa medida fixada
    **/
    public function getIdUsaMedidaFixada($idarvores, $nrorg, $cdservorca){
        $idarvores  = implode("','", $idarvores);
        $cdservorca = implode(",", $cdservorca);
        return $this->propostaFactory->getIdUsaMedidaFixada($idarvores, $nrorg, $cdservorca);
    }
    
    
     public function preencheParamItFatProposta($nrseqorcamento, $escopos, $nrorg){
        try{
            
            $operador = $this->environment->getCdOperador();
            
            foreach ($escopos as $escopo){
             
                $paramGetServicosEscopo = array(
                    "NRTIPOORCAMENTO" => $escopo,
                    "NRORG"           => $nrorg
                );
                
                $GetServicosEscopo = $this->propostaFactory->getServicosEscopo($paramGetServicosEscopo);   
                if (count($GetServicosEscopo) != 0) {
                    
                    foreach ($GetServicosEscopo as $servicos){
                        
                        $cdservorca = $servicos["CDSERVORCA"];
                        $nritescopoproposta = $servicos["NRITESCOPOPROPOSTA"];
                        
                        $paramsGetItProposta = array(
                            "NRSEQORCAMENTO" => $nrseqorcamento,
                            "CDSERVORCA"     => $cdservorca,
                            "NRORG"          => $nrorg
                        );
                        
                        $GetItProposta = $this->propostaFactory->getItProposta($paramsGetItProposta); 
                        
                        if (count($GetItProposta) != 0) {
                            
                            foreach ($GetItProposta as $itProposta){
                                
                                $nritemorcamento = $itProposta['NRITEMORCAMENTO'];
                                        
                                $paramsGetDadosItFatu = array(
                                    "NRTIPOORCAMENTO"    => $escopo,
                                    "NRITESCOPOPROPOSTA" => $nritescopoproposta,
                                    "NRORG"              => $nrorg
                                );
                                
                                $GetDadosItFatu = $this->propostaFactory->getDadosItFaturamento($paramsGetDadosItFatu);   
                                
                                
                                if (count($GetDadosItFatu) != 0) {
                                    
                                    foreach ($GetDadosItFatu as $dadosItFatu){
                                        
                                        $nrparamfatitprop = $this->newCode->getCodeByTableName("NRPARAMFATITPROP", $nrorg, 1, 10, true);

                                        $paramsSetDadosFatu = array(
                                            "NRPARAMFATITPROP" => $nrparamfatitprop,
                                            "NRITEMORCAMENTO"  => $nritemorcamento,
                                            "NRSEQORCAMENTO"   => $nrseqorcamento,
                                            "NRGRUPOFATURA"    => $dadosItFatu["NRGRUPOFATURA"],
                                            "CDPRODFATURA"     => $dadosItFatu["CDPRODFATURA"],
                                            "CDFILIALFATURA"   => $dadosItFatu["CDFILIALFATURA"],
                                            "NRPARCFATURA"     => $dadosItFatu["NRPARCFATURA"],
                                            "IDTPFATURA"       => $dadosItFatu["IDTPFATURA"],
                                            "QTPARCELASFATU"   => $dadosItFatu["QTPARCELASFATU"],
                                            "NRORG"            => $nrorg,
                                            "OPERADOR"         => $operador 
                                        );
                                        
                                        $this->propostaFactory->setDadosItFaturamento($paramsSetDadosFatu);
                                    }
                                
                                };
                            };
                        };
                    };
                };    
            };
                
        } catch(\Exception $e){
            throw $e;
        }
    }
    /**
     * Retorna as informações da variação de preço ligada a proposta
    **/
    public function getInformacoesVariacoesPreco($nrseqorcamento, $nrtipoorcamento, $nrorg, $nrmoeda = null) {
        $nrtipoorcamento = implode(",", $nrtipoorcamento);
        $params = array(
            "NRMOEDA"        => $nrmoeda,
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        return $this->propostaFactory->getInformacoesVariacoesPreco($params, $nrtipoorcamento);
    }
    /**
     * Salva as faixas de variação de preço ligadas a proposta no momento
     * em que ela foi concluida
    **/
    public function salvarVarPrecoOrcaConcluida($nrseqorcamento, $nrtipoorcamento, $nrorg, $cdoperador, $nrmoeda = null) {
        $infoVariacoes = $this->getInformacoesVariacoesPreco($nrseqorcamento, $nrtipoorcamento, $nrorg, $nrmoeda);
        $this->inserirVarPrecoOrcaConcluida($infoVariacoes, $nrseqorcamento, $cdoperador, $nrorg);
        $this->atualizarValoresVariacaoPrecoPropostaComServicosComMedicao($nrseqorcamento, $nrorg, $cdoperador);
    }
    
    public function inserirVarPrecoOrcaConcluida($infoVariacoes, $nrseqorcamento, $cdoperador, $nrorg){
        foreach ($infoVariacoes as $infoVariacao) {
            $nrvariacao = $this->newCode->getCodeByTableName("FCT_VARPRECBASESERVORCA", $nrorg, 1, 10, true);
            $params = array(
                "NRVARPRECBASESERVORCA" => $nrvariacao,
                "NRSEQORCAMENTO"        => $nrseqorcamento,
                "CDSERVORCA"            => $infoVariacao["CDSERVORCA"],
                "CDTPMEDIDASERV"        => $infoVariacao["CDTPMEDIDASERV"],
                "CDTPMEDIDAVARIAVEL"    => $infoVariacao["CDTPMEDIDAVARIAVEL"],
                "QTMEDIDAINIVARIACAO"   => $infoVariacao["QTMEDIDAINIVARIACAO"],
                "QTMEDIDAFIMVARIACAO"   => $infoVariacao["QTMEDIDAFIMVARIACAO"],
                "VRPRECOVARIACAO"       => $infoVariacao["VRPRECOVARIACAO"],
                "IDMULTIPVARIACAO"      => $infoVariacao["IDMULTIPVARIACAO"],
                "QTFRANQUIA"            => $infoVariacao["QTFRANQUIA"],
                "IDATIVO"               => "S",
                "NRORG"                 => $nrorg,
                "NRORGINCLUSAO"         => $nrorg,
                "CDOPERINCLUSAO"        => $cdoperador
            );
            $this->propostaFactory->salvarVarPrecoOrcaConcluida($params);
        }
    }
    
    public function atualizarValoresVariacaoPrecoPropostaComServicosComMedicao($nrseqorcamento, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $servicosComMedicao = $this->propostaFactory->getServicosComMedicao($params);
        $servicosPesquisados = array();
        
        foreach ($servicosComMedicao as $serv) {
            
            $params = array(
                "CDTPMEDIDAVARIAVEL" => $serv["CDTPMEDIDAVARIAVEL"],
                "CDOPERULTATU"       => $cdoperador,
                "NRORGULTATU"        => $nrorg,
                "NRSEQORCAMENTO"     => $nrseqorcamento,
                "NRORG"              => $nrorg,
                "CDSERVORCA"         => $serv["CDSERVORCA"]
            );
            
            $medidaIsNotNull = false;
            
            if (!in_array($serv["CDSERVORCA"], $servicosPesquisados)) {
                $qtd = $this->getQtdeVarPrecPropostaComMedidaVariavel($nrseqorcamento, $serv["CDSERVORCA"], $nrorg);
                if ($qtd > 0) {
                    $medidaIsNotNull = true;
                }
                
                $servicosPesquisados[] = $serv["CDSERVORCA"];
            }
            
            $this->propostaFactory->atualizarValorVariacaoPrecoServicoProposta($params, $medidaIsNotNull);
        }
    }
    
    public function getQtdeVarPrecPropostaComMedidaVariavel($nrseqorcamento, $cdservorca, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "CDSERVORCA"     => $cdservorca,
            "NRORG"          => $nrorg
        );
        $dataset = $this->propostaFactory->getQtdeVarPrecPropostaComMedidaVariavel($params);
        return (int)$dataset[0]["QTD"];
    }
    
    /**
     * Retorna as informações do servico ligado a proposta
    **/
    public function getInformacoesServicoMedida($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        return $this->propostaFactory->getInformacoesServicoMedida($params);
    }
    
    /**
     * Salva as informações do servico relacionado ao itens da proposta quando ela 
     * é concluida
    **/
    public function salvarServicoMedidaOrca($nrseqorcamento, $nrorg, $cdoperador) {
        $infoServicos = $this->getInformacoesServicoMedida($nrseqorcamento, $nrorg);
        $this->insereServicoMedidaOrca($infoServicos, $nrseqorcamento, $cdoperador, $nrorg);
    }
    public function insereServicoMedidaOrca(array $infoServicos, $nrseqorcamento, $cdoperador, $nrorg){
        foreach ($infoServicos as $infoServico) {
            $nrrelacserv = $this->newCode->getCodeByTableName("FCT_RELACSERVMEDIDAORCA", $nrorg, 1, 10, true);
            $params = array(
                "NRSERVMEDORCA"   => $nrrelacserv,
                "NRSEQORCAMENTO"  => $nrseqorcamento,
                "CDSERVORCA"      => $infoServico["CDSERVORCA"],
                "CDSERVORCARELAC" => $infoServico["CDSERVORCARELAC"],
                "CDTPMEDIDASERV"  => $infoServico["CDTPMEDIDASERV"],
                "QTMEDIDASERV"    => $infoServico["QTMEDIDASERV"],
                "IDMEDIDAFIXA"    => $infoServico["IDMEDIDAFIXA"],
                "NRORG"           => $nrorg,
                "IDATIVO"         => "S",
                "NRORGINCLUSAO"   => $nrorg,
                "CDOPERINCLUSAO"  => $cdoperador
            );
            $this->propostaFactory->salvarServicoMedidaOrca($params);
        }
    }
    /**
     * Manda salvar as informações do serviço relacionado e da variação de preço 
     * de um orcamento no momento em que foi concluído 
    **/
    public function salvarInfoServicoEPrecoOrca($nrseqorcamento, $nrtipoorcamento, $nrorg, $cdoperador, $nrmoeda = null) {
        $this->connection->beginTransaction();
        try {
            $this->salvarVarPrecoOrcaConcluida($nrseqorcamento, $nrtipoorcamento, $nrorg, $cdoperador, $nrmoeda);
            $this->salvarServicoMedidaOrca($nrseqorcamento, $nrorg, $cdoperador);
            $this->connection->commit();
        } catch(\Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
    /**
     * Valida se a quantidade de medida fornecida está de acordo com a tabela de variação
    **/
    public function validarVariacaoPreco($nrorg, $nrseqorcamento, $idSituacao, $cdservorca, $qtMedidaOrca, $cdmedidaserv){
        try{
            $faixaPrecVarAtual = null;
            $qtMedidaInicial   = 0;
            $qtMedidaFinal     = 0;
            if(is_array($cdservorca) && count($cdservorca) == 0)
                $cdservorca = $this->propostaFactory->getServicosRelacionadosOrca($nrseqorcamento, $nrorg);
            
            $params = array(
                "NRSEQORCAMENTO"        => $nrseqorcamento,
                "CDTPMEDIDASERV"        => $cdmedidaserv,
                "IDSITUACAOORCAMENTO"   => $idSituacao,
                "NRORG"                 => $nrorg
            );
            
            $variacoesOrca = $this->propostaFactory->getVariacoesLigadasAoOrcamento($params, $cdservorca);
            foreach ($variacoesOrca as $variacaoOrca) {
                if($variacaoOrca["QTMEDIDAINIVARIACAO"] <= $qtMedidaOrca && $qtMedidaOrca <= $variacaoOrca["QTMEDIDAFIMVARIACAO"]){
                    $faixaPrecVarAtual = $variacaoOrca;
                    break;
                } else {
                    if($variacaoOrca["QTMEDIDAINIVARIACAO"] < $qtMedidaInicial || $qtMedidaInicial == 0)
                        $qtMedidaInicial = $variacaoOrca["QTMEDIDAINIVARIACAO"];
                    if($variacaoOrca["QTMEDIDAFIMVARIACAO"] > $qtMedidaFinal)
                        $qtMedidaFinal = $variacaoOrca["QTMEDIDAFIMVARIACAO"];
                }
            }
            
            if(!$faixaPrecVarAtual)
                throw new \Exception("Operação bloqueada!<br>A quantidade de medida informada, está fora da faixa de valores permitida pela variação de preço ligada a essa proposta.<br>Limite permitido: de $qtMedidaInicial até $qtMedidaFinal");
    
            return $faixaPrecVarAtual;
        } catch(\Exception $e){
            throw $e;
        }
    }
    /**
     * Deleta os tipos de medida de um orcamento
    **/
    public function deletarTiposMedidaDaProposta($nrseqorcamento, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );

        $this->propostaFactory->deletarTiposMedidaDaProposta($params);
    }
    /**
     * Salva a informacões do servico relacionado e da variacao de preço
    **/
    public function inserirInformacoesVariacaoServ($composicoes, $nrorg, $nrseqorcamento, $cdoperador, $nrtipoorcamento){
        $composicoes    = implode(",", $this->getCodigoComposicaoArray($composicoes));
        $infoServicos   = $this->propostaFactory->getInfoServicoMedidaPropAceita($composicoes, $nrseqorcamento);
        $this->insereServicoMedidaOrca($infoServicos, $nrseqorcamento, $cdoperador, $nrorg);
        
        
        $nrtipoorcamento = implode(",", $nrtipoorcamento);
        $infoVariacoes   = $this->propostaFactory->getInfoVariacaoPropAceita($composicoes, $nrseqorcamento, $nrtipoorcamento);
        $this->inserirVarPrecoOrcaConcluida($infoVariacoes, $nrseqorcamento, $cdoperador, $nrorg);
    }

    public function prepararInserirParametrosFaturamentoItensProposta($nrseqorcamento, $nrorg) {
        $cdoperador = $this->environment->getCdOperador();
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $itens = $this->propostaFactory->getItensPaiProposta($params);

        foreach ($itens as $item) {
            $params = array(
                "NRTIPOORCAMENTO" => $item["NRTIPOORCAMENTO"],
                "CDSERVORCA"      => $item["CDSERVORCA"],
                "NRORG"           => $nrorg
            );

            $paramFatServicoEscopo = $this->propostaFactory->getParametrosFaturamentoServicoEscopo($params);
            if (count($paramFatServicoEscopo) > 0) {
                
                $nrparamfatitprop = $this->newCode->getCodeByTableName("FCT_PARAMFATITPROP", $nrorg, 1, 10, true);
                $row = array(
                    "NRPARAMFATITPROP" => $nrparamfatitprop,
                    "NRITEMORCAMENTO"  => $item["NRITEMORCAMENTO"],
                    "NRSEQORCAMENTO"   => $nrseqorcamento,
                    "NRGRUPOFATURA"    => $paramFatServicoEscopo[0]["NRGRUPOFATURA"],
                    "CDPRODFATURA"     => $paramFatServicoEscopo[0]["CDPRODFATURA"],
                    "CDFILIALFATURA"   => $paramFatServicoEscopo[0]["CDFILIALFATURA"],
                    "NRPARCFATURA"     => $paramFatServicoEscopo[0]["NRPARCFATURA"],
                    "IDTPFATURA"       => $paramFatServicoEscopo[0]["IDTPFATURA"],
                    "QTPARCELASFATU"   => $paramFatServicoEscopo[0]["QTPARCELASFATU"],
                    "IDATIVO"          => "S",
                    "NRORG"            => $nrorg,
                    "NRORGINCLUSAO"    => $nrorg,
                    "CDOPERINCLUSAO"   => $cdoperador
                );

                $this->propostaFactory->inserirParametrosFaturamentoItemProposta($row);
            }
        }
    }

    public function inserirNegociacaoProposta(array $escopos, $nrorcamentomodelo, array $itens, $nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->excluirTodasNegociacoesProposta($params);
        
        $cdoperador = $this->environment->getCdOperador();

        $escopos = implode(",", $escopos);
        
        $servicos = $itens[0]["CDSERVORCA"];
        for ($i = 1; $i < count($itens); $i++) {
            $servicos .= "," . $itens[$i]["CDSERVORCA"];
        }

        $params = array(
            "NRORCAMENTOMODELO" => $nrorcamentomodelo,
            "NRSEQORCAMENTO"    => $nrseqorcamento,
            "NRORG"             => $nrorg
        );
        $itensNegociacaoValores = $this->propostaFactory->getParametrosFaturamentoParaItensNegociacaoProposta($params, $escopos, $servicos);
        
        $codNegociacoesInseridas = array();

        $itemAnterior = array();
        foreach ($itensNegociacaoValores as $item) {
            
            if ($item["CDFILIALFATURA"] == null) {
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Unidade para Faturamento" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            }
            if ($item["CDTIPOOPERFATURA"] == null) {
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Tipo de Operação da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            }
            if ($item["CDSERIENF"] == null) {
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Série da Nota Fiscal" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo.');
            }
            /*if ($item["CDPRODFATURA"] == null) {
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Produto para Faturamento" não foi encontrado para o item "' . $item["NMITEMORCAMENTO"] . '". Favor conferir a parametrização de faturamento do Escopo ou do Serviço.');
            }*/

            $competencia = array();
            if ($item["IDTPFATURA"] != "P") {
                $params = array(
                    "NRTIPOORCAMENTO" => $item["NRTIPOORCAMENTO"],
                    "CDSERVORCA"      => $item["CDSERVORCA"],
                    "NRORG"           => $nrorg,
                );
                $competencia = $this->propostaFactory->getCompetenciaItemNegociacao($params);
            }

            $item["COMPETENCIA"] = print_r($competencia, true);
            
            if (self::itensNegociacaoSaoDiferentes($item, $itemAnterior)) {
                $nrnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                $params = array(
                    "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                    "NRSEQORCAMENTO"       => $nrseqorcamento,
                    "NRTIPOORCAMENTO"      => $item["NRTIPOORCAMENTO"],
                    "IDTPFATURA"           => $item["IDTPFATURA"],
                    "CDFILIALFATURA"       => $item["CDFILIALFATURA"],
                    "NRPARCFATURA"         => $item["NRPARCFATURA"],
                    "CDTIPOOPERFATURA"     => $item["CDTIPOOPERFATURA"],
                    "CDSERIENF"            => $item["CDSERIENF"],
                    "CDEMPRESA"            => $item["CDEMPRESA"],
                    "CDINSCESTA"           => $item["CDINSCESTA"],
                    "CDINSCMUNI"           => $item["CDINSCMUNI"],
                    "VRTOTITEM"            => 0,
                    "VRPERCDESCITEM"       => null,
                    "VRDESCITEM"           => null,
                    "VRTOTITEMCOMDESC"     => 0,
                    "IDATIVO"              => "S",
                    "NRORG"                => $nrorg,
                    "NRORGINCLUSAO"        => $nrorg,
                    "CDOPERINCLUSAO"       => $cdoperador,
                    "IDPREVCOBRFUT"        => $item["IDPREVCOBRFUT"],
                    "CDTRIBPRODPADR"       => $item["CDTRIBPRODPADR"]
                );
                $this->propostaFactory->inserirNegociacaoProposta($params);
                $codNegociacoesInseridas[] = $nrnegociacaoproposta;

                foreach ($competencia as $comp) {
                    $nrcompetencianegoprop = $this->newCode->getCodeByTableName("FCT_COMPETENCIANEGOPROP", $nrorg, 1, 10, true);
                    $params = array(
                        "NRCOMPETENCIANEGOPROP" => $nrcompetencianegoprop,
                        "NRNEGOCIACAOPROPOSTA"  => $nrnegociacaoproposta,
                        "NRDIACOMPETINI"        => $comp["NRDIACOMPETINI"],
                        "NRDIACOMPETFIN"        => $comp["NRDIACOMPETFIN"],
                        "IDMESCOMPETINI"        => $comp["IDMESCOMPETINI"],
                        "IDMESCOMPETFIN"        => $comp["IDMESCOMPETFIN"],
                        "QTDIASAPURACAO"        => $comp["QTDIASAPURACAO"],
                        "IDTPCALCVENC"          => $comp["IDTPCALCVENC"],
                        "NRDIACALCVENC"         => $comp["NRDIACALCVENC"],
                        "IDMESCALCVENC"         => $comp["IDMESCALCVENC"],
                        "QTDIASFATUVENC"        => $comp["QTDIASFATUVENC"],
                        "IDATIVO"               => "S",
                        "NRORG"                 => $nrorg,
                        "NRORGINCLUSAO"         => $nrorg,
                        "CDOPERINCLUSAO"        => $cdoperador
                    );
                    $this->propostaFactory->inserirCompetenciaNegociacaoProposta($params);
                }
            }
            
            if (is_string($item["VRTOTALITEMORCA"]))
                if (strpos($item["VRTOTALITEMORCA"], ',') !== false)
                    $item["VRTOTALITEMORCA"] = (float) str_replace(',', '.', str_replace(".", "", (string) $item["VRTOTALITEMORCA"]));
                    
            $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
            $params = array(
                "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                "NRITEMORCAMENTO"        => $item["NRITEMORCAMENTO"],
                "NRITEMORCAMENTOPAI"     => $item["NRITEMORCAMENTOPAI"],
                "VRTOTITEM"              => $item["VRTOTALITEMORCA"],
                "VRPERCDESCITEM"         => null,
                "VRDESCITEM"             => null,
                "VRTOTITEMCOMDESC"       => $item["VRTOTALITEMORCA"],
                "CDSERVORCA"             => $item["CDSERVORCA"],
                "CDPRODFATURA"           => $item["CDPRODFATURA"],
                "NRPARCFATURA"           => $item["NRPARCFATURA"],
                "IDATIVO"                => "S",
                "NRORG"                  => $nrorg,
                "NRORGINCLUSAO"          => $nrorg,
                "CDOPERINCLUSAO"         => $cdoperador
            );
            $this->propostaFactory->inserirItemNegociacaoProposta($params);

            $params = array(
                "NRSEQORCAMENTO"     => $nrseqorcamento,
                "NRITEMORCAMENTOPAI" => $item["NRITEMORCAMENTO"],
                "NRORG"              => $nrorg
            );
            $itensFilhos = $this->propostaFactory->getItensFilhosItemProposta($params);
            
            foreach ($itensFilhos as $filho) {
                $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                    
                $params = array(
                    "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                    "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                    "NRITEMORCAMENTO"        => $filho["NRITEMORCAMENTO"],
                    "NRITEMORCAMENTOPAI"     => $filho["NRITEMORCAMENTOPAI"],
                    "VRTOTITEM"              => $filho["VRTOTALITEMORCA"],
                    "VRPERCDESCITEM"         => null,
                    "VRDESCITEM"             => null,
                    "VRTOTITEMCOMDESC"       => $filho["VRTOTALITEMORCA"],
                    "CDSERVORCA"             => $filho["CDSERVORCA"],
                    "CDPRODFATURA"           => $item["CDPRODFATURA"],
                    "NRPARCFATURA"           => $item["NRPARCFATURA"],
                    "IDATIVO"                => "S",
                    "NRORG"                  => $nrorg,
                    "NRORGINCLUSAO"          => $nrorg,
                    "CDOPERINCLUSAO"         => $cdoperador
                );
                $this->propostaFactory->inserirItemNegociacaoProposta($params);
            }

            $itemAnterior = $item;
        }

        foreach ($codNegociacoesInseridas as $cod) {
            $this->atualizarValorNegociacaoComSomaDosItens($cod, $nrorg, $cdoperador);
        }
    }

    public static function itensNegociacaoSaoDiferentes($itemAtual, $itemAnterior) {
        if (count($itemAnterior) == 0) {
            return true;
        }
        else {
            if ($itemAtual["NRTIPOORCAMENTO"] == $itemAnterior["NRTIPOORCAMENTO"] &&
            $itemAtual["IDTPFATURA"] == $itemAnterior["IDTPFATURA"] &&            
            $itemAtual["CDTIPOOPERFATURA"] == $itemAnterior["CDTIPOOPERFATURA"] &&
            $itemAtual["CDSERIENF"] == $itemAnterior["CDSERIENF"] &&            
            $itemAtual["CDFILIALFATURA"] == $itemAnterior["CDFILIALFATURA"] &&
            $itemAtual["NRPARCFATURA"] == $itemAnterior["NRPARCFATURA"] &&
            $itemAtual["QTPARCELASFATU"] == $itemAnterior["QTPARCELASFATU"] &&
            $itemAtual["QTDIASAPURACAO"] == $itemAnterior["QTDIASAPURACAO"] &&
            $itemAtual["NRDIACALCVENC"] == $itemAnterior["NRDIACALCVENC"] &&
            $itemAtual["QTDIASFATUVENC"] == $itemAnterior["QTDIASFATUVENC"] &&
            $itemAtual["IDTPCALCVENC"] == $itemAnterior["IDTPCALCVENC"] &&
            $itemAtual["IDMESCALCVENC"] == $itemAnterior["IDMESCALCVENC"] &&
            $itemAtual["COMPETENCIA"] == $itemAnterior["COMPETENCIA"] &&
            $itemAtual["IDPREVCOBRFUT"] == $itemAnterior["IDPREVCOBRFUT"] &&
            $itemAtual["CDTRIBPRODPADR"] == $itemAnterior["CDTRIBPRODPADR"]) {
                return false;
            }
            else {
                return true;
            }
        }
    }
    
    public function buscarLinksDocumentosProposta($nrseqorcamento, $nrorg) {
        $links = array();
        $dataset = $this->getLinksDocumentosProposta($nrseqorcamento, $nrorg);
        foreach ($dataset as $row) {
            $links[] = $row["DSCAMINHOARQ"];
        }
        return $links;
    }

    public function parcelarNegociacaoPorIgual($nrnegociacaoproposta, $qtparcelas, $qtdiasintervalo, $nrdiavencimento, $qtcarenciadias, $vrtotitemcomdesc) {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();

        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        
        $this->propostaFactory->excluirParcelasNegociacao($params);

        $vrParcela = round((float)$vrtotitemcomdesc / $qtparcelas, 2);
        $sumParcelas = 0;

        $params = array(
            "NRPARCELANEGOPROP"    => null,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "QTDIASFATURAMENTO"    => null,
            "NRPARCELA"            => null,
            "NRDIAVENCIMENTO"      => $nrdiavencimento,
            "VRPARCELA"            => null,
            "IDATIVO"              => "S",
            "NRORG"                => $nrorg,
            "NRORGINCLUSAO"        => $nrorg,
            "CDOPERINCLUSAO"       => $cdoperador,
        );
        
        if ((empty($qtcarenciadias)) || ($qtcarenciadias == null)){
            
            $qtcarenciadias = 0;
        }
        
        $diasintervalo = 0;
        for ($i = 1; $i <= $qtparcelas; $i++) {
            if ($i == $qtparcelas)
                $vrParcela = $vrtotitemcomdesc - $sumParcelas;

            $params["NRPARCELANEGOPROP"] = $this->newCode->getCodeByTableName("FCT_PARCELANEGOPROP", $nrorg, 1, 10, true);
            $params["VRPARCELA"] = $vrParcela;
            
            if ($i == 1) {
                $diasintervalo = $qtdiasintervalo + $qtcarenciadias;
            }
            else {
                $diasintervalo = $diasintervalo + $qtdiasintervalo;
            }
            
            $params["QTDIASFATURAMENTO"] = $diasintervalo;
            $params["NRPARCELA"] = $i;
            $this->propostaFactory->inserirParcelaNegociacao($params);

            $sumParcelas += $vrParcela;
        }
    }

    public function validarValorNegociacoesValores($nrseqorcamento) {
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getNegociacoesValoresComSomaDasParcelas($params);
        foreach ($dataset as $row) {
            if ((float)$row["VRTOTITEMCOMDESC"] !== (float)$row["SOMA_PARCELAS"]) {
                return false;
            }
        }
        return true;
    }

    public function popularDatasFinaisDescontoPorPeriodoNegociacaoValores($dataAtual, $nrseqorcamento, $nrorg) {
        $params = array (
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $negociacoes = $this->propostaFactory->getNegociacoesProposta($params);
        
        foreach ($negociacoes as $nego) {
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $nego["NRNEGOCIACAOPROPOSTA"],
                "NRORG"                => $nrorg
            );
            $descontosPorPeriodo = $this->propostaFactory->getDescontosPorPeriodoDaNegociacao($params);
            $competencias        = $this->propostaFactory->getCompetenciaNegociacaoProposta($params);
            $dataFinal           = null;
            $dataInicialProxDesc = null;
            foreach ($descontosPorPeriodo as $desc) {
                $qtdParcelas  = $desc["QTMESESDESC"];
                $contador     = 1;
                
                while ($contador <= $qtdParcelas) {
                    foreach ($competencias as $comp) {
                        if ($dataFinal == null) { 
                            $dataAux = explode("/", $dataAtual);
                        } else {
                            if($dataInicialProxDesc == null) 
                                $dataAux = explode("/", $dataFinal->format("d/m/Y"));
                            else 
                                $dataAux = explode("/", $dataInicialProxDesc->format("d/m/Y"));
                        }
                        
                        if (checkdate($dataAux[1], $comp["NRDIACOMPETFIN"], $dataAux[2])) {
                            $dataFinal = DateUtil::getDataDeString(str_pad($comp["NRDIACOMPETFIN"], 2, "0", STR_PAD_LEFT) . "/" . $dataAux[1] . "/" . $dataAux[2]);
                        } else {
                            $dataFinal = DateUtil::getDataDeString("01/" . $dataAux[1] . "/" . $dataAux[2]);
                            $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                        }

                        /*if ($contador == 1 && $comp["IDMESCOMPETFIN"] == "1") {
                            if (checkdate($dataFinal->format("d"), $dataFinal->format("m")-1, $dataFinal->format("Y"))) {
                                $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                            }
                            else {
                                $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                                $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                            }
                        }
                        else */
                        if ($contador == 1 && $comp["IDMESCOMPETFIN"] == "3") {
                            if (checkdate($dataFinal->format("d"), $dataFinal->format("m")+1, $dataFinal->format("Y"))) {
                                $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                            } else {
                                $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                                $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                            }
                        }
                        
                        $contador++;
                    }
                    
                    if (checkdate($dataFinal->format("d"), $dataFinal->format("m")+1, $dataFinal->format("Y"))) {
                        $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                    } else {
                        $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")+1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                        $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                    }
                    
                    $dataInicialProxDesc = DateUtil::getDataDeString($dataFinal->format("d/m/Y"), DateUtil::FORMATO_BRASILEIRO);
                }

                if (checkdate($dataFinal->format("d"), $dataFinal->format("m")-1, $dataFinal->format("Y"))) {
                    $dataFinal = DateUtil::getDataDeString($dataFinal->format("d") . "/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                } else {
                    $dataFinal = DateUtil::getDataDeString("01/" . str_pad((int)$dataFinal->format("m")-1, 2, "0", STR_PAD_LEFT) . "/" . $dataFinal->format("Y"));
                    $dataFinal = DateUtil::getUltimoDiaDoMes($dataFinal);
                }
                
                //update negociacao com data final
                $paramsUpdate = array(
                    "DTFINALVALIDADEDESC"   => $dataFinal->format("d/m/Y"),
                    "NRDESCPERIODONEGOPROP" => $desc["NRDESCPERIODONEGOPROP"],
                    "NRORG"                 => $nrorg
                );
                $this->propostaFactory->atualizarDataFinalValidadeDescontoPorPeriodo($paramsUpdate);
            }
        }
        
        /*$params = array(
            "DTACEITE"       => $dataAceite,
            "NRORG"          => $nrorg,
            "NRSEQORCAMENTO" => $nrseqorcamento
        );
        
        $this->propostaFactory->atualizarDatasFinaisDescontoPorPeriodo($params);*/
    }

    /*public function replicarDescontoItensNegociacao($nrnegociacaoproposta, $vrdescitem) {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        $itens = $this->propostaFactory->getElementosItensNegociacao($params);
        $qtdeItens = count($itens);

        $valorDescontoDividido = round((float)$vrdescitem / $qtdeItens, 2);
        $somaValorDesconto = 0;
        foreach($itens as $indice => $item) {

            if ($qtdeItens == $indice + 1)
                $valorDescontoDividido = $vrdescitem - $somaValorDesconto;

            $percentualDesconto = round($valorDescontoDividido / (float)$item["VRTOTITEM"] * 100, 2);

            $params = array(
                "VRPERCDESCITEM"         => $percentualDesconto,
                "VRDESCITEM"             => $valorDescontoDividido,
                "VRTOTITEMCOMDESC"       => (float)$item["VRTOTITEM"] - $valorDescontoDividido,
                "CDOPERULTATU"           => $cdoperador,
                "NRORGULTATU"            => $nrorg,
                "NRITNEGOCIACAOPROPOSTA" => $item["NRITNEGOCIACAOPROPOSTA"],
                "NRORG"                  => $nrorg,
            );
            
            $this->propostaFactory->atualizarValorItemNegociacao($params);
            $somaValorDesconto += $valorDescontoDividido;
        }
    }*/

    public function atualizarValoresNegociacaoAoEditarElemento($nrnegociacaoproposta, $nritemorcamentopai) {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            //1- retorna a soma do valor dos elementos filhos do item
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRITEMORCAMENTOPAI"   => $nritemorcamentopai,
                "NRORG"                => $nrorg
            );
            $dataset = $this->propostaFactory->getSomaValorElementosItemNegociacao($params);
            $somaValoresItem = (float)$dataset[0]["VRTOTAL"];

            //2- atualiza o item pai com a soma dos filhos
            $params = array(
                "VRTOTITEM"            => $somaValoresItem,
                "CDOPERULTATU"         => $cdoperador,
                "NRORGULTATU"          => $nrorg,
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRITEMORCAMENTO"      => $nritemorcamentopai,
                "NRORG"                => $nrorg
            );
            $this->propostaFactory->atualizarValorItemNegociacao($params);

            //3- atualiza o valor da negociacao de valores com a soma dos itens
            $valor = $this->atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador);

            $this->connection->commit();

            //retorna o valor da negociacao de valoress
            return $valor;
        }
        catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function atualizarValoresDescontoPorPeriodoDaNegociacao($valorNegociacao, $nrnegociacaoproposta, $nrorg, $cdoperador) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );

        $dataset = $this->propostaFactory->getDescontosPorPeriodoDaNegociacao($params);
        foreach ($dataset as $row) {
            $params = array (
                "VRTOTITEM"             => $valorNegociacao,
                "CDOPERULTATU"          => $cdoperador,
                "NRORGULTATU"           => $nrorg,
                "NRDESCPERIODONEGOPROP" => $row["NRDESCPERIODONEGOPROP"],
                "NRORG"                 => $nrorg
            );
            $this->propostaFactory->atualizarValorDescontoPorPeriodoDaNegociacao($params);
        }
    }
    
    /**
     * Altera um item para um novo grupo de negociacao de valores
     */
    public function desagruparItemNegociacao($negociacao, $itemNegociacao) {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();

            //1- pega os elementos filhos do item da negociacao para usar depois
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $itemNegociacao["NRNEGOCIACAOPROPOSTA"],
                "NRORG"                => $nrorg,
                "NRITEMORCAMENTOPAI"   => $itemNegociacao["NRITEMORCAMENTO"]
            );
            $itensFilhos = $this->propostaFactory->getElementosItemNegociacao($params);

            //2- exclui o item da negociacao de valores junto com seus elementos filhos
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $itemNegociacao["NRNEGOCIACAOPROPOSTA"],
                "NRITEMORCAMENTO"      => $itemNegociacao["NRITEMORCAMENTO"],
                "NRORG"                => $nrorg
            );
            $this->propostaFactory->excluirItemNegociacaoComFilhos($params);

            //3- insere a nova negociacao
            $nrnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRSEQORCAMENTO"       => $negociacao["NRSEQORCAMENTO"],
                "NRTIPOORCAMENTO"      => $negociacao["NRTIPOORCAMENTO"],
                "IDTPFATURA"           => $negociacao["IDTPFATURA"],
                "CDFILIALFATURA"       => $negociacao["CDFILIALFATURA"],
                "NRPARCFATURA"         => $itemNegociacao["NRPARCFATURA"],
                "CDTIPOOPERFATURA"     => $negociacao["CDTIPOOPERFATURA"],
                "CDSERIENF"            => $negociacao["CDSERIENF"],
                "CDEMPRESA"            => $negociacao["CDEMPRESA"],
                "CDINSCESTA"           => $negociacao["CDINSCESTA"],
                "CDINSCMUNI"           => $negociacao["CDINSCMUNI"],
                "VRTOTITEM"            => 0,
                "VRPERCDESCITEM"       => null,
                "VRDESCITEM"           => null,
                "VRTOTITEMCOMDESC"     => 0,
                "IDATIVO"              => "S",
                "NRORG"                => $nrorg,
                "NRORGINCLUSAO"        => $nrorg,
                "CDOPERINCLUSAO"       => $cdoperador,
                "IDPREVCOBRFUT"        => $negociacao["IDPREVCOBRFUT"],
                "CDTRIBPRODPADR"       => $negociacao["CDTRIBPRODPADR"]
            );
            $this->propostaFactory->inserirNegociacaoProposta($params);

            //4- insere o item na nova negociacao
            $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
            
            if (is_string($itemNegociacao["VRTOTITEMCOMDESC"]))
                if (strpos($itemNegociacao["VRTOTITEMCOMDESC"], ',') !== false)
                    $itemNegociacao["VRTOTITEMCOMDESC"] = (float) str_replace(',', '.', str_replace(".", "", (string) $itemNegociacao["VRTOTALITEMORCA"]));
                        
            $params = array(
                "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                "NRITEMORCAMENTO"        => $itemNegociacao["NRITEMORCAMENTO"],
                "NRITEMORCAMENTOPAI"     => $itemNegociacao["NRITEMORCAMENTOPAI"],
                "VRTOTITEM"              => $itemNegociacao["VRTOTITEMCOMDESC"],
                "VRPERCDESCITEM"         => $itemNegociacao["VRPERCDESCITEM"],
                "VRDESCITEM"             => $itemNegociacao["VRDESCITEM"],
                "VRTOTITEMCOMDESC"       => $itemNegociacao["VRTOTITEMCOMDESC"],
                "CDSERVORCA"             => $itemNegociacao["CDSERVORCA"],
                "CDPRODFATURA"           => $itemNegociacao["CDPRODFATURA"],
                "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
                "IDATIVO"                => "S",
                "NRORG"                  => $nrorg,
                "NRORGINCLUSAO"          => $nrorg,
                "CDOPERINCLUSAO"         => $cdoperador
            );
            $this->propostaFactory->inserirItemNegociacaoProposta($params);
            
            //5- insere os elementos filhos do item na nova negociacao
            foreach ($itensFilhos as $filho) {
                $nritnegociacaoproposta = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOPROPOSTA", $nrorg, 1, 10, true);
                
                $params = array(
                    "NRITNEGOCIACAOPROPOSTA" => $nritnegociacaoproposta,
                    "NRNEGOCIACAOPROPOSTA"   => $nrnegociacaoproposta,
                    "NRITEMORCAMENTO"        => $filho["NRITEMORCAMENTO"],
                    "NRITEMORCAMENTOPAI"     => $filho["NRITEMORCAMENTOPAI"],
                    "VRTOTITEM"              => $filho["VRTOTITEM"],
                    "VRPERCDESCITEM"         => $filho["VRPERCDESCITEM"],
                    "VRDESCITEM"             => $filho["VRDESCITEM"],
                    "VRTOTITEMCOMDESC"       => $filho["VRTOTITEMCOMDESC"],
                    "CDSERVORCA"             => $filho["CDSERVORCA"],
                    "CDPRODFATURA"           => $itemNegociacao["CDPRODFATURA"],
                    "NRPARCFATURA"           => $itemNegociacao["NRPARCFATURA"],
                    "IDATIVO"                => "S",
                    "NRORG"                  => $nrorg,
                    "NRORGINCLUSAO"          => $nrorg,
                    "CDOPERINCLUSAO"         => $cdoperador
                );
                $this->propostaFactory->inserirItemNegociacaoProposta($params);
            }
            
            //6- atualiza o valor da negociacao nova com a soma dos itens
            $this->atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador);

            //7- atualiza o valor da negociacao antiga com a soma dos itens
            $valor = $this->atualizarValorNegociacaoComSomaDosItens($itemNegociacao["NRNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);

            $this->atualizarValorProposta($negociacao["NRSEQORCAMENTO"], $nrorg);

            $this->connection->commit();

            return $valor;
        }
        catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    /**
     * Valida se o modelo de contrato ligado ao modelo de proposta está ativo
    **/
    public function validarModeloContrato($nrseqorcamento, $nrorg) {
        try {
            $params = array(
                "NRSEQORCAMENTO" => $nrseqorcamento,
                "NRORG"          => $nrorg
            );
            $modeloAtivo = $this->propostaFactory->getTotalModelosAtivos($params);
            if($modeloAtivo[0]["MODELOS"] == 0) 
                throw new \Exception("Operação bloqueada!<br>Falha ao aceitar a proposta. Não foram encontrados modelos de contratos ativos vinculados ao modelo de proposta deste orçamento. Verifique as parametrizações e tente novamente.");
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    
    /* Insere o endereço principal do parceiro de negócio na proposta */
    public function inserirEnderecoProposta($nrseqorcamento, $parcNegocio, $nrorg){
        
        $params = array(
            "NRPARCNEGOCIO" => $parcNegocio,
            "NRORG"         => $nrorg
        );
            
        $valEndereco = $this->propostaFactory->buscaEnderecoProposta($params);
        
        if (count($valEndereco) > 0) {
    
            $nrEnderecoOrca = $this->newCode->getCodeByTableName("NRENDERECOORCA", $nrorg, 1, 10, true);
            $nrEnderecoParc = $valEndereco[0]["NRENDERECOPARC"];
            $cdoperador = $this->environment->getCdOperador();
            
            $paramsIns = array(
                "NRENDERECOORCA" => $nrEnderecoOrca,  
                "NRSEQORCAMENTO" => $nrseqorcamento,
                "NRORG"          => $nrorg,
                "CDOPERADOR"     => $cdoperador, 
                "NRPARCNEGOCIO"  => $parcNegocio,
                "NRENDERECOPARC" => $nrEnderecoParc
            );
            
            $this->propostaFactory->inserirEnderecoProposta($paramsIns);
            
        }    
        
    }
    
    /* Insere os itens padrão do modelo da proposta na proposta */
    public function inserirItensPadraoProposta($nrseqorcamento, $modelo, $nrorg){
        
        $dataAtual = date_create();
        $dataAtual = date_create_from_format("d/m/Y", $dataAtual->format("d/m/Y"));
        $cdoperador = $this->environment->getCdOperador();
        
        $params = array(
            "NRORCAMENTOMODELO" => $modelo,
            "NRORG"             => $nrorg
        );
            
        $valComposicao = $this->propostaFactory->validaUtilizaComposicao($params);
        
        if (count($valComposicao) > 0 && $valComposicao[0]["IDUTILIZACOMP"] == "N") {
        
            $params = array(
                "NRORCAMENTOMODELO" => $modelo,
                "NRORG"             => $nrorg
            );
                
            $itensPai = $this->propostaFactory->ListaItensPadroesPai($params);
            
            if (count($itensPai) > 0) {  
                
                foreach ($itensPai as $itemPai) {
                     
                    $vrunitario = $itemPai["VRUNITITEMORCA"];
                    $quantidade = $itemPai["QTITEMORCAMENTO"];
                    $medida     = $itemPai["QTMEDIDAORCA"];
                    
                    if ($itemPai["IDMULTMEDVRTOT"] == 'S') {
                        
                        if ((!empty($medida)) || ($medida == null) ||($medida == 0)){
                            $medida = 1;
                        }

                        $vrtotalitem = $vrunitario * $quantidade* $medida;
                    }
                    else{
                        
                        $vrtotalitem = $itemPai["VRTOTALITEMORCA"];
                    }
                    
                    $nritemorcamentoPai = $this->newCode->getCodeByTableName("NRITEMORCAMENTO", $nrorg, 1, 10, true);
                    
                    $paramsitPai= array(
                        "CDSERVORCA"            => $itemPai["CDSERVORCA"],
                        "CDPRODUTO"             => $itemPai["CDPRODUTO"],
                        "NMITEMORCAMENTO"       => $itemPai["NMITEMORCAMENTO"],
                        "QTITEMORCAMENTO"       => $quantidade,
                        "CDTPMEDIDASERV"        => $itemPai["CDTPMEDIDASERV"],
                        "QTMEDIDAORCA"          => $medida,
                        "VRUNITITEM"            => $vrunitario,
                        "VRTOTALITEM"           => $vrtotalitem,
                        "IDFATURAORCA"          => $itemPai["IDFATURAORCA"],
                        "CDMODPGTO"             => $itemPai["CDMODPGTO"],
                        "IDITEMOBRIGORCA"       => $itemPai["IDITEMOBRIGORCA"],
                        "IDSOMASUBITENS"        => $itemPai["IDSOMASUBITENS"],
                        "IDSOMANOITEMPAI"       => $itemPai["IDSOMANOITEMPAI"],
                        "NRORG"                 => $nrorg,
                        "CDOPERADOR"            => $cdoperador,
                        "IDSOMANOTOTALORCA"     => $itemPai["IDSOMANOTOTALORCA"],
                        "NRITEMPAI"             => null,
                        "NRSEQORCAMENTO"        => $nrseqorcamento,
                        "NRITEMORCAMENTO"       => $nritemorcamentoPai,
                        "NRGRUPOFATURA"         => $itemPai["NRGRUPOFATURA"],
                        "IDIMPRESSAOORCA"       => $itemPai["IDIMPRESSAOORCA"],
                        "SGUNIDADE"             => $itemPai["SGUNIDADE"],
                        "IDTRANSPORTADORA"      => $itemPai["IDTRANSPORTADORA"],
                        "IDADICCOBRITEMORC"     => $itemPai["IDADICCOBRITEMORC"],
                        "IDADICITEMORC"         => $itemPai["IDADICITEMORC"],
                        "IDBLOQALTORC"          => $itemPai["IDBLOQALTORC"],
                        "IDMULTMEDVRTOT"        => $itemPai["IDMULTMEDVRTOT"],
                        "DTINIFATURAMENTO"      => $itemPai["DTINIFATURAMENTO"],
                        "NRTIPOHIERARQSERV"     => $itemPai["NRTIPOHIERARQSERV"],
                        "QTPARCELASFATU"        => $itemPai["QTPARCELASFATU"],
                        "NRDIAVENCPARCELASFATU" => $itemPai["NRDIAVENCPARCELASFATU"]
                    );
                    
                    $this->propostaFactory->insereItensPadrao($paramsitPai);
                    
                    $params = array(
                        "NRORCAMENTOMODELO" => $modelo,
                        "NRORG"             => $nrorg,
                        "NRITEMORCAMODELO"  => $nritemorcamentoPai
                    );
                        
                    $itensAdic = $this->propostaFactory->ListaItensPadroesAdic($params);
                    
                    if (count($itensAdic) > 0) {  
                
                        foreach ($itensAdic as $itemAdic) {
                            
                            $vrunitario = $itemAdic["VRUNITITEMORCA"];
                            $quantidade = $itemAdic["QTITEMORCAMENTO"];
                            $medida     = $itemAdic["QTMEDIDAORCA"];
                            
                            if ($itemAdic["IDMULTMEDVRTOT"] == 'S') {
                                
                                if ((!empty($medida)) || ($medida == null) ||($medida == 0)){
                                    $medida = 1;
                                }
        
                                $vrtotalitem = $vrunitario * $quantidade* $medida;
                            }
                            else{
                                
                                $vrtotalitem = $itemAdic["VRTOTALITEMORCA"];
                            }
                        
                            $nritemorcamentoAdic = $this->newCode->getCodeByTableName("NRITEMORCAMENTO", $nrorg, 1, 10, true);
                            
                            $paramsitAdic = array(
                                "CDSERVORCA"            => $itemAdic["CDSERVORCA"],
                                "CDPRODUTO"             => $itemAdic["CDPRODUTO"],
                                "NMITEMORCAMENTO"       => $itemAdic["NMITEMORCAMENTO"],
                                "QTITEMORCAMENTO"       => $quantidade,
                                "CDTPMEDIDASERV"        => $itemAdic["CDTPMEDIDASERV"],
                                "QTMEDIDAORCA"          => $medida,
                                "VRUNITITEM"            => $vrunitario,
                                "VRTOTALITEM"           => $vrtotalitem,
                                "IDFATURAORCA"          => $itemAdic["IDFATURAORCA"],
                                "CDMODPGTO"             => $itemAdic["CDMODPGTO"],
                                "IDITEMOBRIGORCA"       => $itemAdic["IDITEMOBRIGORCA"],
                                "IDSOMASUBITENS"        => $itemAdic["IDSOMASUBITENS"],
                                "IDSOMANOITEMPAI"       => $itemAdic["IDSOMANOITEMPAI"],
                                "NRORG"                 => $nrorg,
                                "CDOPERADOR"            => $cdoperador,
                                "IDSOMANOTOTALORCA"     => $itemAdic["IDSOMANOTOTALORCA"],
                                "NRITEMPAI"             => $nritemorcamentoPai,
                                "NRSEQORCAMENTO"        => $nrseqorcamento,
                                "NRITEMORCAMENTO"       => $nritemorcamentoAdic,
                                "NRGRUPOFATURA"         => $itemAdic["NRGRUPOFATURA"],
                                "IDIMPRESSAOORCA"       => $itemAdic["IDIMPRESSAOORCA"],
                                "SGUNIDADE"             => $itemAdic["SGUNIDADE"],
                                "IDTRANSPORTADORA"      => $itemAdic["IDTRANSPORTADORA"],
                                "IDADICCOBRITEMORC"     => $itemAdic["IDADICCOBRITEMORC"],
                                "IDADICITEMORC"         => $itemAdic["IDADICITEMORC"],
                                "IDBLOQALTORC"          => $itemAdic["IDBLOQALTORC"],
                                "IDMULTMEDVRTOT"        => $itemAdic["IDMULTMEDVRTOT"],
                                "DTINIFATURAMENTO"      => $itemPai["DTINIFATURAMENTO"],
                                "NRTIPOHIERARQSERV"     => $itemAdic["NRTIPOHIERARQSERV"],
                                "QTPARCELASFATU"        => $itemAdic["QTPARCELASFATU"],
                                "NRDIAVENCPARCELASFATU" => $itemAdic["NRDIAVENCPARCELASFATU"]
                            );
                            
                            $this->propostaFactory->insereItensPadrao($paramsitAdic);
                            
                        }
                    }  
                }
            } 
        }
    }
    
    public function atualizaValorProposta($nrseqorcamento, $nrorg){
      
       $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );

        $this->propostaFactory->atualizaValorProposta($params);  
        
    }
    
    
    /* Insere os documentos da proposta */
    public function inserirDocumentosProposta($nrseqorcamento, $modelo, $nrorg, $cdoperador) {
        $params = array(
            "NRORCAMENTOMODELO" => $modelo,
            "NRORG"             => $nrorg
        );
        
        // 1- buscar os documentos ligados aos escopos do modelo de proposta
        $documentos = $this->propostaFactory->getDocumentosModProposta($params);
        foreach ($documentos as $doc) {
            $nome    = $doc["NMARQUIVO"];
            $caminho = $doc["DSCAMINHOARQ"];
            $tipo    = $doc["DSTIPO"];
            $tamanho = $doc["VRTAMANHO"];
            
            $nomeNovo    = null;
            $caminhoNovo = null;
            $tamanhoNovo = null;
            $tipoNovo    = null;

            if (!empty($caminho)) {
                $arquivoDoc = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $caminho, $nrorg);
                if ($arquivoDoc !== false) {
                    $arquivoDoc = base64_encode($arquivoDoc);
                    
                    // 2- anexar uma cópia do documento
                    $docNovo = $this->anexaOrcamentoDoc($arquivoDoc, $nome, $tipo, $tamanho);
                    
                    $nomeNovo    = $docNovo["name"];
                    $caminhoNovo = $docNovo["path"];
                    $tamanhoNovo = $docNovo["size"] / 1024;
                    $tipoNovo    = $docNovo["type"];
                }
            }

            // 3- inserir o documento cópia na proposta
            $nrseqorcadoc = $this->newCode->getCodeByTableName("NRSEQORCADOC", $nrorg, 1, 10, true);
            $paramsIns = array(
                "NRSEQORCADOC"        => $nrseqorcadoc,   
                "NRSEQORCAMENTO"      => $nrseqorcamento,
                "NRSEQMODDOCFCT"      => $doc["NRSEQMODDOCFCT"],
                "IDMODPADRAO"         => "N",//$docPadrao,
                "NRORG"               => $nrorg,
                "CDOPERADOR"          => $cdoperador,
                "NMARQUIVO"           => $nomeNovo,
                "DSCAMINHOARQ"        => $caminhoNovo,
                "DSTIPO"              => $tipoNovo,
                "VRTAMANHO"           => $tamanhoNovo,
                "IDSITUACAOORCAMENTO" => null, //$doc["IDSITUACAOORCAMENTO"],
                "NRTIPOORCAMENTO"     => $doc["NRTIPOORCAMENTO"],
                "VRTAMANHOLOGO"       => $doc["VRTAMANHOLOGO"]
            );
            
            $this->propostaFactory->inserirDocumentosProposta($paramsIns);

            // 4- insere as situacoes de proposta habilitadas para esde documento
            $situacoes = explode(",", $doc["IDSITUACAOORCAMENTO"]);
            $this->inserirSituacaoDocumentoProposta($situacoes, $nrseqorcadoc, $nrorg, $cdoperador);
            
            // 5- busca os anexos por idioma
            $this->inserirAnexosIdioma($doc, $nrseqorcadoc, $nomeNovo, $caminhoNovo, $tamanhoNovo, $tipoNovo, $nrorg, $cdoperador);
        }
    }

    public function inserirSituacaoDocumentoProposta(array $situacoes, $nrseqorcadoc, $nrorg, $cdoperador) {
        $params = [
            "NRORCAMENTODOCSITU"  => null,
            "NRSEQORCADOC"        => $nrseqorcadoc,
            "IDSITUACAOORCAMENTO" => null,
            "IDATIVO"             => "S",
            "NRORG"               => $nrorg,
            "NRORGINCLUSAO"       => $nrorg,
            "CDOPERINCLUSAO"      => $cdoperador
        ];

        foreach ($situacoes as $situacao) {
            $params["NRORCAMENTODOCSITU"] = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCSITU", $nrorg, 1, 10, true);
            $params["IDSITUACAOORCAMENTO"] = $situacao;
            $this->propostaFactory->inserirSituacaoDocumentoProposta($params);
        }
    }

    public function inserirAnexosIdioma($doc, $nrseqorcadoc, $nomeArqivoOrcaDoc, $caminhoArqivoOrcaDoc, $tamanhoArqivoOrcaDoc, $tipoArqivoOrcaDoc, $nrorg, $cdoperador) {
        $anexosIdioma = $this->getAnexosModeloDocumentoPorIdioma($doc["NRSEQMODDOCFCT"]);
        foreach ($anexosIdioma as $anexo) {
            if (!empty($anexo["DSCAMINHOARQ"])) {
                if ($anexo["DSCAMINHOARQ"] == $doc["DSCAMINHOARQ"]) {
                    $nomeAnexo    = $nomeArqivoOrcaDoc;
                    $caminhoAnexo = $caminhoArqivoOrcaDoc;
                    $tipoAnexo    = $tipoArqivoOrcaDoc;
                    $tamanhoAnexo = $tamanhoArqivoOrcaDoc;
                }
                else {
                    $arquivoDocIdioma = $this->smdocumentos->getDocumentoFileServer($this->fileServerBaseUrl . $anexo["DSCAMINHOARQ"], $nrorg);
                    if ($arquivoDocIdioma !== false) {
                        $arquivoDocIdioma = base64_encode($arquivoDocIdioma);

                        $anexoNovo = $this->anexaOrcamentoDoc($arquivoDocIdioma, $anexo["NMARQUIVO"], $anexo["DSTIPO"], $anexo["VRTAMANHO"]);
                        $nomeAnexo    = $anexoNovo["name"];
                        $caminhoAnexo = $anexoNovo["path"];
                        $tipoAnexo    = $anexoNovo["type"];
                        $tamanhoAnexo = $anexoNovo["size"] / 1024;
                    }
                }
                
                $nrorcamentodocidioma = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCIDIOMA", $nrorg, 1, 10, true);
                $params = array(
                    "NRORCAMENTODOCIDIOMA" => $nrorcamentodocidioma,
                    "NRSEQORCADOC"         => $nrseqorcadoc,
                    "CDIDIOM"              => $anexo["CDIDIOM"],
                    "NMARQUIVO"            => $nomeAnexo,
                    "DSCAMINHOARQ"         => $caminhoAnexo,
                    "DSTIPO"               => $tipoAnexo,
                    "VRTAMANHO"            => $tamanhoAnexo,
                    "IDATIVO"              => "S",
                    "NRORG"                => $nrorg,
                    "NRORGINCLUSAO"        => $nrorg,
                    "CDOPERINCLUSAO"       => $cdoperador
                );

                $this->propostaFactory->inserirAnexosDocumentoPropostaPorIdioma($params);
            }
        }
    }
    
    public function getQuantidadeItensNegociacaoProposta($nrnegociacaoproposta, $nrorg) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        $dataset = $this->propostaFactory->getQuantidadeItensNegociacaoProposta($params);
        return (int)$dataset[0]["QTDE"];
    }

    public function atualizarParceiroNegociacoesProposta($nrseqorcamento, $nrparcnegocio) {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        $params = array(
            "NRPARCFATURA"   => $nrparcnegocio,
            "NRORGULTATU"    => $nrorg,
            "CDOPERULTATU"   => $cdoperador,
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $this->propostaFactory->atualizarParceiroNegociacoesProposta($params);
        $this->propostaFactory->atualizarParceiroItensNegociacoesProposta($params);
    }

    public function validaPropReneg($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
    
        $valida = $this->propostaFactory->validaPropReneg($params);
        return $valida[0];
    }
    /**
     * Retorna a competencia ligada a uma negociação
    **/
    public function getCompetenciaNegociacaoProposta($nrnegociacaoproposta, $nrorg) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        return $this->propostaFactory->getCompetenciaNegociacaoProposta($params);
    }
    /**
     * valida a quantidade maxima de parcelas numa negociacao de valores
    **/
    public function validarQuantidadeMaxParcelas($nrtipoorcamento, $nrnegociacaoproposta, $cdoperador, $nrorg) {
        $params = array(
            "CDOPERADOR" => $cdoperador,
            "NRORG"      => $nrorg
        );
        
        $dataOperador = $this->propostaFactory->getQuantidadeMaxParcelasOper($params);
        if(count($dataOperador) == 0)
            $dataOperador = $this->propostaFactory->getQuantidadeMaxParcelasPerfil($params);
        
        if(count($dataOperador) > 0 && $dataOperador[0]["QTPARCMAXIMA"]) {
            return $dataOperador[0]["QTPARCMAXIMA"];
        } else {
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRORG"                => $nrorg,
                "NRTIPOORCAMENTO"      => $nrtipoorcamento,
            );
            $dataEscopo = $this->propostaFactory->getQtMaxParcelasItemEscopo($params);
            
            if(count($dataEscopo) == 0 || !$dataEscopo[0]["QTPARCELASFATU"]) {
                $params = array(
                    "NRTIPOORCAMENTO" => $nrtipoorcamento,
                    "NRORG"           => $nrorg
                );
                $dataEscopo = $this->propostaFactory->getQtMaxParcelasEscopo($params);
            }
        
            return $dataEscopo[0]["QTPARCELASFATU"];
        }
    }
    /**
     * Valida a quantidade de parcelas inseridas atualmente na negociação
    **/
    public function validarQuantidadeParcelasInseridas($nrnegociacaoproposta, $nrmaxparcelas, $nrorg) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        $parcelasInseridas = $this->propostaFactory->getParcelasNegociacao($params);
        if(count($parcelasInseridas) >= $nrmaxparcelas)
            return "LIMITE_PARC_INSERIDO" . " " . $nrmaxparcelas;
        else return (string) $nrmaxparcelas;
    }

    /**
     * Atualiza o valor da negociação de valores com a soma do itens e retorna o valor total sem desconto.
     * 
     * @param integer $nrnegociacaoproposta
     * @param integer $nrorg
     * @param string  $cdoperador
     * 
     * @return float
    **/
    public function atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        $soma = $this->propostaFactory->getSomaValorItensNegociacao($params);
        $soma = $soma[0]["VRTOTAL"];

        if (is_null($soma)) {
            $this->propostaFactory->excluirNegociacaoProposta($params);
        } else {
            $params = array(
                "VRTOTAL"              => $soma,
                "CDOPERULTATU"         => $cdoperador,
                "NRORGULTATU"          => $nrorg,
                "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                "NRORG"                => $nrorg
            );
            $this->propostaFactory->atualizarValorNegociacaoComSomaDosItens($params);
    
            // Atualiza os registros da aba de Desconto por Periodo com o valor novo
            $this->atualizarValoresDescontoPorPeriodoDaNegociacao($soma, $nrnegociacaoproposta, $nrorg, $cdoperador);
        }
        
        return $soma;
    }

    /**
     * Atualiza o valor de todas as negociaçções de valores da proposta com a soma do itens.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     * @param string  $cdoperador
    **/
    public function atualizarValorTodasNegociacoesComSomaDosItens($nrseqorcamento, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $negociacoes = $this->propostaFactory->getNegociacoesProposta($params);
        foreach ($negociacoes as $nego) {
            $this->atualizarValorNegociacaoComSomaDosItens($nego["NRNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);
        }
    }

    public function reajustarParcelasNegociacao($nrseqorcamento, $nrnegociacaoproposta, $nrorg, $cdoperador) {
        $params = array(
            "NRSEQORCAMENTO"       => $nrseqorcamento,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        $dataset = $this->propostaFactory->getValorNegociacaoComSomaParcelas($params);
        
        if (count($dataset) > 0) {
            $valorNegociacao = $dataset[0]["VRTOTITEMCOMDESC"];
            $somaParcelas = $dataset[0]["SOMA_PARCELAS"];
            if (!is_null($somaParcelas) && $valorNegociacao != $somaParcelas) {
                $diferenca = $valorNegociacao - $somaParcelas;
                $percentual = $diferenca / $somaParcelas * 100;

                $params = array(
                    "VRPERCENTUAL"         => $percentual,
                    "NRORGULTATU"          => $nrorg,
                    "CDOPERULTATU"         => $cdoperador,
                    "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                    "NRORG"                => $nrorg
                );
                $this->propostaFactory->reajustarParcelasNegociacao($params);
            }
        }
    }

    public function salvarVendedor($nrseqorcamento, $nrparcvendedor, $nrparcgerente, $vrpeparticipavenda, $idvenpriorca, $idativo, $nrorg, $cdoperador) {
        $nrvendedororca = $this->newCode->getCodeByTableName("NRVENDEDORORCA", $nrorg, 1, 10, true);
        $params = array(
            "NRVENDEDORORCA"     => $nrvendedororca,
            "NRSEQORCAMENTO"     => $nrseqorcamento,
            "NRPARCVENDEDOR"     => $nrparcvendedor,
            "NRPARCGERENTE"      => $nrparcgerente,
            "VRPEPARTICIPAVENDA" => $vrpeparticipavenda,
            "IDVENPRIORCA"       => $idvenpriorca,
            "NRORG"              => $nrorg,
            "IDATIVO"            => $idativo,
            "NRORGINCLUSAO"      => $nrorg,
            "CDOPERINCLUSAO"     => $cdoperador
        );

        $this->propostaFactory->salvarVendedor($params);
    }

    public function atualizarValoresNegociacaoAoEditarItemSemComposicao($nritemorcamento, $vrtotalitemorca) {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        $params = array(
            "NRITEMORCAMENTO" => $nritemorcamento,
            "NRORG"           => $nrorg
        );
        $dataset = $this->propostaFactory->getCodigoNegociacaoDoItem($params);
        if (count($dataset) > 0) {
            
            $this->connection->beginTransaction();
            try {
                $nrnegociacaoproposta = $dataset[0]["NRNEGOCIACAOPROPOSTA"];
            
                $params = array(
                    "VRTOTITEM"            => $vrtotalitemorca,
                    "CDOPERULTATU"         => $cdoperador,
                    "NRORGULTATU"          => $nrorg,
                    "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
                    "NRITEMORCAMENTO"      => $nritemorcamento,
                    "NRORG"                => $nrorg
                );
                $this->propostaFactory->atualizarValorItemNegociacao($params);
    
                // Atualiza o valor da negociacao de valores com a soma dos itens
                $this->atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador);
    
                $this->connection->commit();
            }
            catch (\Exception $e) {
                $this->connection->rollback();
                throw $e;
            }
        }
    }
    
    public function excluirParcelasNegociacao($nrnegociacaoproposta, $nrorg) {
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        
        $this->propostaFactory->excluirParcelasNegociacao($params);
    }
    /**
     * Valida se o operador logado por efetuar alterações nos itens da proposta
    **/
    public function validarPermissaoAlteracaoQtMedida($operador, $nrorg) {
        $params = array(
            "CDOPERADOR" => $operador,
            "NRORG"      => $nrorg
        );
        
        $datasetOperador  = $this->propostaFactory->getOperadorReducaoQtMedida($params);
        $datasetPerfAcess = $this->propostaFactory->getPerfAcessReducaoQtMedida($params);
        
        if(count($datasetOperador) == 0) {
            if(count($datasetPerfAcess) == 0)
                return false;
        }
        
        return true; 
    }
    
    public function validarParametrosFaturamentoOrca($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $negociacoes = $this->propostaFactory->getParametrosFaturaNegociacoesProposta($params);
        foreach($negociacoes as $negociacao) {
            if ($negociacao["CDFILIALFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Unidade para Faturamento" não foi encontrado para esta proposta. Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($negociacao["CDTIPOOPERFATURA"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Tipo de Operação da Nota Fiscal" não foi encontrado para esta proposta. Favor conferir a parametrização de faturamento do Escopo.');
            
            if ($negociacao["CDSERIENF"] == null)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Série da Nota Fiscal" não foi encontrado para esta proposta. Favor conferir a parametrização de faturamento do Escopo.');
            
            /*if ($negociacao["QTPRODFATURA"] > 0)
                throw new \Exception('Operação bloqueada. <br/><br/>O parâmetro "Produto para Faturamento" não foi encontrado para esta proposta. Favor conferir a parametrização de faturamento do Escopo ou do Serviço.');
            */
            
            if(in_array($negociacao["IDTPFATURA"], array("A", "X"))) {
                $competencia = $this->getCompetenciaNegociacaoProposta($negociacao["NRNEGOCIACAOPROPOSTA"], $nrorg);
                if(count($competencia) == 0)
                    throw new \Exception('Operação bloqueada. <br/><br/>O período de competência não foi encontrado para esta proposta. Favor conferir a parametrização de faturamento do Escopo ou do Serviço.');
            }
        }
    }
    
    /**
     * Busca todos os descontos da negociação de uma proposta
    **/
    public function getDescontosProposta($nrseqorcamento, $nrorg) {
        $descontoNegociacao = array();
        $descontoPorPeriodo = array();
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $negociacoes = $this->propostaFactory->getNegociacoesProposta($params);
        foreach($negociacoes as $negociacao) {
            $params = array(
                "NRNEGOCIACAOPROPOSTA" => $negociacao["NRNEGOCIACAOPROPOSTA"],
                "NRORG"                => $nrorg
            );
            
            $descPorperiodo = $this->propostaFactory->getDescontosPorPeriodoDaNegociacao($params);
            $descNegociacao = $this->propostaFactory->getDescontosNegociacaoValores($params);
            
            if(count($descPorperiodo) > 0) $descontoPorPeriodo = array_merge($descontoPorPeriodo, $descPorperiodo);
            if(count($descNegociacao) > 0) $descontoNegociacao = array_merge($descontoNegociacao, $descNegociacao);
        }
        
        $descontos = array(
            "NEGOCIACAO" => $descontoNegociacao,
            "PORPERIODO" => $descontoPorPeriodo
        );
        
        return (count($descontoPorPeriodo) > 0 || count($descontoNegociacao) > 0) ? $descontos : array();
    }
    
    /**
     * Atualiza os acrescimos e descontos dados na proposta
     * antes das atualizações dos itens e medidas
    **/
    public function atualizarDescontosAcrescimosProposta($itensProposta, $descontosProposta, $nrseqorcamento, $nrorg, $negociacoes, $alteraMedida, $idSituacao, $parcelas) {
        $cdoperador = $this->environment->getCdOperador();
        
        foreach($itensProposta as $item) {
            $novoItem  = $this->getNovoItemCorrespondente($item["IDELEMENTO"], $item["CDSERVORCA"], $item["CDTPMEDIDAVARIAVEL"], $nrseqorcamento, $nrorg);
            if(!empty($novoItem) && count($novoItem) > 0) {
                $nrnewitemorcamento    = $novoItem["NRITEMORCAMENTO"];
                $nrnewitemorcamentopai = $novoItem["NRITEMORCAMENTOPAI"];
                
                if($item["IDELEMENTO"] && $item["VRUNITITEMORCATBLPRECO"] != $item["VRUNITITEMORCA"]) {
                
                        $qtmedidaorca   = (!$alteraMedida) ?  $item["QTMEDIDAORCA"] : $novoItem["QTMEDIDACALCULADA"];
                        $dadosTblPreco  = $this->getIdMultiplicavariacaoItem($item["CDSERVORCA"], $item["CDTPMEDIDASERV"], $item["CDTPMEDIDAVARIAVEL"], $qtmedidaorca, $nrorg);
                        
                        $vrtblpreco = $dadosTblPreco["VRPRECOVARIACAO"];
                        if ($dadosTblPreco["IDMULTIPVARIACAO"] == "S") {
                            $somatorioMedidaServico = $this->getSomatorioMedidaServico($item["CDSERVORCA"], $item["IDELEMENTO"], $nrseqorcamento, $nrorg);
                            $vrtblpreco *= $somatorioMedidaServico;
                        }
                        
                        $vracrescimento = ($item["VRUNITITEMORCA"] < $vrtblpreco) ? $vrtblpreco : $item["VRUNITITEMORCA"];
                        
                        $vrtotalitemorca = ($dadosTblPreco == 'N') ? $vracrescimento : $vracrescimento * $qtmedidaorca;
                        $params = array(
                            "NRORG"                  => $nrorg,
                            "NRITEMORCAMENTO"        => $nrnewitemorcamento,
                            "QTMEDIDAORCA"           => $qtmedidaorca,
                            "VRUNITITEMORCATBLPRECO" => $vrtblpreco,
                            "VRUNITITEMORCA"         => $vracrescimento,
                            "VRTOTALITEMORCA"        => $vrtotalitemorca
                        );
                        
                        $this->propostaFactory->atualizarValorItensOrcamento($params);
                        
                        $params = array (
                            "NRSEQORCAMENTO" => $nrseqorcamento,
                            "CDSERVORCA"     => $item["CDSERVORCA"],
                            "NRORG"          => $nrorg
                        );
                        $this->propostaFactory->atualizarValorItemPai($params);
                        $this->atualizarValorItensNegociacaoValores($nrseqorcamento, $nrnewitemorcamento, $vrtotalitemorca, $nrnewitemorcamentopai, $nrorg, $item["CDOPERINCLUSAO"]);
                }    

                if(count($descontosProposta) > 0) {
                    foreach($descontosProposta["NEGOCIACAO"] as &$desconto) {
                        if($desconto["TIPODESCONTO"] == "ITENS" && $desconto["NRITEMORCAMENTO"] == $item["NRITEMORCAMENTO"]) {
                            if ($nrnewitemorcamento) {
                                $desconto["NRITEMORCAMENTO"] = $nrnewitemorcamento;
                                $desconto["NRITEMORCAMENTOPAI"] = $nrnewitemorcamentopai;
                            }
                        }
                    }
                    unset($desconto);
                }
            }
        }

        if(count($descontosProposta) > 0) {
            foreach($negociacoes as $negociacao) {
                $params = array(
                    "NRSEQORCAMENTO"   => $nrseqorcamento,
                    "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                    "CDSERIENF"        => $negociacao["CDSERIENF"],
                    "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                    "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                    "NRORG"            => $nrorg
                );
                
                $newnegociacao = $this->propostaFactory->getNovaNegociacaoCorrespondente($params);
                foreach($descontosProposta as $key=>$descontos) {
                    foreach($descontos as $row) {
                        if($row["NRNEGOCIACAOPROPOSTA"] == $negociacao["NRNEGOCIACAOPROPOSTA"]) {
                            if(count($newnegociacao) < 0) {
                                unset($row);
                            } else {
                                if($key != "PORPERIODO") {
                                    $vrpercdesc = $row["VRPERCDESCITEM"];
                                    $vrdesconto = $row["VRDESCITEM"];
                                    
                                    if ($row['IDTPDESCONTO'] == 'V') {
                                        $sqlAux = "VRPERCDESCITEM   = ROUND($vrdesconto / VRTOTITEM * 100, 2),
                                                   VRDESCITEM       = $vrdesconto,
                                                   IDTPDESCONTO     = '" . $row['IDTPDESCONTO'] . "',
                                                   VRTOTITEMCOMDESC = VRTOTITEM - $vrdesconto";
                                    }
                                    else {
                                        $sqlAux = "VRPERCDESCITEM   = $vrpercdesc,
                                                   VRDESCITEM       = ROUND(VRTOTITEM * $vrpercdesc / 100, 2),
                                                   IDTPDESCONTO     = '" . $row['IDTPDESCONTO'] . "',
                                                   VRTOTITEMCOMDESC = VRTOTITEM - (ROUND(VRTOTITEM * $vrpercdesc / 100, 2))";
                                    }
                                    
                                    if($row["TIPODESCONTO"] == "ITENS") {
                                        $params = array(
                                            "NRNEGOCIACAOPROPOSTA" => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                            "NRITEMORCAMENTO"      => $row["NRITEMORCAMENTO"],
                                            "NRORG"                => $nrorg
                                        );
                                        $this->propostaFactory->atualizarItensNegociaco($params, $sqlAux);
                                        
                                        // retorna a soma do valor dos elementos filhos do item
                                        $params = array(
                                            "NRNEGOCIACAOPROPOSTA" => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                            "NRITEMORCAMENTOPAI"   => $row["NRITEMORCAMENTOPAI"],
                                            "NRORG"                => $nrorg
                                        );
                                        $dataset = $this->propostaFactory->getSomaValorElementosItemNegociacao($params);
                                        $somaValoresItem = (float)$dataset[0]["VRTOTAL"];
                                
                                        // atualiza o item pai com a soma dos filhos
                                        $params = array(
                                            "VRTOTITEM"            => $somaValoresItem,
                                            "CDOPERULTATU"         => $cdoperador,
                                            "NRORGULTATU"          => $nrorg,
                                            "NRNEGOCIACAOPROPOSTA" => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                            "NRITEMORCAMENTO"      => $row["NRITEMORCAMENTOPAI"],
                                            "NRORG"                => $nrorg
                                        );
                                        $this->propostaFactory->atualizarValorItemNegociacao($params);
                                        
                                        // atualiza o valor da negociacao de valores com a soma de seus itens
                                        $this->atualizarValorNegociacaoComSomaDosItens($newnegociacao[0]["NRNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);
                                        
                                    } else {
                                        $params = array(
                                            "NRNEGOCIACAOPROPOSTA" => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                            "NRORG"                => $nrorg
                                        );
                                        $this->propostaFactory->atualizarNegociaco($params, $sqlAux);
                                    }
                                } else {
                                    $params = array(
                                        "NRSEQORCAMENTO"   => $nrseqorcamento,
                                        "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                                        "CDSERIENF"        => $negociacao["CDSERIENF"],
                                        "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                                        "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                                        "NRORG"            => $nrorg
                                    );
                                    $newnegociacao = $this->propostaFactory->getNovaNegociacaoCorrespondente($params);
                                    
                                    $nrdescontoporperiodo = $this->newCode->getCodeByTableName("FCT_DESCPERIODONEGOPROP", $nrorg, 1, 10, true);
                                    
                                    if ($row['IDTPDESCONTO'] == 'V') {
                                        if ($newnegociacao[0]["VRTOTITEMCOMDESC"] == 0) {
                                            $vrdescitem = 0;
                                            $vrpercdesc = 0;
                                        }
                                        else {
                                            $vrdescitem = $row["VRDESCITEM"];
                                            $vrpercdesc = round($vrdescitem / $newnegociacao[0]["VRTOTITEMCOMDESC"] * 100, 2);
                                        }
                                    }
                                    else {
                                        $vrpercdesc = $row["VRPERCDESCITEM"];
                                        $vrdescitem = round($newnegociacao[0]["VRTOTITEMCOMDESC"] * $vrpercdesc / 100, 2);
                                    }
                                    $vrtotitemcomdesc = $newnegociacao[0]["VRTOTITEMCOMDESC"] - $vrdescitem;
                                    
                                    $params = array(
                                        "NRDESCPERIODONEGOPROP" => $nrdescontoporperiodo,
                                        "IDATIVO"               => 'S',
                                        "NRORG"                 => $nrorg,
                                        "VRPERCDESCITEM"        => $vrpercdesc,
                                        "VRDESCITEM"            => $vrdescitem,
                                        "VRTOTITEMCOMDESC"      => $vrtotitemcomdesc,
                                        "NRNEGOCIACAOPROPOSTA"  => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                        "QTMESESDESC"           => $row["QTMESESDESC"],
                                        "DTFINALVALIDADEDESC"   => $row["DTFINALVALIDADEDESC"],
                                        "DTINCLUSAO"            => $row["DTINCLUSAO"],
                                        "NRORGINCLUSAO"         => $row["NRORGINCLUSAO"],
                                        "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                                        "DTULTATU"              => $row["DTULTATU"],
                                        "NRORGULTATU"           => $row["NRORGULTATU"],
                                        "CDOPERULTATU"          => $row["CDOPERULTATU"],
                                        "NRORDEMAPLICADESC"     => $row["NRORDEMAPLICADESC"],
                                        "IDTPDESCONTO"          => $row["IDTPDESCONTO"]
                                    );
                                    $this->propostaFactory->inserirDescontoPorPeriodo($params);
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    
    /**
     * Retorna o nritemorcamento de um item segundo as informações do elemento, serviço e medida
    **/
    public function getNovoItemCorrespondente($idelemento, $cdservorca, $cdtpmedida, $nrseqorcamento, $nrorg){
        $params = array(
            "IDELEMENTO"         => $idelemento, 
            "CDSERVORCA"         => $cdservorca, 
            "CDTPMEDIDAVARIAVEL" => $cdtpmedida,
            "NRSEQORCAMENTO"     => $nrseqorcamento, 
            "NRORG"              => $nrorg
        );
        
        $item = $this->propostaFactory->getNovoItemCorrespondente($params);
        return count($item) > 0 ? $item[0] : null;
    }
    
    /**
     * Retorna o somatório da quantidade de medida do serviço de um elemento da proposta
    **/
    public function getSomatorioMedidaServico($cdservorca, $idelemento, $nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO"     => $nrseqorcamento,
            "NRORG"              => $nrorg,
            "IDELEMENTO"         => $idelemento,
            "CDSERVORCA"         => $cdservorca
        );
        
        $medidaservico = $this->propostaFactory->getSomatorioMedidaServico($params);
        return count($medidaservico) > 0 ? $medidaservico[0]["QTMEDIDASERV"] : null;
    }
    
    /**
     * Retorna os dados da tabela de preço ligados a medida de um serviço 
    **/
    public function getIdMultiplicavariacaoItem($cdservorca, $cdtpmedidaserv, $cdtpmedidavariavel, $qtmedida, $nrorg) {
        $params = array(
            "CDTPMEDIDASERV"     => $cdtpmedidaserv,
            "CDTPMEDIDAVARIAVEL" => $cdtpmedidavariavel,
            "QTMEDIDAORCA"       => $qtmedida,
            "CDSERVORCA"         => $cdservorca, 
            "NRORG"              => $nrorg
        );
        $dadosTblPreco = $this->propostaFactory->getIdMultiplicavariacaoItem($params);
        return count($dadosTblPreco) > 0 ? $dadosTblPreco[0] : null; 
    }
    
    /**
     * Atualiza o valor dos itens da negociacao
    **/
    public function atualizarValorItensNegociacaoValores($nrseqorcamento, $nritemorcamento, $vrtotalitemorca, $nritemorcamentopai, $nrorg, $cdoperador) {
        $params = array(
            "NRITEMORCAMENTO" => $nritemorcamento,
            "NRORG"           => $nrorg
        );
        $dataset = $this->propostaFactory->getCodigoNegociacaoDoItem($params);
        $nrnegociacaoproposta = $dataset[0]["NRNEGOCIACAOPROPOSTA"];
        $params = array(
            "VRTOTITEM"            => $vrtotalitemorca,
            "CDOPERULTATU"         => $cdoperador,
            "NRORGULTATU"          => $nrorg,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRITEMORCAMENTO"      => $nritemorcamento,
            "NRORG"                => $nrorg
        );
        $this->propostaFactory->atualizarValorItemNegociacao($params);

        //1- retorna a soma do valor dos elementos filhos do item
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRITEMORCAMENTOPAI"   => $nritemorcamentopai,
            "NRORG"                => $nrorg
        );
        $dataset = $this->propostaFactory->getSomaValorElementosItemNegociacao($params);
        $somaValoresItem = (float)$dataset[0]["VRTOTAL"];

        //2- atualiza o item pai com a soma dos filhos
        $params = array(
            "VRTOTITEM"            => $somaValoresItem,
            "CDOPERULTATU"         => $cdoperador,
            "NRORGULTATU"          => $nrorg,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRITEMORCAMENTO"      => $nritemorcamentopai,
            "NRORG"                => $nrorg
        );
        $this->propostaFactory->atualizarValorItemNegociacao($params);
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $negociacoes = $this->propostaFactory->getNegociacoesProposta($params);

        foreach ($negociacoes as $nego) 
            $valor = $this->atualizarValorNegociacaoComSomaDosItens($nego["NRNEGOCIACAOPROPOSTA"], $nrorg, $cdoperador);
    }
    
    /**
     * Verifica se não houve alteração no valor das parcelas
    **/
    public function atualizarParcelasProposta($negociacoes, $nrseqorcamento, $parcelas, $nrorg) {
        foreach($negociacoes as $negociacao) {
            $params = array(
                "NRSEQORCAMENTO"   => $nrseqorcamento,
                "IDTPFATURA"       => $negociacao["IDTPFATURA"],
                "CDSERIENF"        => $negociacao["CDSERIENF"],
                "CDTIPOOPERFATURA" => $negociacao["CDTIPOOPERFATURA"],
                "CDFILIALFATURA"   => $negociacao["CDFILIALFATURA"],
                "NRORG"            => $nrorg
            );
            
            $newnegociacao = $this->propostaFactory->getNovaNegociacaoCorrespondente($params);
            if (count($newnegociacao) > 0) {
                if($negociacao["SOMA_PARCELAS"] == $newnegociacao[0]["VRTOTITEMCOMDESC"]) {
                    foreach($parcelas as $parcela) {
                        if($parcela["NRNEGOCIACAOPROPOSTA"] == $negociacao["NRNEGOCIACAOPROPOSTA"]) { 
                            $nrparcelanegoprop = $this->newCode->getCodeByTableName("FCT_PARCELANEGOPROP", $nrorg, 1, 10, true);
                            $params = array(
                                "NRPARCELANEGOPROP"    => $nrparcelanegoprop,
                                "IDATIVO"              => "S",
                                "NRNEGOCIACAOPROPOSTA" => $newnegociacao[0]["NRNEGOCIACAOPROPOSTA"],
                                "QTDIASFATURAMENTO"    => $parcela["QTDIASFATURAMENTO"],
                                "NRPARCELA"            => $parcela["NRPARCELA"],
                                "NRDIAVENCIMENTO"      => $parcela["NRDIAVENCIMENTO"],
                                "VRPARCELA"            => $parcela["VRPARCELA"],
                                "NRORG"                => $parcela["NRORG"],
                                "NRORGINCLUSAO"        => $parcela["NRORGINCLUSAO"],
                                "CDOPERINCLUSAO"       => $parcela["CDOPERINCLUSAO"],
                            );
                            
                            $this->propostaFactory->inserirParcelaNegociacao($params);
                        }
                    }
                }
            }
        }
    }
    
    public function validaBloqAlteraValor($nrtipoorcamento, $nrorg) {
        $params = array(
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "NRORG"             => $nrorg
        );
        $dataset = $this->propostaFactory->validaBloqAlteraValor($params);
        return $dataset[0]["IDALTVRTABRPECPROP"];
    }
    
    public function inserirOuAtualizarMedidaVariavelServico($row, $nrorg, $cdoperador, $somenteAtualizar = false) {
        $params = array(
            "NRSEQORCAMENTO"     => $row["NRSEQORCAMENTO"],
            "CDTPMEDIDAVARIAVEL" => $row["CDTPMEDIDAVARIAVEL"],
            "CDSERVORCA"         => $row["CDSERVORCA"],
            "NRORG"              => $nrorg
        );
        
        $dataset = $this->propostaFactory->getMedidaVariavelServicoProposta($params);
        if (count($dataset) > 0) {
            $nrrelacmedidaproposta = $dataset[0]["NRRELACMEDIDAPROPOSTA"];
            $qtmedidavariavel      = $row["QTMEDIDAORCA"];
            
            $this->atualizarMedidaVariavelServico($nrrelacmedidaproposta, $qtmedidavariavel, $cdoperador, $nrorg);
        } else if ($somenteAtualizar === false) {
            $this->inserirMedidaVariavelServico($row, $nrorg, $cdoperador);
        }
    }
    
    private function atualizarMedidaVariavelServico($nrrelacmedidaproposta, $qtmedidavariavel, $cdoperador, $nrorg) {
        $params = array(
            "QTMEDIDAVARIAVEL"      => $qtmedidavariavel,
            "NRORGULTATU"           => $nrorg,
            "CDOPERULTATU"          => $cdoperador,
            "NRRELACMEDIDAPROPOSTA" => $nrrelacmedidaproposta,
            "NRORG"                 => $nrorg
        );

        $this->propostaFactory->atualizarMedidaVariavelServico($params);
    }
    
    private function inserirMedidaVariavelServico($row, $nrorg, $cdoperador) {
        $nrrelacmedidaproposta = $this->newCode->getCodeByTableName("FCT_RELACMEDIDAPROPOSTA", $nrorg, 1, 10, true);
        $params = array(
            "NRRELACMEDIDAPROPOSTA" => $nrrelacmedidaproposta,
            "NRSEQORCAMENTO"        => $row["NRSEQORCAMENTO"],
            "CDTPMEDIDAVARIAVEL"    => $row["CDTPMEDIDAVARIAVEL"],
            "QTMEDIDAVARIAVEL"      => $row["QTMEDIDAORCA"],
            "NRORG"                 => $nrorg,
            "NRORGINCLUSAO"         => $nrorg,
            "CDOPERINCLUSAO"        => $cdoperador,
            "IDATIVO"               => "S",
            "IDELEMENTORAIZ"        => null,
            "QTFRANQUIA"            => null,
            "CDSERVORCA"            => $row["CDSERVORCA"],
            "NRTIPOORCAMENTO"       => $row["NRTIPOORCAMENTO"]
        );

        $this->propostaFactory->inserirMedidaVariavelServico($params);
    }
    
    public function getSomaQuantidadeMedidaServicoProposta($nrseqorcamento, $cdservorca, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "CDSERVORCA"     => $cdservorca,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getSomaQuantidadeMedidaServicoProposta($params);
        return (count($dataset) > 0) ? $dataset[0]["QTMEDIDAORCA"] : null;
    }
    
    public function vincularEscopoAoTipoDeMedida($medidas, $itens,  $escopos = array()) {

        $medidascomescopo = array();

        if (count($escopos) > 0){

           $escoposAux = '_';
           foreach($escopos as $escopo){
                $escoposAux = $escoposAux.$escopo.'_';
           }

           $params = array(
            "NRTIPOORCAMENTO" => $escoposAux
           );

           $escTipoFat = $this->propostaFactory->getTipoFaturamentoEscopo($params);

            foreach($medidas as $medida) {
                foreach($itens as $item) {
                
                    if($medida["IDELEMENTORAIZ"] == $item["IDELEMENTO"] && $medida["CDTPMEDIDASERV"] == $item["CDTPMEDIDAVARIAVEL"]) {
                        foreach($escTipoFat as $tipoFat){
                            if ($tipoFat["NRTIPOORCAMENTO"] == $item["NRTIPOORCAMENTO"] && $tipoFat["IDTPFATURA"] == 'X') {
                                if (count($medidascomescopo) > 0){

                                    $insere = 'S';

                                    foreach($medidascomescopo as $medescopo) {

                                        if($medescopo["IDELEMENTORAIZ"] == $item["IDELEMENTO"] && $medescopo["CDTPMEDIDASERV"] == $item["CDTPMEDIDAVARIAVEL"] && $medescopo["NRTIPOORCAMENTO"] == $item["NRTIPOORCAMENTO"]) {

                                            $insere = 'N';
                                        }
                                    }

                                    if ($insere == 'S') {
                                        $medida["NRTIPOORCAMENTO"] = $item["NRTIPOORCAMENTO"];
                                        array_push($medidascomescopo, $medida);
                                    }
                                }
                                else{

                                    $medida["NRTIPOORCAMENTO"] = $item["NRTIPOORCAMENTO"];
                                    array_push($medidascomescopo, $medida);
                                }
                            }
                        }
                    }
                }
            } 
            
        }
        else {

            foreach($medidas as $medida) {
                foreach($itens as $item) {
                    if($medida["IDELEMENTORAIZ"] == $item["IDELEMENTO"] && $medida["CDTPMEDIDASERV"] == $item["CDTPMEDIDAVARIAVEL"]) {
                        $medida["NRTIPOORCAMENTO"] = $item["NRTIPOORCAMENTO"];
                        array_push($medidascomescopo, $medida);
                        break;
                    }
                }
            }
        }

        return $medidascomescopo;

    }
    
    public function getQuantidadeMedidaServico($cdservorca, $cdtpmedida, $qtmedida, $itens) {
        $qtmedidaatulaservico = 0;
        foreach($itens as $item) {
            if($item["IDELEMENTO"] && $item["CDSERVORCA"] == $cdservorca && $item["CDTPMEDIDAVARIAVEL"] == $cdtpmedida)
                $qtmedidaatulaservico += (float) $item["QTMEDIDASERV"];
        }
        
        return ($qtmedidaatulaservico > 0) ? $qtmedidaatulaservico : $qtmedida; 
    }
    
    /**
     * realiza o update da proposta para incluir / alterar o campo "DSALTERACONTRATUAIS"
    **/
    public function updateDsAlteracoesContr($nrseqorcamento, $dsalteracontratuais, $nrorg, $cdoperador) {
        
        $params = array(
            "DSALTERACONTRATUAIS" => $dsalteracontratuais,
            "OPERADOR"            => $cdoperador,
            "NRORG"               => $nrorg,
            "NRSEQORCAMENTO"      => $nrseqorcamento
        );

        $this->propostaFactory->updateDsAlteracoesContr($params);
    }
    
    /**
     * Valida se o operador tem acesso à página "Alterações Contratuais"
    **/
    public function validaAlteracoesContratuais($nrorg) {
        
        $params = array(
            "NRORG" => $nrorg
        );

        $operadores = $this->propostaFactory->validaAlteracoesContratuais($params);
        
        if (!empty($operadores)){
            
            $cdoperador = $this->environment->getCdOperador();
            $count = 0;
            
            foreach ($operadores as $operador){
                if ($operador["CDOPERADOR"] == $cdoperador){
                    $count = $count + 1;
                }    
            }
            
            if ($count == 0){
                $retorno = "DESABILITADO";  
            }
            else{
                $retorno = "HABILITADO"; 
            }
        }
        else{
            $retorno = "DESABILITADO";    
        }
        
        return $retorno;
    }
    
    /**
     *recebe os dados de "Alterações Contratuais"
    **/
    public function getAlteracaoContratual($nrseqorcamento, $nrorg) {
        
        $params = array(
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "NRORG"               => $nrorg
        );

        $dsalteracontratuais = $this->propostaFactory->getAlteracaoContratual($params);
        $dsalteracontratuais = $dsalteracontratuais[0]["DSALTERACONTRATUAIS"];
        
        return $dsalteracontratuais;
    }
    
    /**

     * A função "inserirAssinaturasOrca" realiza a inserção das assinaturas de acordo com os signatários padrões 
     * cadastrados no modelo de proposta
     */
    public function inserirAssinaturasOrca($nrorcamentomodelo, $nrseqorcamento, $interlocutor, $nrorg, $cdoperador){
        try {
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if(!empty($certsign)) {
                
                $idasseletrdigital = $this->getUtilizaAssinaturaEletronicaProposta($nrseqorcamento, $nrorg);
                if ($idasseletrdigital == "S") {
                
                    $params = array(
                        "NRORCAMENTOMODELO" => $nrorcamentomodelo,
                        "NRORG" => $nrorg
                    );
                    
                    $signatarios = $this->propostaFactory->buscaSignatariosPadroes($params);
                    
                    if(count($signatarios) > 0) {
                    
                      foreach($signatarios as $signatario){
                          
                          $params = array(
                              "NRSEQORCAMENTO" => $nrseqorcamento,
                              "NRPARCNEGOCIO"  => $signatario["NRPARCNEGOCIO"],
                              "NRSEQINTERLOCUTOR" => null,
                              "NRORG"          => $nrorg
                           );
                          
                           $valida = $this->propostaFactory->validaSignatCadastrados($params);
                           
                           if ($valida == 0){
                               
                               $nrassdigitalorca = $this->newCode->getCodeByTableName("FCT_ASSINATDIGITALPROP", $nrorg, 1, 10, true);
                              
                               $params= array(
                                  "NRASSDIGITALORCA"   => $nrassdigitalorca,
                                  "NRSEQORCAMENTO"     => $nrseqorcamento,
                                  "NRSEQINTERLOCUTOR"  => null,
                                  "NRPARCNEGOCIO"      => $signatario["NRPARCNEGOCIO"],
                                  "NRCPFSIGNATARIO"    => $signatario["NRINSCRICAOPARC"],
                                  "IDTIPOASSINATURA"   => $signatario["IDTIPOASSINATURA"], 
                                  "IDTESTEMUNHA"       => $signatario["IDTESTEMUNHA"], 
                                  "NRORDENACAO"        => $signatario["NRORDENACAO"], 
                                  "DSEMAILNOTSIGNENV"  => $signatario["DSEMAILNOTSIGNENV"], 
                                  "DSEMAILNOTIFOUTROS" => $signatario["DSEMAILNOTIFOUTROS"],
                                  "NRORG"              => $nrorg,  
                                  "OPERADOR"           => $cdoperador,
                                  "IDSIGNATCERTSIGN"   => null
                               );
                              
                               $this->propostaFactory->insereAssinatura($params);
                               
                               $params = array(
                                  "NRSIGNATPADRORCA" => $signatario["NRSIGNATPADRORCA"],
                                  "NRORG"            => $nrorg
                               ); 
                              
                               $operadores = $this->propostaFactory->buscaOperadoresNotif($params);
                                    
                               foreach($operadores as $operador){
                                 
                                 $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
               
                                 $params = array(
                                    "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                                    "NRASSDIGITALORCA"     => $nrassdigitalorca,
                                    "CDOPERADOR"           => $operador["CDOPERADOR"], 
                                    "NRORG"                => $nrorg,  
                                    "OPERADOR"             => $cdoperador
                                 );
                                
                                 $this->propostaFactory->insereOperadoresNotifica($params);
                              }
                           }
                       } 
                    }
                    $this->insereInterlocutor($nrseqorcamento, $interlocutor, null, $nrorg, $cdoperador, $nrorcamentomodelo);
                }
            }
        }
        catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * A função "validaAssinaturaOrca" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaAssinaturaOrca($row){
        try {
            
           $nrorg = $this->environment->getNrOrg();
           $nrparcnegocio = $row["NRPARCNEGOCIO"];
           $nrseqorcamento = $row["NRSEQORCAMENTO"];
           $interlocutor = $row["NRSEQINTERLOCUTOR"];
           
           $params = array(
              "NRSEQORCAMENTO" => $nrseqorcamento,
              "NRPARCNEGOCIO"  => $nrparcnegocio,
              "NRSEQINTERLOCUTOR" => $interlocutor,
              "NRORG"          => $nrorg
           );
          
           $valida = $this->propostaFactory->validaSignatCadastrados($params);
        
           return $valida;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * Valida se o token da certsign está preenchido
     */
    public function validaIdCertsign($nrseqorcamento, $nrorg) {
        try {
            /* Recebe Token Certsign */    
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if (empty($certsign) || empty($nrseqorcamento)) {
                $retorno = array(
                    "DSTOKENCERTSIGN"   => $certsign,
                    "IDASSELETRDIGITAL" => "N"
                );
            }
            else {
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
                $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG" => $nrorg
                );
               
                $idAssEletrDigital = $this->propostaFactory->recebeIdAssEletrDigital($params);
                
                $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"]; 
               
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
                $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG" => $nrorg
                );
               
                $iddocumcertsign = $this->propostaFactory->validaExisteDocCertsign($params);
            
                if (!empty($iddocumcertsign)) {
                    $iddocumcertsign = $iddocumcertsign[0]["IDDOCUMCERTSIGN"];
                
                    if ($iddocumcertsign == 'TRUE') {
                         
                        $documcertsign = true;
                    }
                    else{
                        $documcertsign = false;
                    }
                }
                else{
                    $documcertsign = false;
                }
                
                $retorno = array(
                    "DSTOKENCERTSIGN"   => $certsign,
                    "IDASSELETRDIGITAL" => $idAssEletrDigital,
                    "IDDOCUMCERTSIGN"   => $documcertsign
                );
            }
           
            return $retorno;
        }
        catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * Envia novamente o e-mail de assinatura para os signatários que ainda não realziaram a assinatura
     */
    public function solicitarAssinatura($nrseqorcamento, $tipoorcamentos, $nrorg, $operador) {
        try {
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->propostaFactory->validaTokenCertsign($params);
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];
           
           $retornos = array();
           
           if(!empty($certsign)) {
                foreach ($tipoorcamentos as $tipoorcamento) {
                    $params = array(
                        "NRSEQORCAMENTO"  => $nrseqorcamento,
                        "NRTIPOORCAMENTO" => $tipoorcamento,
                        "NRORG"           => $nrorg
                    ); 
                   
                    $documentsId = $this->propostaFactory->getIdDocumentoCertsign($params);
                    
                    $documentIdAux = 0;
                
                    foreach($documentsId as $docId) {
                        
                        $documentId = $docId["IDDOCUMCERTSIGN"];
                        
                        if (($documentId != null) && ($documentId != $documentIdAux)) {
                            
                            // Chamada da API do Certsign
                            $solicitarCertsign = $this->assinaturaDigital->reenviarSolicitacao($documentId);
                            $solicita = $solicitarCertsign["response"]["id"];
                            $retornos[] = 'OK';
                            
                            //Inserir no log do documento
                            $this->notificarSignatarioNoLog($solicitarCertsign, $nrseqorcamento, $tipoorcamento, $nrorg);
                        }
                        else {
                            $retornos[] = 'N_DOC';
                        }
                        
                        $documentIdAux = $documentId;
                    };
                };
            };
            
            $countOk = 0;
            $countNDoc = 0;
           
            foreach ($retornos as $retorno) {
                if ($retorno == 'OK') {
                    $countOk = $countOk+1;
                }
                else {
                    $countNDoc = $countNDoc+1;
                }
            };
            
            if (($countOk > 0) && ($countNDoc == 0)){
                return 'OK';
            }
            else if (($countOk > 0) && ($countNDoc > 0)){
                return 'OK_N_DOC';
            }
            else {
                return 'N_DOC';
            };
        }
        catch(\Exception $e) {
           if (isset($solicitarCertsign["response"]["message"])){
                
                if (isset($incSignatCertsign["response"]["statusCode"])) {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$solicitarCertsign["response"]["statusCode"]. ' - ' .$solicitarCertsign["response"]["message"]);
                }
                else {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$solicitarCertsign["response"]["message"]);
                }
            }
            else {
                throw $e;
            }
        }   
    }
    
    /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmente($signatarios, $checked, $nrorg, $operador) {
        try {
            if ($checked == true) {
                $assinaturas = $signatarios;  
            }   
            else {
                $assinaturas = array(
                    "0" => $signatarios
                );
            }
            
            /* Recebe Token Certsign */    
            $params = array(
                "NRORG" => $nrorg
            );
        
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
           
            $retornos = array();
            $realizado = 0;
           
            if (!empty($certsign)) {
                foreach ($assinaturas as $assinatura){
                   
                    $situacao = $assinatura["IDSITUACAO"];
                   
                    if ($situacao == 'P') { 
                            
                        $params = array(
                            "NRASSDIGITALORCA" => $assinatura["NRASSDIGITALORCA"],
                            "NRSEQORCAMENTO"   => $assinatura["NRSEQORCAMENTO"],
                            "NRORG"            => $nrorg
                        ); 
                       
                        $assDocumento = $this->propostaFactory->recebeSeqDocumento($params);

                        foreach ($assDocumento as $assDoc) {
                            
                            $params = array(
                                "NRSEQORCAMENTO"  => $assinatura["NRSEQORCAMENTO"],
                                "NRSEQORCADOC"    => $assDoc["NRSEQORCADOC"],
                                "NRORG"           => $nrorg
                            ); 
                           
                            $documentsId = $this->propostaFactory->getIdDocumentoCertsignDoc($params);
                            
                            $documentIdAux = 0;
                            $realizado = 0;
                    
                            foreach($documentsId as $docId) {
                            
                                $documentId = $docId["IDDOCUMCERTSIGN"];
                                     
                                if (($documentId != null) && ($documentId != $documentIdAux)) {
     
                                    $idsignatcertsign = $assinatura["IDSIGNATCERTSIGN"];
                                    $nrcpfsignatario  = $assinatura["NRCPFSIGNATARIO"];
                                    $situacao = $assinatura["IDSITUACAO"];
                                        
                                    // Chamada da API do Certsign
                                    $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrcpfsignatario);
                                    
                                    //inserir remoção no log 
                                    $this->removerSignatarioNoLog($delSignatCertsign, $assinatura["NRASSDIGITALORCA"], $nrorg);
                                    $del = $delSignatCertsign["response"]["id"];
                                    
                                    /* -- Limpa o ID dos signatários da proposta antiga -- */
                                    $params = array(
                                        "OPERADOR"         => $operador,
                                        "NRORG"            => $nrorg,
                                        "NRASSDIGITALORCA" => $assinatura["NRASSDIGITALORCA"],
                                        "NRSEQORCAMENTO"   => $assinatura["NRSEQORCAMENTO"],
                                        "NRSEQORCADOC"     => $assDoc["NRSEQORCADOC"]
                                    ); 
                                   
                                    $this->propostaFactory->updateSituacaoAssManualDoc($params);
                                    $retornos[] = 'OK';
                                    $realizado = $realizado+1;
                                }
                                else {
                            
                                    $retornos[] = 'N_DOC';
                                }
                        
                                $documentIdAux = $documentId;
                            }
                        };
                        
                        if ($realizado > 0) {  
                            $this->verificaSituacaoSignatarios($assinatura["NRSEQORCAMENTO"], $assinatura["NRASSDIGITALORCA"], $nrorg, $operador);
                        }
                    }
                }
            }
            
            $countOk = 0;
            $countNDoc = 0;
           
            foreach ($retornos as $retorno) {
                if ($retorno == 'OK') {
                    $countOk = $countOk+1;
                }
                else {
                    $countNDoc = $countNDoc+1;
                }
            }
            
            if (($countOk > 0) && ($countNDoc == 0)) {
                return 'OK';
            }
            else if (($countOk > 0) && ($countNDoc > 0)) {
                return 'OK_N_DOC';
            }
            else {
                return 'N_DOC';
            }
        
        } catch(\Exception $e) {
            
            if (isset($delSignatCertsign["response"]["message"])){
                
                if (isset($incSignatCertsign["response"]["statusCode"])) {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["statusCode"]. ' - ' .$delSignatCertsign["response"]["message"]);
                }
                else {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["message"]);
                }
            }
            else {
                throw $e;
            }
        }   
    }
    
    /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmenteDoc($signatarios, $checked, $nrorg, $operador) {
        try {
            if ($checked == true) {
                $assinaturas = $signatarios;  
            }   
            else {
                $assinaturas = array(
                    "0" => $signatarios
                );
            }
            
            /* Recebe Token Certsign */    
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
           
            $retornos = array();
            $realizado = 0;
           
            if (!empty($certsign)) {
                foreach ($assinaturas as $assinatura) {
                    $situacao = $assinatura["IDSITUACAO"];
                   
                    if ($situacao == 'P') {     
                        $params = array(
                            "NRSEQORCAMENTO"  => $assinatura["NRSEQORCAMENTO"],
                            "NRSEQORCADOC"    => $assinatura["NRSEQORCADOC"],
                            "NRORG"           => $nrorg
                        ); 
                       
                        $documentsId = $this->propostaFactory->getIdDocumentoCertsignDoc($params);
                        
                        $documentIdAux = 0;
                        $realizado = 0;
                        
                        foreach ($documentsId as $docId) {
                        
                            $documentId = $docId["IDDOCUMCERTSIGN"];
                        
                            if (($documentId != null) && ($documentId != $documentIdAux)) {
 
                                $params = array(
                                    "NRASSDIGITALORCA" => $assinatura["NRASSDIGITALORCA"],
                                    "NRSEQORCAMENTO"   => $assinatura["NRSEQORCAMENTO"],
                                    "NRORG"            => $nrorg
                                ); 
                               
                                $nrcpfsignatario = $this->propostaFactory->getCpfSignatAssDoc($params);
                                
                                if(!empty($nrcpfsignatario))
                                $nrCPF = $nrcpfsignatario[0]["NRCPFSIGNATARIO"];
                                
                                $idsignatcertsign = $assinatura["IDSIGNATCERTSIGN"];
                                $situacao = $assinatura["IDSITUACAO"];
                                    
                                // Chamada da API do Certsign
                                $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrCPF);
                                $this->removerSignatarioNoLog($delSignatCertsign, $assinatura["NRASSDIGITALORCA"], $nrorg);
                                $del = $delSignatCertsign["response"]["id"];
                                
                                /* -- Limpa o ID dos signatários da proposta antiga -- */
                                $params = array(
                                    "OPERADOR"         => $operador,
                                    "NRORG"            => $nrorg,
                                    "NRASSDIGITALORCA" => $assinatura["NRASSDIGITALORCA"],
                                    "NRSEQORCAMENTO"   => $assinatura["NRSEQORCAMENTO"],
                                    "NRSEQORCADOC"     => $assinatura["NRSEQORCADOC"]
                                ); 
                               
                                $this->propostaFactory->updateSituacaoAssManualDoc($params);
                                
                                $retornos[] = 'OK';
                                
                                $realizado = $realizado+1;
                            }
                            else {
                            
                                $retornos[] = 'N_DOC';
                            }
                
                            $documentIdAux = $documentId;
                        }
                        
                        if ($realizado > 0) {
                            $this->verificaSituacaoSignatarios($assinatura["NRSEQORCAMENTO"], $assinatura["NRASSDIGITALORCA"], $nrorg, $operador);
                        }
                   }
               };
            };
        
            $countOk = 0;
            $countNDoc = 0;
           
            foreach ($retornos as $retorno){
                
                if ($retorno == 'OK') {
                    
                    $countOk = $countOk+1;
                }
                else {
                    $countNDoc = $countNDoc+1;
                }
            };
            
            if (($countOk > 0) && ($countNDoc == 0)){
                return 'OK';
            }
            else if (($countOk > 0) && ($countNDoc > 0)){
                return 'OK_N_DOC';
            }
            else {
                return 'N_DOC';
            };    
        
        } catch(\Exception $e) {
            
           if (isset($delSignatCertsign["response"]["message"])){
               
                if (isset($incSignatCertsign["response"]["statusCode"])) {
                    
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["statusCode"]. ' - ' .$delSignatCertsign["response"]["message"]);
                }
                else{
                    
                   throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["message"]); 
                }
            }
            else{
                throw $e;
            }
        }   
    }
    
    
    /* Verifica se todos os as situações dos documentos de assinatura para atuzalizar os registros dos signatários. Sendo:
       - Se alguns dos documentos estiver recusado,  o signatário fica como recusado.
       - Fora o caso acima, caso ainda tenha algum documento pendente, o signatário permanece pendente.
       - Caso não haja nenhum pendente e nenhum recusado e algum registro aprovado, o signatário fica aprovado.
       - Caso não haja nenhum pendente e nenhum recusado e nenhum aprovado, o signatário fica manual.
    */
    public function verificaSituacaoSignatarios($seqProposta, $signatario, $nrorg, $operador) {
        try {
            
            $countAprovado  = 0;
            $countRecusado = 0;
            //$countPendente  = 0;
            $justificaRecusa = null;
            
            $params = array(
                "NRASSDIGITALORCA" => $signatario,
                "NRSEQORCAMENTO"   => $seqProposta,
                "NRORG"            => $nrorg
            );
            
            $dadosProposta = $this->propostaFactory->recebeDadosAssDocProp($params);  
            foreach ($dadosProposta as $dados) {
                
                if ($dados["IDSITUACAO"] == 'A') {
                    $countAprovado = $countAprovado+1;
                }
                else if ($dados["IDSITUACAO"] == 'R') {
                    $countRecusado = $countRecusado+1;
                    
                    if ($justificaRecusa == null) {
                        $justificaRecusa = $dados["DSJUSTIFICARECUSA"];
                    }
                    else {
                        $justificaRecusa = $justificaRecusa.' /// '.$dados["DSJUSTIFICARECUSA"];
                    }
                }
                /*else if ($dados["IDSITUACAO"] == 'P') {
                    $countPendente = $countPendente+1;
                } */
            } 

            $idsituacao = null;
            if ($countRecusado > 0) {
                $idsituacao = 'R';
            }
            /*else if ($countPendente > 0) {
                // O registro permanece pendente
            }*/
            else if ($countAprovado > 0) {
                $idsituacao = 'A';
            }
            else {
                $idsituacao = 'M';
            }

            $params = array(
                "IDSITUACAO"        => $idsituacao,
                "DSJUSTIFICARECUSA" => $justificaRecusa,
                "NRORG"             => $nrorg, 
                "OPERADOR"          => $operador,
                "NRASSDIGITALORCA"  => $signatario,
                "NRSEQORCAMENTO"    => $seqProposta
            );
            
            $this->propostaFactory->updateAssinaProposta($params);

        } catch(\Exception $e){
            throw $e;
        }
    }
    
    /**
     * Valida se as assinaturas da certsign estão aprovadas para a conclusão da proposta
     */
    public function validaAceiteCertsign($nrseqorcamento, $nrorg) {
        try {
            
           /* Recebe Token Certsign */    
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->propostaFactory->validaTokenCertsign($params);
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];
        
           if(!empty($certsign)) {
           
               /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG" => $nrorg
               );
               
               $idAssEletrDigital = $this->propostaFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                  
                   /* Recebe as assinaturas e verifica se todas estão aprovadas*/
                   $params = array(
                        "NRSEQORCAMENTO" => $nrseqorcamento,
                        "NRORG"          => $nrorg
                   );
                   
                   $assinaturas = $this->propostaFactory->recebeassinaturas($params); 
                   
                   $countPendCanc = 0;
                   foreach ($assinaturas as $assinatura){
                       
                       if ($assinatura["IDSITUACAO"] == 'P'|| $assinatura["IDSITUACAO"] == 'R'){
                         
                         $countPendCanc = $countPendCanc + 1; 
                       }
                   }
                   
                   if ($countPendCanc == 0){
                       $retorno = 'OK';
                   }
                   else{
                       $retorno = 'PENDENCIA';
                   }
                   
               }
               else{
                  $retorno = 'OK';     
               }    
           }
           else{
             
              $retorno = 'OK';  
           }

           return $retorno;    
           
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * A função "insereInterlocutor" realiza a inserção automática do interlocutor do parceiro
     */
    public function insereInterlocutor($nrseqorcamento, $interlocutor, $interlocutorAnte, $nrorg, $cdoperador, $nrorcamentomodelo){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if(!empty($certsign)) {
                
                
                $params = array(
                    "NRSEQORCAMENTO"    => $nrseqorcamento,
                    "NRPARCNEGOCIO"     => null,
                    "NRSEQINTERLOCUTOR" => $interlocutor,
                    "NRORG"             => $nrorg
                );
              
                $valida = $this->propostaFactory->validaSignatCadastrados($params);
                
                
                if ($valida == 0) {
                   
                    $params = array(
                        "NRSEQINTERLOCUTOR" => $interlocutor,
                        "NRORG"             => $nrorg
                    );
                   
                    $interloc = $this->propostaFactory->buscarDadosInterlocutor($params);

                    if (count($interloc) > 0) {
                           
                        $cpfInterloc = $interloc[0]["NRCPFINTERLOC"];
                        $tipoSignatario = $interloc[0]["IDTPSIGNATARIO"];
                            
                        if (($cpfInterloc != null) && ($tipoSignatario != null) && ($tipoSignatario != 'N')){
                           
                            $params = array(
                                "NRSEQORCAMENTO"    => $nrseqorcamento,
                                "NRPARCNEGOCIO"     => null,
                                "NRSEQINTERLOCUTOR" => $interlocutorAnte,
                                "NRORG"             => $nrorg
                            );
                           
                            $validaInterlocInserido = $this->propostaFactory->validaSignatCadastrados($params);
                           
                            if ($validaInterlocInserido > 0) {
                           
                                $params = array(
                                    "NRSEQINTERLOCUTOR" => $interlocutorAnte,
                                    "NRSEQORCAMENTO"    => $nrseqorcamento,
                                    "NRORG"             => $nrorg
                                );
                               
                                $this->propostaFactory->deleteInterlocutorInserido($params);
                            }
                           
                            if ($tipoSignatario == 'T') {
                                $testemunha = 'S';
                             
                                $params = array(
                                    "NRORCAMENTOMODELO" => $nrorcamentomodelo,
                                    "IDTPSIGNATARIO" => 'TC',
                                    "NRORG" => $nrorg
                                );
                            
                                $dadosSigCli = $this->propostaFactory->buscaSignatariosPadroesPorTipo($params);
                             
                            }
                            else {
                                $testemunha = 'N';
                             
                                $params = array(
                                    "NRORCAMENTOMODELO" => $nrorcamentomodelo,
                                    "IDTPSIGNATARIO" => 'SC',
                                    "NRORG" => $nrorg
                                );
                                
                                $dadosSigCli = $this->propostaFactory->buscaSignatariosPadroesPorTipo($params);
                            }
                            
                            if (count($dadosSigCli) > 0) {
                                $dadosSigCli = $dadosSigCli[0];
                                
                                $nrassdigitalorca = $this->newCode->getCodeByTableName("FCT_ASSINATDIGITALPROP", $nrorg, 1, 10, true);
                          
                                $params = array(
                                    "NRASSDIGITALORCA"   => $nrassdigitalorca,
                                    "NRSEQORCAMENTO"     => $nrseqorcamento,
                                    "NRSEQINTERLOCUTOR"  => $interlocutor,
                                    "NRPARCNEGOCIO"      => null,
                                    "NRCPFSIGNATARIO"    => $cpfInterloc,
                                    "IDTIPOASSINATURA"   => 'E', 
                                    "IDTESTEMUNHA"       => $testemunha,
                                    "NRORDENACAO"        => $dadosSigCli["NRORDENACAO"],
                                    "DSEMAILNOTSIGNENV"  => $dadosSigCli["DSEMAILNOTSIGNENV"],
                                    "DSEMAILNOTIFOUTROS" => $dadosSigCli["DSEMAILNOTIFOUTROS"],
                                    "NRORG"              => $nrorg,
                                    "OPERADOR"           => $cdoperador,
                                    "IDSIGNATCERTSIGN"   => null
                                );
                              
                                $this->propostaFactory->insereAssinatura($params);
                               
                                $params = array(
                                    "NRSIGNATPADRORCA" => $dadosSigCli["NRSIGNATPADRORCA"],
                                    "NRORG"            => $nrorg
                                ); 
                                
                                $operadores = $this->propostaFactory->buscaOperadoresNotif($params);
                                    
                                foreach($operadores as $operador) {
                                 
                                    $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
                   
                                    $params = array(
                                        "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                                        "NRASSDIGITALORCA"     => $nrassdigitalorca,
                                        "CDOPERADOR"           => $operador["CDOPERADOR"], 
                                        "NRORG"                => $nrorg,  
                                        "OPERADOR"             => $cdoperador
                                    );
                                    
                                    $this->propostaFactory->insereOperadoresNotifica($params);
                                }
                            }
                        }
                    }
                }
            }
        }
        catch(\Exception $e) {
            throw $e;
        }
    }

    // Função responsável por inserir interlocutor de faturamento.
    public function insereInterlocutorfat($nrseqorcamento, $interlocutorfat,  $nrorg, $cdoperador) {
            $params = array(
                "NRPARCINTERLOCUTORFAT" => $interlocutorfat,
                "NRSEQORCAMENTO"        => $nrseqorcamento,
                "NRORG"                 => $nrorg,
                "CDOPERULTATU"          => $cdoperador,
            );

            $this->propostaFactory->inserirInterlocutorFaturamento($params);
        
    }
    
    public function gerarDocumentosEEnviarAoPortalDeAssinaturasEletronica($nrseqorcamento, $tipoorcamentos, $nrorg, $idsituacaoorcamento, $documentoService, $nrorcamento, $operador){        
        $arquivos = $this->gerarArquivoDePropostas($nrseqorcamento, $tipoorcamentos, $nrorg, $idsituacaoorcamento, $documentoService, $nrorcamento); 
        return $this->enviarArquivosParaPortal($arquivos, $nrseqorcamento, $nrorg, $operador);
    }
    
    private function gerarArquivoDePropostas($nrseqorcamento, $tipoorcamentos, $nrorg, $idsituacaoorcamento, $documentoService, $nrorcamento){
        $arquivos = array();
        foreach ($tipoorcamentos as $nrtipoorcamento) {
            $params = array(
                "NRSEQORCAMENTO"  => $nrseqorcamento,
                "NRTIPOORCAMENTO" => $nrtipoorcamento
            );
            
            $idverificadoc = $this->propostaFactory->getIdVerificaDoc($params);
            if ($idverificadoc == 'S'){
                $caminhoArquivos = $documentoService->gerarDocumentoProposta($nrseqorcamento, $nrtipoorcamento, $nrorg, $idsituacaoorcamento, 'P');
                //$nmDocumento = $nrorcamento.'_'.$nrtipoorcamento.'.pdf';
                //$arquivos[$nmDocumento] = $caminhoArquivos[0]["DADOSDOCUMENTO"];
                foreach ($caminhoArquivos as $arq) {
                    $nmDocumento = $nrorcamento.'_'.$nrtipoorcamento.'.pdf';
                    $arquivos[$nmDocumento] = $arq["DADOSDOCUMENTO"];
                    $arquivos[$nmDocumento]["TIPOORCAMENTO"] = $nrtipoorcamento;
                }
            }
        }
        return $arquivos;
    }
    
    private function enviarArquivosParaPortal($arquivos, $nrseqorcamento, $nrorg, $operador) {
        foreach($arquivos as $nome => $arquivo) {
            $documento = $arquivo["DSCAMINHOARQ"];
            $nrtipoorcamento = $arquivo["TIPOORCAMENTO"];
                      
            $result = $this->gerarDocumentoCertsign($nrseqorcamento, $nrtipoorcamento, $nome, $documento, $nrorg, $operador);            
        }
        return $result;
    }
    
     /**
     * A função "gerarDocumentoCertsign" realiza o upload e cria o documento no ambiente certsign
     */
    public function gerarDocumentoCertsign($nrseqorcamento, $nrtipoorcamento, $nmDocumento, $documento, $nrorg, $operador){
        try {
            
            /* 1 - Realiza o Upload e recebe a string de upload para criação do documento no Certsign */
            $upload = $this->assinaturaDigital->uploadtoCertsing($nmDocumento, $documento);
            
            //inserir no log do update 
            $this->uploadCertisignNoLog($upload, $nrseqorcamento, $nrtipoorcamento, $nrorg);
            
            //$uploadId = $upload;
            $uploadId = $upload["response"]["uploadId"];
            
            /* -- Arrumando a String para criação do documento -- */
            //$uploadId = str_replace(array('{"uploadId":"', '"}'), '', $uploadId);
            //$uploadId = str_replace('\/', '/', $uploadId);
        
            /* 2 - Cria o documento no Certsign */
            
            /* -- Recebe dados do Sender -- */
            $params= array(
                "NRORG" => $nrorg
            );        
            
            $responsavel = $this->propostaFactory->getDadosSender($params);
            
            $sender = array();
             
            foreach ($responsavel as $resp) {
                $sender['NOME']  = $resp['NMSENDERCERTSIGN'];
                $sender['EMAIL'] = $resp['DSEMAILSENDERCERTSIGN'];
                $sender['CPF']   = $resp['NRCPFSENDERCERTSIGN'];
            }
            
            /* -- Recebe os Signatários Digitais -- */
            
            $params = array(
                "NRSEQORCAMENTO"   => $nrseqorcamento,
                "IDTIPOASSINATURA" => 'D',
                "NRORG"            => $nrorg
            );        
            
            $signatarios = $this->propostaFactory->getSignatarios($params);
        
            $signers = array();
        
            foreach ($signatarios as $ind => $sign) {
                
                if ($sign['IDTESTEMUNHA'] == 'N') {
                    $testemunha = 'Signer';  
                }
                else {
                    $testemunha = 'Witness';   
                }
                
                $signers[$ind] = array(
                    'POSICAO' => $sign['NRORDENACAO'],
                    'TIPO'    => $testemunha,
                    'NOME'    => $sign['NOME'],
                    'EMAIL'   => $sign['EMAIL'],
                    'CPF'     => $sign['NRCPFSIGNATARIO']
                );
            }
            
            /*  -- Recebe os Signatários Eletrônicos -- */
            
            $params= array(
                "NRSEQORCAMENTO"   => $nrseqorcamento,
                "IDTIPOASSINATURA" => 'E',
                "NRORG"            => $nrorg
            );        
            
            $signatarios = $this->propostaFactory->getSignatarios($params);
        
            $eletrSigners = array();
        
            foreach ($signatarios as $ind => $sign) {
                if ($sign['IDTESTEMUNHA'] == 'N'){
                    $testemunha = 'Signer';  
                }
                else{
                    $testemunha = 'Witness';   
                }
                
                $eletrSigners[$ind] = array(
                    'POSICAO' => $sign['NRORDENACAO'],
                    'TIPO'    => $testemunha,
                    'NOME'    => $sign['NOME'],
                    'EMAIL'   => $sign['EMAIL'],
                    'CPF'     => $sign['NRCPFSIGNATARIO']
                );
            }
            
            /* -- Recebe o Tipo de Documento e email do operador responsável -- */
            
            $params= array(
                "NRSEQORCAMENTO" => $nrseqorcamento
            );    
            
            $tipoDocParamSm = (int)$responsavel[0]['NRTIPODOCCERTSIGN'];
            $padraoAssinatura = (int)$responsavel[0]['IDPADRAOASSINACERTSIGN'];
            
            $dados = $this->propostaFactory->getTipoDocumento($params);
            $tipoDoc = (int)$dados[0]['NRTIPODOCCERTSIGN'];
            if(empty($tipoDoc)){
                $tipoDoc = $tipoDocParamSm;
            }
            
            $dados = $this->propostaFactory->getEnviarDocAss($params);
            $emailOperResp = null;
            if(count($dados) > 0) {
                $emailOperResp = $dados[0]['DSEMAILOPER'];
            }
            
            /* -- Chama a API para criar o Documento no Certsign -- */
            $docCertsign = $this->assinaturaDigital->createSignatureCertsing($uploadId, $nmDocumento, $sender, $signers, $eletrSigners, $padraoAssinatura, $tipoDoc, $emailOperResp);
            
            //inserir no log do create
            $this->createCertisignNoLog($docCertsign, $nrseqorcamento, $nrtipoorcamento, $nrorg);
            
            //if ($docCertsign["response"]["message"]){
            /* -- Atualiza o registro dos documentos da proposta para incluir o ID e a Chave do Certsing -- */
            
            $id    = $docCertsign['response']['id'];
            $chave = $docCertsign['response']['chave'];
            
            $params = array(
                "IDDOCUMCERTSIGN"    => $id,
                "CHAVEDOCUMCERTSIGN" => $chave,
                "OPERADOR"           => $operador,
                "NRORG"              => $nrorg,
                "NRSEQORCAMENTO"     => $nrseqorcamento,
                "NRTIPOORCAMENTO"    => $nrtipoorcamento
            );        
            
            $this->propostaFactory->updateDocumentoIdCertsign($params);
             
            /* -- Atualiza o registro dos signatários da proposta para incluir o ID do Certsing -- */
            
            
            $attendees = $docCertsign['response']['attendees'];
            foreach ($attendees as $signatario){
                
                /* recebe o sequencial do signatário */
                $params = array(
                    "NRSEQORCAMENTO"  => $nrseqorcamento,
                    "NRCPFSIGNATARIO" => $signatario['individualIdentificationCode'],
                    "NRORG"           => $nrorg
                );  
                
                $seqSignatario = $this->propostaFactory->recebeSeqSignatario($params);
                
                if (!empty($seqSignatario))
                    $seqSignat = $seqSignatario[0]["NRASSDIGITALORCA"];
                
                /* recebe o sequencual do documento */
                $params = array(
                    "NRSEQORCAMENTO"     => $nrseqorcamento,
                    //"NRTIPOORCAMENTO"    => $nrtipoorcamento,
                    "NRORG"              => $nrorg
                );
                
                $seqDocumento = $this->propostaFactory->recebeSeqDocOrca($params, $nrtipoorcamento);
                
                $nrseqorcadoc = null;
                if (!empty($seqDocumento))
                    $nrseqorcadoc = $seqDocumento[0]["NRSEQORCADOC"];
                
                /*Atualiza o documento do signatário*/
                if ((!empty($seqSignat)) && (!empty($nrseqorcadoc))) {
                
                    $nrDocAssinatProp = $this->newCode->getCodeByTableName("FCT_DOCASSINATPROP", $nrorg, 1, 10, true);
                  
                    $params = array(
                        "NRDOCASSINATPROP" => $nrDocAssinatProp,
                        "NRASSDIGITALORCA" => $seqSignat,
                        "NRSEQORCADOC"     => $nrseqorcadoc,
                        "IDSIGNATCERTSIGN" => $signatario['signerId'],
                        "NRSEQORCAMENTO"   => $nrseqorcamento,
                        "NRORG"            => $nrorg,
                        "OPERADOR"         => $operador
                    );
                    
                    $this->propostaFactory->insereDocAssinatura($params);
                }
            }
            return "OK";
        }
        catch(\Exception $e) {
            if (isset($docCertsign["response"]["message"])) {
                if (isset($incSignatCertsign["response"]["statusCode"])) {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$docCertsign["response"]["statusCode"]. ' - ' .$docCertsign["response"]["message"]);
                }
                else {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$docCertsign["response"]["message"]); 
                }
            }
            else {
                throw $e;
            }
        }
    }
    
    /**
     * A função "inserirSignatario" realiza a inclusão de um novo signatário.
     */
    public function inserirSignatario($dados, array $codEscopos) {
        try {
            $nrorg              = $this->environment->getNrOrg();
            $operador           = $this->environment->getCdOperador();
            $nrseqorcamento     = $dados["NRSEQORCAMENTO"];
            $nrparcnegocio      = $dados["NRPARCNEGOCIO"];
            $interlocutor       = $dados["NRSEQINTERLOCUTOR"];
            $nome               = $dados["NMPRINCIPALPARC"];
            $email              = $dados["EMAIL"];
            $cpf                = $dados["NRCPFSIGNATARIO"];
            $tipo               = $dados["IDTIPOASSINATURA"];
            $testemunhaId       = $dados["IDTESTEMUNHA"];
            $ordenacao          = $dados["NRORDENACAO"];
            $dsemailnotsignenv  = $dados["DSEMAILNOTSIGNENV"];
            $dsemailnotifoutros = $dados["DSEMAILNOTIFOUTROS"];
            $nrassdigitalorca   = null;
            
            $retorno = array();
           
            $params = array(
               "NRSEQORCAMENTO"    => $nrseqorcamento,
               "NRPARCNEGOCIO"     => $nrparcnegocio,
               "NRSEQINTERLOCUTOR" => $interlocutor,
               "NRORG"             => $nrorg
            );
          
            $valida = $this->propostaFactory->validaSignatCadastrados($params);
           
            if ($valida == 0) {
                // -- Insere Signatário --
                $nrassdigitalorca = $this->newCode->getCodeByTableName("FCT_ASSINATDIGITALPROP", $nrorg, 1, 10, true);
               
                $params= array(
                   "NRASSDIGITALORCA"   => $nrassdigitalorca,
                   "NRSEQORCAMENTO"     => $nrseqorcamento,
                   "NRSEQINTERLOCUTOR"  => $interlocutor,
                   "NRPARCNEGOCIO"      => $nrparcnegocio,
                   "NRCPFSIGNATARIO"    => $cpf, //$signer['individualIdentificationCode'],
                   "IDTIPOASSINATURA"   => $tipo, 
                   "IDTESTEMUNHA"       => $testemunhaId, 
                   "NRORDENACAO"        => $ordenacao, 
                   "DSEMAILNOTSIGNENV"  => $dsemailnotsignenv,
                   "DSEMAILNOTIFOUTROS" => $dsemailnotifoutros,
                   "NRORG"              => $nrorg,  
                   "OPERADOR"           => $operador,
                   "IDSIGNATCERTSIGN"   => null //$signer['id']
                );

              
                $this->propostaFactory->insereAssinatura($params);
                
                /* recebe o sequencual do documento */
                $codEscoposString = implode(",", $codEscopos);
                
                $params = array(
                    "NRSEQORCAMENTO"  => $nrseqorcamento,
                    //"NRTIPOORCAMENTO" => $nrtipoorcamento,
                    "NRORG"           => $nrorg
                );  
                
                $docsProposta = $this->propostaFactory->recebeSeqDocOrca($params, $codEscoposString);
                foreach ($docsProposta as $doc) {
                    $documento = $doc["NRSEQORCADOC"];
                    $nrtipoorcamento = $doc["NRTIPOORCAMENTO"];
                    $documentId = $doc["IDDOCUMCERTSIGN"];
                    
                    if (!empty($documentId)) {
                        if ($tipo == 'D') {
                            $signers      = array();
                            $eletrSigners = array();
                            
                            if ($testemunhaId == 'N') {
                                $testemunha = 'Signer';
                            }
                            else {
                                $testemunha = 'Witness';
                            }
                            
                            $signers[0] = array(
                                'POSICAO' => $ordenacao,
                                'TIPO'    => $testemunha,
                                'NOME'    => $nome,
                                'EMAIL'   => $email,
                                'CPF'     => $cpf
                            );
                        }
                        else {
                            $signers      = array();
                            $eletrSigners = array();
                                
                            if ($testemunhaId == 'N') {
                                $testemunha = 'Signer';
                            }
                            else {
                                $testemunha = 'Witness';
                            }
                            
                            $eletrSigners[0] = array(
                                'POSICAO' => $ordenacao,
                                'TIPO'    => $testemunha,
                                'NOME'    => $nome,
                                'EMAIL'   => $email,
                                'CPF'     => $cpf
                            );
                        }
                        
                        // -- Chama a API para inserir o signatario no Certsign --
                        $incSignatCertsign = $this->assinaturaDigital->incluirSignatario($documentId, $signers, $eletrSigners);
                        
                        //inserir no log o signatario
                        $this->inserirSignatarioNoLog($incSignatCertsign, $nrassdigitalorca, $nrorg);
                        // -- Atualiza o registro dos signatários da proposta para incluir o ID do Certsing --
                        $signatarios = $incSignatCertsign["response"];
                        
                        foreach ($signatarios as $signatario) {
                            foreach ($signatario as $signer) {
                                if (isset($signer["individualIdentificationCode"])) {
                                    
                                    $nrDocAssinatProp = $this->newCode->getCodeByTableName("FCT_DOCASSINATPROP", $nrorg, 1, 10, true);
                                    $params = array(
                                        "NRDOCASSINATPROP" => $nrDocAssinatProp,
                                        "NRASSDIGITALORCA" => $nrassdigitalorca,
                                        "NRSEQORCADOC"     => $documento,
                                        "IDSIGNATCERTSIGN" => $signer["id"],
                                        "NRSEQORCAMENTO"   => $nrseqorcamento,
                                        "NRORG"            => $nrorg,
                                        "OPERADOR"         => $operador
                                    );
                                    
                                    $this->propostaFactory->insereDocAssinatura($params);
                                }
                            }
                        }
                    }
                }
            }
            
            $retorno['STATUS']           = 'OK';
            $retorno['NRASSDIGITALORCA'] = $nrassdigitalorca;
            return $retorno;
        }
        catch(\Exception $e) {
            if ($nrassdigitalorca) {
                $params = array(
                    "NRASSDIGITALORCA" => $nrassdigitalorca,
                    "NRORG"            => $nrorg
                );
                $this->propostaFactory->excluirSignatarioProposta($params);
            }
            
            if (isset($incSignatCertsign["response"]["message"])) {
                
                if (isset($incSignatCertsign["response"]["statusCode"])) {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$incSignatCertsign["response"]["statusCode"].' - '.$incSignatCertsign["response"]["message"]);
                }
                else {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$incSignatCertsign["response"]["message"]);
                }
            }
            else {
                throw $e;
            }
        }   
    }
    
    /**
     * A função "excluirDocumentoCertsign" realiza a exclusão do documento no Certsign.
     */
    public function excluirDocumentoCertsign($nrseqorcamento, $nrtipoorcamento, $nrorg, $operador){
        try {
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG" => $nrorg
               );
               
               $idAssEletrDigital = $this->propostaFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                   
                   $params = array(
                        "NRSEQORCAMENTO"  => $nrseqorcamento,
                        "NRTIPOORCAMENTO" => $nrtipoorcamento,
                        "NRORG"           => $nrorg
                    ); 
                   
                    $documentsId = $this->propostaFactory->getIdDocumentoCertsign($params);
                    
                    $documentIdAux = 0;
                    
                    foreach($documentsId as $docId) {
                        
                        $documentId = $docId["IDDOCUMCERTSIGN"];
                        
                        if (($documentId != null) && ($documentId != $documentIdAux)) {
                            
                            /* -- Chama a API para excluir o documento no Certsign -- */
                            $delDocCertsign = $this->assinaturaDigital->excluirdocumento($documentId);
                            
                            //inserir delete no log
                            $this->deleteCertisignNoLog($delDocCertsign, $nrseqorcamento, $nrtipoorcamento, $nrorg);
                            
                            /* -- Limpa o ID e a Chave dos documentos da proposta antiga -- */
                            $params = array(
                                "OPERADOR"        => $operador,
                                "NRORG"           => $nrorg,
                                "NRSEQORCAMENTO"  => $nrseqorcamento,
                                "NRTIPOORCAMENTO" => $nrtipoorcamento
                            ); 
                            
                            $this->propostaFactory->clearDocumentoIdCertsign($params);
                            
                            /* -- Limpa o ID dos signatários da proposta antiga -- */
                            $params = array(
                                "OPERADOR"       => $operador,
                                "NRORG"          => $nrorg,
                                "NRSEQORCAMENTO" => $nrseqorcamento,
                                "NRCPFSIGNATARIO" => 'T'
                            ); 
                           
                            $this->propostaFactory->clearSignatarioIdCertsign($params);
                            
                        }
                        
                        $documentIdAux = $documentId;
                    }
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * A função "excluirSignatariosCertsign" realiza a exclusão de um signatário no Certsign.
     */
    public function excluirSignatariosCertsign($nrseqorcamento, $nrassdigitalorca, $nrtipoorcamento, $idsignatcertsign, $nrcpfsignatario, $nrorg, $operador){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG" => $nrorg
               );
               
               $idAssEletrDigital = $this->propostaFactory->recebeIdAssEletrDigital($params);
            
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S'){
                   
                    $idAceitaExclusao  = 'N';
                    
                    $params = array(
                        "NRASSDIGITALORCA" => $nrassdigitalorca,
                        "NRSEQORCAMENTO"   => $nrseqorcamento,
                        "NRORG"            => $nrorg
                    );
                    
                    $dadosProposta = $this->propostaFactory->recebeDadosAssDocProp($params);  
                    
                    foreach ($dadosProposta as $dados){
                        
                        if (($dados["IDSITUACAO"] != 'P') && ($dados["IDSITUACAO"] != 'M')) {
                            
                             $idAceitaExclusao = 'S'; 
                        }
                    }
                   
                    if ($idAceitaExclusao != 'S'){
                        
                       $params = array(
                            "NRSEQORCAMENTO"  => $nrseqorcamento,
                            "NRTIPOORCAMENTO" => $nrtipoorcamento,
                            "NRORG"           => $nrorg
                        ); 
                       
                        $documentsId = $this->propostaFactory->getIdDocumentoCertsign($params);
                        
                        $documentIdAux = 0;
                        
                        foreach($documentsId as $docId) {
                            
                            $documentId = $docId["IDDOCUMCERTSIGN"];
                            
                            if (($documentId != null) && ($documentId != $documentIdAux)) {
                              
                                /* -- Chama a API para excluir um signatário no Certsign -- */
                                $delSignatCertsign = $this->assinaturaDigital->excluirSignatario($documentId, $idsignatcertsign, $nrcpfsignatario);
                                
                                //inserir remoção do signatario no log
                                $this->removerSignatarioNoLog($delSignatCertsign, $nrassdigitalorca, $nrorg);
                                  
                                $signatario = $delSignatCertsign['response']['id'];
                                
                                $documentIdAux = $documentId;
                            }
                        }
                    } 
                    else {
                        throw new \Exception("Operação bloqueada!<br/><br/>Existem documentos já assinados ou recusados.");
                    }
                }
            }
            
            return 'OK';
            
        } catch(\Exception $e) {
            if (isset($delSignatCertsign["response"]["message"])){
                
                if (isset($delSignatCertsign["response"]["statusCode"])){
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["statusCode"].' - '.$delSignatCertsign["response"]["message"]);
                }
                else {
                    throw new \Exception('Ocorreram erros durante a integração com o Portal Certisign: <br><br>'.$delSignatCertsign["response"]["message"]);
                }
            }
            else{
                throw $e;
            }
        }
    }

    /**
     * realiza o download do documento do ambiente Certsign 
    **/
    public function downloadDocEletrDigital($nrseqorcamento, $nrtipoorcamento, $nrorg){
        
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->propostaFactory->validaTokenCertsign($params);
            $certsign = $certsign[0]["DSTOKENCERTSIGN"];
            
            if(!empty($certsign)) {
                
                /* Recebe identificador de utilização de assinatura eletrônica ou digital*/
               $params = array(
                    "NRSEQORCAMENTO" => $nrseqorcamento,
                    "NRORG"          => $nrorg
               );
               
               $idAssEletrDigital = $this->propostaFactory->recebeIdAssEletrDigital($params);
               $idAssEletrDigital = $idAssEletrDigital[0]["IDASSELETRDIGITAL"];
               
               if ($idAssEletrDigital == 'S') {
                   $params = array(
                        "NRSEQORCAMENTO"  => $nrseqorcamento,
                        "NRTIPOORCAMENTO" => $nrtipoorcamento,
                        "NRORG"           => $nrorg
                    ); 
                   
                    $documentsId = $this->propostaFactory->getIdDocumentoCertsign($params);
                    
                    $documentIdAux = 0;
                    
                    foreach($documentsId as $docId) {
                        
                        $documentId = $docId["IDDOCUMCERTSIGN"];
                        $chave      = $docId["CHAVEDOCUMCERTSIGN"];
                        
                        if (($documentId != null) && ($documentId != $documentIdAux)) {
                            
                            $ds = DIRECTORY_SEPARATOR;
                            
                            /* -- Chama a API para Download do documento no Certsign -- */
                            $downDocCertsign = $this->assinaturaDigital->dowloadDocumento($chave);
                            
                            //inserir dowload no log 
                            $this->downloadCertisignNoLog($downDocCertsign, $nrseqorcamento, $nrtipoorcamento, $nrorg);
                            
                            $docs = $downDocCertsign['response'];
                            $conteudo = base64_decode($docs['bytes']);

                            $file = $this->tempDir.$ds.$docs['name'];
                            
                            file_put_contents($file, $conteudo);

                            if (file_exists($file)) {
                                set_time_limit(0);
                                
                                header('Content-Description: File Transfer');
                                header('Content-Transfer-Encoding: binary');
                                header('Content-Type: '. $docs['mimeType']);
                                header('Content-Disposition: attachment; filename="'.basename($file).'"');
                                header('Expires: 0');
                                header('Cache-Control: must-revalidate');
                                header("Pragma: no-cache");
                                header('Content-Length: ' . filesize($file));
                                ob_clean();
                                flush();
                                
                                readfile($file);   
                                exit;
                            }
                        }
                        
                        $documentIdAux = $documentId;
                    }
                }
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /**
     * realiza a atualização do Nr. de Parcelas da negociação
     **/
    public function atualizarNrParcelas($nrnegociacaoproposta, $nrorg){
        
        $params = array(
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta,
            "NRORG"                => $nrorg
        );
        
        $parcelas = $this->propostaFactory->getParcelasOrderQtDiasFatu($params);
        
        $cont = 0;
        foreach($parcelas as $parcela){
            
            $cont = $cont+1;
            
            $params = array(
                "NRPARCELA"         => $cont,
                "NRPARCELANEGOPROP" => $parcela['NRPARCELANEGOPROP'],
                "NRORG"             => $nrorg
            );
            
            $this->propostaFactory->atualizarNrParcelas($params);
        }
    }
    
    
    /**
     * Habilita / Desabilita proposta para assinatura eletrônica e digital 
     **/
    public function habilitarAssinaturaEletrDigital($row, $nrorg, $operador){
        
        $nrseqorcamento    = $row["NRSEQORCAMENTO"];
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $valida = $this->propostaFactory->validaGeracaoDocCertisign($params);
        
        if ($valida == 0){
            
            $retorno  = 'OK';
            
            $params = array(
                "NRORG"          => $nrorg,
                "OPERADOR"       => $operador,
                "NRSEQORCAMENTO" => $nrseqorcamento
            );
            
            $this->propostaFactory->habilitaAssinatura($params);
            
        }
        else {
            $retorno = "Operação Bloqueada! <br><br> Não é permitido desabilitar a assinatura eletronica e digital quando já foram gerados documentos.";
        }
        
        return $retorno;
    }
    
    /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function validaFiltroServico($tipoorcamento, $nrorg){
        
        $filtrar = 'N';
        
        foreach ($tipoorcamento as $escopo){
            
            $params = array(
                "NRTIPOORCAMENTO" => $escopo,
                "NRORG"           => $nrorg
            );
            
            $count = $this->propostaFactory->countServicos($params);
            
            if ($count > 0) {
                
                $valida = $this->propostaFactory->validaFiltroServico($params);
                
                if ($valida == 'S') {
                    $filtrar = 'S';
                } 
            }
        }
        
        return $filtrar;
    }
    
   /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function validaStatusAssinaturas($nrseqorcamento, $nrorg){
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"           => $nrorg
        );
        
        $situacoes = $this->propostaFactory->validaStatusAssinaturas($params);
        
        $resultado = 'N_Pendente'; 
        
        foreach ($situacoes as $situacao){
            
            if ($situacao["IDSITUACAO"] == 'P') {
                
                $resultado = 'Pendente';
            }
        }
        
        return $resultado;
    }
    
    /**
     * A função "insereOperadoresNotifica" realiza a inserção dos operadores do sistema que devem ser notificados.
     */
    public function insereOperadoresNotifica($nrassdigitalorca, $operadores) {
        $nrorg = $this->environment->getNrOrg();
        $operador = $this->environment->getCdOperador();
       
        /* -- Deleta os registros antigos -- */
        $params = array(
            "NRASSDIGITALORCA" => $nrassdigitalorca,
            "NRORG"            => $nrorg
        );
      
        $this->propostaFactory->deletaOperadoresNotifica($params);
        
        if (!empty($operadores) && is_array($operadores)) {
            foreach ($operadores as $cdoperdor) {
                $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
                $params = array(
                    "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                    "NRASSDIGITALORCA"     => $nrassdigitalorca,
                    "CDOPERADOR"           => $cdoperdor,
                    "NRORG"                => $nrorg,
                    "OPERADOR"             => $operador
                );
              
                $this->propostaFactory->insereOperadoresNotifica($params);
            }
        }
    }
    

    public function recebeOrdenacaoENotificacoes($orcamentoModelo, $idtpsignatario, $nrorg){
        try {
            
           $retorno = array();
           
           $params = array(
              "NRORCAMENTOMODELO" => $orcamentoModelo, 
              "IDTPSIGNATARIO"    => $idtpsignatario,
              "NRORG"             => $nrorg
           );
          
           $dados = $this->propostaFactory->recebeOrdenacaoENotificacoes($params);
           if (count($dados) != 0) {
               $retorno['DADOS'] = 'OK';
               $retorno['NRORDENACAO']        = $dados[0]['NRORDENACAO'];
               $retorno['DSEMAILNOTSIGNENV']  = $dados[0]['DSEMAILNOTSIGNENV'];
               $retorno['DSEMAILNOTIFOUTROS'] = $dados[0]['DSEMAILNOTIFOUTROS'];
               
               $nrsignatpadrorca = $dados[0]['NRSIGNATPADRORCA'];
               
               $params = array(
                  "NRSIGNATPADRORCA" => $nrsignatpadrorca, 
                  "NRORG"            => $nrorg
               );
               
               $operadores = $this->propostaFactory->recebeOperdoresNotificacoes($params);
               
               foreach ($operadores as $operador){
                   
                   $retorno['OPERADORES'][] = $operador["CDOPERADOR"];
               }
               
           }
           else{
               
             $retorno['DADOS'] = 'VAZIO';
           }
           
           return $retorno;
        }
        catch(\Exception $e) {
            throw $e;
        }
    }

    public function validaGeraDocCertisign($orcamentoModelo, $nrorg){
        try {
           $params = array(
              "NRORCAMENTOMODELO" => $orcamentoModelo, 
              "NRORG"             => $nrorg
           );
          
           $retorno = $this->propostaFactory->validaGeraDocCertisign($params);
           return $retorno;
        }
        catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function inserirDadosDosElementosInvisiveisNaProposta($escopos, $composicoes, $nrseqorcamento, $arrayItensPai, $medidas, $nrorg) {
        $dadosProposta = $this->getDadosProposta($nrseqorcamento, $nrorg);
        $nrmoeda = $dadosProposta["NRMOEDA"];
        
        // Pega os elementos da composição que são invisiveis na proposta e os insere
        $elementosInvisiveisProposta = $this->getElementosComposicao($escopos, $composicoes, "N", $nrmoeda);
        $elementosInvisiveisProposta = $this->zerarValoresElementosInvisiveis($elementosInvisiveisProposta);
        $this->inserirElementosProposta($elementosInvisiveisProposta, $nrseqorcamento);
        
        // Pega os itens do tipo elemento para inserir na tabela de itens da proposta
        $elementosSemCodComposicao = $this->getElementosComposicaoSemCodigoComposicao($escopos, $composicoes, $nrorg, "N", $nrmoeda);
        $elementosSemCodComposicao = $this->eliminarElementosDuplicados($elementosSemCodComposicao);
        //$elementosSemCodComposicao = $this->validarItensOrcamento($elementosSemCodComposicao, $elementosEscolhidos, $variacoesPreco, $medidas);
        
        $itensElementoInvisiveis = array();
        
        $itensElementoInvisiveis = $this->getItensMedida($elementosSemCodComposicao, $nrorg);
        $itensElementoInvisiveis = $this->zerarValoresElementosInvisiveis($itensElementoInvisiveis);
        
        //Remover a linha abaixo se não for puxar a quantidade de medida de outros itens
        $itensElementoInvisiveis = $this->atualizarQuantidadeMedidaParaItensInvisiveis($itensElementoInvisiveis, $nrseqorcamento, $nrorg);
        
        $this->inserirItensProposta($itensElementoInvisiveis, $nrseqorcamento, $arrayItensPai);
        
        // Pega os tipos de medida variáveis desses elementos para inserir também
        $idelementos = array();
        foreach ($elementosInvisiveisProposta as $elemento) {
            array_push($idelementos, $elemento["IDELEMENTO"]);
        }
        $tiposMedidaInvisiveis = $this->getTiposMedidaVariaveisDosElementos(null, $idelementos, $escopos, $nrorg);
        $tiposMedidaInvisiveis = $this->vincularEscopoAoTipoDeMedida($tiposMedidaInvisiveis, $itensElementoInvisiveis,  $escopos);
        
        //Remover a linha abaixo se não for puxar a quantidade de medida de outros itens
        $tiposMedidaInvisiveis = $this->atualizarQuantidadeMedidaParaMedidasInvisiveis($tiposMedidaInvisiveis, $medidas);
        
        $this->inserirTipoDeMedidaProposta($tiposMedidaInvisiveis, $nrseqorcamento, "N");
    }
    
    public function zerarValoresElementosInvisiveis(array $elementos) {
        foreach ($elementos as &$elemento) {
            $elemento["IDAPARECEPROPOSTA"] = 'N';
            
            $elemento["QTMEDIDASERV"]      = 1;
            $elemento["QTMEDIDASERV_GRID"] = 1;
            $elemento["QTMEDIDAVARIAVEL"]  = 1;
            $elemento["QTMEDIDACALC"]      = 1;
            $elemento["QTMEDIDACALCULADA"] = 1;
            
            $elemento["VRUNITARIO"]             = 0;
            $elemento["VRPRECO"]                = 0;
            $elemento["VRUNITITEMORCA"]         = 0;
            $elemento["VRUNITITEMORCA_GRID"]    = 0;
            $elemento["VRUNITITEMORCATBLPRECO"] = 0;
            $elemento["VRTOTALITEMORCA"]        = 0;
            $elemento["VRITEMSEMDESC"]          = 0;
        }
        unset($elemento);
        
        return $elementos;
    }
    
    public function atualizarQuantidadeMedidaParaMedidasInvisiveis($tiposMedidaInvisiveis, $medidas) {
        foreach ($tiposMedidaInvisiveis as &$tipoMedidaInvisivel) {
            foreach ($medidas as $medida) {
                if ($tipoMedidaInvisivel["CDTPMEDIDASERV"] == $medida["CDTPMEDIDASERV"]) {
                    $tipoMedidaInvisivel["QUANTIDADE"] = $medida["QUANTIDADE"];
                    break;
                }
            }
        }
        unset($tipoMedidaInvisivel);
        
        return $tiposMedidaInvisiveis;
    }
    
    public function atualizarQuantidadeMedidaParaItensInvisiveis($itensElementoInvisiveis, $nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $itensElementoProposta = $this->propostaFactory->getItensElementoProposta($params);
        
        foreach ($itensElementoInvisiveis as &$itemElementoInvisivel) {
            foreach ($itensElementoProposta as $itemElementoProposta) {
                if ($itemElementoInvisivel["CDSERVORCA"] == $itemElementoProposta["CDSERVORCA"] &&
                  $itemElementoInvisivel["CDTPMEDIDASERV"] == $itemElementoProposta["CDTPMEDIDASERV"] &&
                  $itemElementoInvisivel["CDTPMEDIDAVARIAVEL"] == $itemElementoProposta["CDTPMEDIDAVARIAVEL"]) {
                    
                    $itemElementoInvisivel["QTMEDIDASERV"] = $itemElementoProposta["QTMEDIDAORCA"];
                    break;
                }
            }
        }
        unset($itemElementoInvisivel);
        
        return $itensElementoInvisiveis;
    }
    
    public function getUtilizaAssinaturaEletronicaProposta($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->propostaFactory->getUtilizaAssinaturaEletronicaProposta($params);
        return $dataset[0]["IDASSELETRDIGITAL"];
    }
    
    public function salvarDadosIntegracaoOMConclusaoProposta($dados, $nrseqorcamento, $nrorg){
        $dados = json_encode($dados);
        $params = array(
            "DADOS"          => $dados,
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        $this->propostaFactory->salvarDadosIntegracaoOMConclusaoProposta($params);
    }
    
    public function inserirSignatarioNoLog($incSignatCertsign, $nrassdigitalorca, $nrorg){
        $this->propostaFactory->inserirLogAddSignatario(array(
           "JSONPARTADDCERTISIGN" => json_encode($incSignatCertsign),
           "NRASSDIGITALORCA"   => $nrassdigitalorca,
           "NRORG"              => $nrorg 
        ));
    }
    
    public function removerSignatarioNoLog($delSignatCertsign, $nrassdigitalorca, $nrorg){
        $this->propostaFactory->inserirLogRemoveSignatario(array(
           "JSONPARTDELETECERTISIGN" => json_encode($delSignatCertsign),
           "NRASSDIGITALORCA"   => $nrassdigitalorca,
           "NRORG"              => $nrorg 
        ));
    }
    
    public function notificarSignatarioNoLog($dado, $nrseqorcamento, $nrtipoorcamento, $nrorg){
        $this->propostaFactory->notificarSignatarioNoLog(array(
           "JSONSENDREMINDERCERTISIGN" => json_encode($dado),
           "NRSEQORCAMENTO"            => $nrseqorcamento,
           "NRTIPOORCAMENTO"           => $nrtipoorcamento,
           "NRORG"                     => $nrorg 
        ));
    }
    
    public function uploadCertisignNoLog($dado, $nrseqorcamento, $nrtipoorcamento, $nrorg){
        $this->propostaFactory->uploadCertisignNoLog(array(
           "JSONUPLOADDOCCERTISIGN" => json_encode($dado),
           "NRSEQORCAMENTO"         => $nrseqorcamento,
           "NRTIPOORCAMENTO"        => $nrtipoorcamento,
           "NRORG"                  => $nrorg 
        ));
    }
    
    public function createCertisignNoLog($dado, $nrseqorcamento, $nrtipoorcamento, $nrorg){
        $this->propostaFactory->createCertisignNoLog(array(
           "JSONCREATEDOCCERTISIGN" => json_encode($dado),
           "NRSEQORCAMENTO"         => $nrseqorcamento,
           "NRTIPOORCAMENTO"        => $nrtipoorcamento,
           "NRORG"                  => $nrorg 
        ));
    }
    
    public function deleteCertisignNoLog($dado, $nrseqorcamento, $nrtipoorcamento, $nrorg){
        $this->propostaFactory->deleteCertisignNoLog(array(
           "JSONDELETEDOCCERTISIGN" => json_encode($dado),
           "NRSEQORCAMENTO"         => $nrseqorcamento,
           "NRTIPOORCAMENTO"        => $nrtipoorcamento,
           "NRORG"                  => $nrorg 
        ));
    }
    
    public function downloadCertisignNoLog($dado, $nrseqorcamento, $nrtipoorcamento, $nrorg){
        $this->propostaFactory->downloadCertisignNoLog(array(
           "JSONDOWNLOADDOCCERTISIGN" => json_encode($dado),
           "NRSEQORCAMENTO"           => $nrseqorcamento,
           "NRTIPOORCAMENTO"          => $nrtipoorcamento,
           "NRORG"                    => $nrorg 
        ));
    }
    
    public function validarMedicaoServico($nrnegociacaoproposta, $nrtipoorcamento) {
        $nrorg = $this->environment->getNrOrg();
        
        $params = array(
            "NRTIPOORCAMENTO"      => $nrtipoorcamento,
            "NRORG"                => $nrorg,
            "NRNEGOCIACAOPROPOSTA" => $nrnegociacaoproposta
        );
        $dataset = $this->propostaFactory->validarMedicaoServico($params);
        return (int)$dataset[0]["QTD"] > 0;
    }
    
    public function salvarAlteraSituAssina($widassinatura, $widsituacao, $nrorg, $operador) {
        $this->connection->beginTransaction();
        try {
            $idalteraemmassa     = $widsituacao["IDALTERAEMMASSA"];
            $situacaoNova        = $widsituacao["IDSITUACAO"];
            $documentos          = $widsituacao["DOCUMENTOS"];
            $dsjustaltsitumanual = $widsituacao["DSJUSTALTSITUMANUAL"];
            $dsjustificarecusa   = $widsituacao["DSJUSTIFICARECUSA"];
            
            
            /*Atualiza Documentos*/
            foreach ($documentos as $documento) {
                $params = array(
                    "IDSITUACAO"          => $situacaoNova,
                    "OPERADOR"            => $operador,
                    "NRORG"               => $nrorg,
                    "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                    "NRDOCASSINATPROP"    => $documento
                );
                
                $this->propostaFactory->salvarAlteraSituDocAssina($params);
            }
            
            if ($idalteraemmassa == false) {
                $widassinatura = array($widassinatura);
            }
            
            foreach ($widassinatura as $assina) {
                
                $nrassdigitalorca = $assina['NRASSDIGITALORCA'];
                $nrseqorcamento   = $assina['NRSEQORCAMENTO'];
                
                $params = array(
                    "IDSITUACAO"          => 'R',
                    "NRASSDIGITALORCA"    => $nrassdigitalorca,
                    "NRSEQORCAMENTO"      => $nrseqorcamento,
                    "NRORG"               => $nrorg
                );
                
                $qtRecusado = $this->propostaFactory->validaSituacaoDocAssina($params);
                
                if ($qtRecusado == 0) {
                    
                    $params = array(
                        "IDSITUACAO"          => 'P',
                        "NRASSDIGITALORCA"    => $nrassdigitalorca,
                        "NRSEQORCAMENTO"      => $nrseqorcamento,
                        "NRORG"               => $nrorg
                    );
                    
                    $qtPendente = $this->propostaFactory->validaSituacaoDocAssina($params);
                    
                    if ($qtPendente == 0) {
                        
                        $params = array(
                            "IDSITUACAO"          => $situacaoNova,
                            "OPERADOR"            => $operador,
                            "DSJUSTALTSITUMANUAL" => $dsjustaltsitumanual,
                            "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                            "NRORG"               => $nrorg,
                            "NRASSDIGITALORCA"    => $nrassdigitalorca,
                            "NRSEQORCAMENTO"      => $nrseqorcamento
                        );
                        
                        $this->propostaFactory->salvarAlteraSituAssina($params);
                    }
                    else {
                        $params = array(
                            "IDSITUACAO"          => 'P',
                            "OPERADOR"            => $operador,
                            "DSJUSTALTSITUMANUAL" => $dsjustaltsitumanual,
                            "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                            "NRORG"               => $nrorg,
                            "NRASSDIGITALORCA"    => $nrassdigitalorca,
                            "NRSEQORCAMENTO"      => $nrseqorcamento
                        );
                        
                        $this->propostaFactory->salvarAlteraSituAssina($params);
                    }
                }
                else {
                    
                    $params = array(
                        "IDSITUACAO"          => 'R',
                        "OPERADOR"            => $operador,
                        "DSJUSTALTSITUMANUAL" => $dsjustaltsitumanual,
                        "DSJUSTIFICARECUSA"   => $dsjustificarecusa,
                        "NRORG"               => $nrorg,
                        "NRASSDIGITALORCA"    => $nrassdigitalorca,
                        "NRSEQORCAMENTO"      => $nrseqorcamento
                    );
                    
                    $this->propostaFactory->salvarAlteraSituAssina($params);
                }
            }

            $this->connection->commit();
            return 'OK';
        }
         catch(\Exception $e) {
            $this->connection->rollback();
            return $e->getMessage();
        }
    }

    public function getAnexosModeloDocumentoPorIdioma($nrseqmoddocfct) {
        $params = array(
            "NRSEQMODDOCFCT" => $nrseqmoddocfct
        );

        return $this->propostaFactory->getAnexosModeloDocumentoPorIdioma($params);
    }

    public function getDadosProposta($nrseqorcamento, $nrorg) {
        $params = [
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        ];
        $dataset = $this->propostaFactory->getDadosProposta($params);
        return $dataset[0];
    }

    /**
     * Retorna a quantidade de itens que possuem uma moeda diferente da moeda da proposta
     */
    public function getQuantidadeItensMoedaDiferente($nrseqorcamento) {
        $params = [
            "NRSEQORCAMENTO" => $nrseqorcamento
        ];
        $dataset = $this->propostaFactory->getQuantidadeItensMoedaDiferente($params);
        return (int)$dataset[0]["QTD"];
    }

    public function getLinksDocumentosProposta($nrseqorcamento, $nrorg) {
        $params = [
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        ];
        
        return $this->propostaFactory->getLinksDocumentosProposta($params);
    }

    /**
     * Retorna os elementos que formam a composição da proposta (o que será inserido na FCT_TRABSERVORCAMENTO).
     * 
     * @param integer[] $escopos
     * $param mixed[]   $composicoes
     * 
     * @return mixed[]
     */
    public function getElementosComposicaoContrRenegociado(array $escopos, $composicoes, $contratoPai, $idApareceProposta = "S", $nrmoeda = null) {
        $escopos = implode(",", $escopos);
        $nrorg = $this->environment->getNrOrg();
        
        $composicoesAux = $this->getCodigoComposicaoArray($composicoes);
        $composicoesAux = implode(",", $composicoesAux);
        
        return $this->propostaFactory->getElementosComposicaoContrRenegociado($escopos, $composicoesAux, $nrorg, $idApareceProposta, $nrmoeda, $contratoPai);
    }

}

?>